(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    626089,      14582]
NotebookOptionsPosition[    612974,      14163]
NotebookOutlinePosition[    613310,      14178]
CellTagsIndexPosition[    613267,      14175]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Double Rayleigh-Duffing oscillator in nearly 1:2 resonance. MSM.\
\>", "Subtitle",
 CellChangeTimes->{{3.425124443004222*^9, 3.425124445762727*^9}, {
   3.425735461809439*^9, 3.42573547015233*^9}, 3.426348355615857*^9, {
   3.426402791378215*^9, 3.426402801108219*^9}, {3.426486298228353*^9, 
   3.426486298965107*^9}, 3.431239605251194*^9, {3.431239662218741*^9, 
   3.431239684177401*^9}, {3.436706963737631*^9, 3.436706965447862*^9}, {
   3.436707090786545*^9, 3.436707093403086*^9}}],

Cell["Double Hopf in 1:2 resonance", "Subsubtitle",
 CellChangeTimes->{3.564682106389267*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
Modification of \"Perturbation Methods with Mathematica\", by Ali H.Nayfeh \
and Char - Ming Chin; email: anayfeh@vt.edu  - cchin@vt.edu\
\>", "Text",
 CellChangeTimes->{{3.436612104894086*^9, 3.436612107479716*^9}, {
  3.436612149403952*^9, 3.436612164463007*^9}, {3.436612215423699*^9, 
  3.436612226943978*^9}, {3.436623545845568*^9, 3.436623547111357*^9}, {
  3.436623611625734*^9, 3.436623612680314*^9}}],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
Frst-order equations of motion:\
\>", "Text",
 CellChangeTimes->{3.5646915071472178`*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EOM", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["u", "1"], "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       SubscriptBox["u", "2"], "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["u", "2"], "'"}], "[", "t", "]"}], "==", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SubscriptBox["u", "2"], "[", "t", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Omega]", "1"], "2"], " ", 
        RowBox[{
         SubscriptBox["u", "1"], "[", "t", "]"}]}], "-", 
       RowBox[{"c", " ", 
        SuperscriptBox[
         RowBox[{
          SubscriptBox["u", "1"], "[", "t", "]"}], "3"]}], "-", 
       RowBox[{
        SubscriptBox["b", "1"], " ", 
        SuperscriptBox[
         RowBox[{
          SubscriptBox["u", "2"], "[", "t", "]"}], "3"]}], "+", 
       RowBox[{
        SubscriptBox["b", "0"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["u", "4"], "[", "t", "]"}], "-", 
           RowBox[{
            SubscriptBox["u", "2"], "[", "t", "]"}]}], ")"}], "2"]}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["u", "3"], "'"}], "[", "t", "]"}], "\[Equal]", 
      RowBox[{
       SubscriptBox["u", "4"], "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["u", "4"], "'"}], "[", "t", "]"}], "==", 
      RowBox[{
       RowBox[{"\[Nu]", " ", 
        RowBox[{
         SubscriptBox["u", "4"], "[", "t", "]"}]}], "-", " ", 
       RowBox[{
        SuperscriptBox[
         SubscriptBox["\[Omega]b", "2"], "2"], " ", 
        RowBox[{
         SubscriptBox["u", "3"], "[", "t", "]"}]}], "-", 
       RowBox[{"c", " ", 
        SuperscriptBox[
         RowBox[{
          SubscriptBox["u", "3"], "[", "t", "]"}], "3"]}], "-", 
       RowBox[{
        SubscriptBox["b", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SubscriptBox["u", "4"], "[", "t", "]"}], "3"]}], "-", 
       RowBox[{
        SubscriptBox["b", "0"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["u", "4"], "[", "t", "]"}], "-", 
           RowBox[{
            SubscriptBox["u", "2"], "[", "t", "]"}]}], ")"}], "2"]}]}]}]}], 
    " ", "}"}]}], ";", 
  RowBox[{"EOM", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.46893615030783*^9, 3.468936239314488*^9}, {
   3.468936272280236*^9, 3.468936318448524*^9}, 3.489321295702851*^9, {
   3.532704579668943*^9, 3.532704582861166*^9}, {3.56466457003692*^9, 
   3.564664697396453*^9}, {3.564664844965757*^9, 3.5646648563788633`*^9}, {
   3.564665954849226*^9, 3.564665963876842*^9}, 3.5646679448386106`*^9, {
   3.5646683694133253`*^9, 3.564668373028203*^9}, 3.564682139891275*^9, {
   3.5646822167786617`*^9, 3.5646822482012157`*^9}, {3.564691611505567*^9, 
   3.564691612320362*^9}, {3.564694458896144*^9, 3.5646945294788303`*^9}, 
   3.564694575037881*^9}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "1"], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        SubscriptBox["u", "2"], "[", "t", "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "2"], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Omega]", "1", "2"]}], " ", 
         RowBox[{
          SubscriptBox["u", "1"], "[", "t", "]"}]}], "-", 
        RowBox[{"c", " ", 
         SuperscriptBox[
          RowBox[{
           SubscriptBox["u", "1"], "[", "t", "]"}], "3"]}], "+", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SubscriptBox["u", "2"], "[", "t", "]"}]}], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SuperscriptBox[
          RowBox[{
           SubscriptBox["u", "2"], "[", "t", "]"}], "3"]}], "+", 
        RowBox[{
         SubscriptBox["b", "0"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["u", "2"], "[", "t", "]"}]}], "+", 
            RowBox[{
             SubscriptBox["u", "4"], "[", "t", "]"}]}], ")"}], "2"]}]}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "3"], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        SubscriptBox["u", "4"], "[", "t", "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox[
         SubscriptBox["u", "4"], "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SubsuperscriptBox["\[Omega]b", "2", "2"]}], " ", 
         RowBox[{
          SubscriptBox["u", "3"], "[", "t", "]"}]}], "-", 
        RowBox[{"c", " ", 
         SuperscriptBox[
          RowBox[{
           SubscriptBox["u", "3"], "[", "t", "]"}], "3"]}], "+", 
        RowBox[{"\[Nu]", " ", 
         RowBox[{
          SubscriptBox["u", "4"], "[", "t", "]"}]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SubscriptBox["u", "4"], "[", "t", "]"}], "3"]}], "-", 
        RowBox[{
         SubscriptBox["b", "0"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["u", "2"], "[", "t", "]"}]}], "+", 
            RowBox[{
             SubscriptBox["u", "4"], "[", "t", "]"}]}], ")"}], "2"]}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.564665010310721*^9, 3.564665782691915*^9, 3.564665869421844*^9, {
   3.5646659650276833`*^9, 3.5646659948181067`*^9}, 3.5646663586597*^9, 
   3.564668505854898*^9, 3.564680116068169*^9, 3.564680885823604*^9, 
   3.5646809234515133`*^9, 3.564681254470047*^9, 3.564682261943922*^9, 
   3.564682354704873*^9, 3.564689553151588*^9, 3.564690622945016*^9, 
   3.564693015171558*^9, 3.5646932017808533`*^9, 3.564694548150487*^9, 
   3.564694587836335*^9, 3.564694944001917*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.564691828065243*^9, 3.564691836860322*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "We use  the method of multiple scales  to obtain a second-order  uniform \
expansion of the solution of ",
 StyleBox["EOM.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " We need the three time scales  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["T", "0"], "=", "t"}], ",", 
    RowBox[{
     SubscriptBox["T", "1"], "=", 
     RowBox[{"\[Epsilon]", " ", "t"}]}], ","}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "2"], "=", 
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], " ", "t"}]}], TraditionalForm]]],
 ", which we symbolize by"
}], "Text",
 CellChangeTimes->{{3.564691587325418*^9, 3.564691660761216*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"<<", "Notation`"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Symbolize", "[", 
   TagBox[
    SubscriptBox["T", "0"],
    "NotationTemplateTag",
    Editable->True], "]"}], ";", 
  RowBox[{"Symbolize", "[", 
   TagBox[
    SubscriptBox["T", "1"],
    "NotationTemplateTag",
    Editable->True], "]"}], ";", 
  RowBox[{"Symbolize", "[", 
   TagBox[
    SubscriptBox["T", "2"],
    "NotationTemplateTag",
    Editable->True], "]"}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"timeScales", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["T", "0"], ",", 
     SubscriptBox["T", "1"], ",", 
     SubscriptBox["T", "2"]}], "}"}]}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
In terms of the new time scales, we can express the time derivatives as\
\>", "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dt", "[", "1", "]"}], "[", "expr_", "]"}], ":=", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Epsilon]", "i"], " ", 
        RowBox[{"D", "[", 
         RowBox[{"expr", ",", 
          RowBox[{"timeScales", "[", 
           RowBox[{"[", 
            RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\n", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dt", "[", "2", "]"}], "[", "expr_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"dt", "[", "1", "]"}], "[", 
         RowBox[{
          RowBox[{"dt", "[", "1", "]"}], "[", "expr", "]"}], "]"}], "//", 
        "Expand"}], ")"}], "/.", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{"i_", "/;", 
         RowBox[{"i", ">", "3"}]}]], "->", "0"}]}]}], ";"}]}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
To get the conjugate and the Hermitian:\
\>", "Text",
 CellChangeTimes->{{3.564691679924993*^9, 3.564691751927719*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"conjugateRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "->", 
      OverscriptBox["A", "_"]}], ",", 
     RowBox[{
      OverscriptBox["A", "_"], "->", "A"}], ",", 
     RowBox[{
      RowBox[{"Complex", "[", 
       RowBox[{"0", ",", "n_"}], "]"}], "->", 
      RowBox[{"Complex", "[", 
       RowBox[{"0", ",", 
        RowBox[{"-", "n"}]}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"hermitian", "[", 
   RowBox[{"mat_", "?", "MatrixQ"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"mat", "/.", "conjugateRule"}], "//", "Transpose"}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
To represent  some  of the expression s in a more concise  way, we introduce \
the following display rule:\
\>", "Text",
 CellChangeTimes->{
  3.564691679924993*^9, {3.564691774413266*^9, 3.56469178432066*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"displayRule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "a__", "]"}], "[", 
        SubscriptBox["u_", 
         RowBox[{"i_", ",", "j_"}]], "]"}], "[", "__", "]"}], ":>", 
      RowBox[{"SequenceForm", "[", 
       RowBox[{
        RowBox[{"Times", " ", "@@", " ", 
         RowBox[{"MapIndexed", "[", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox["D", 
             RowBox[{
              RowBox[{"#2", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], "#1"], " ", "&"}], 
           ",", 
           RowBox[{"{", "a", "}"}]}], "]"}]}], ",", 
        SubscriptBox["u", 
         RowBox[{"i", ",", "j"}]]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "a__", "]"}], "[", 
        SubscriptBox["A_", "i_"], "]"}], "[", "__", "]"}], ":>", 
      RowBox[{"SequenceForm", "[", 
       RowBox[{
        RowBox[{"Times", " ", "@@", " ", 
         RowBox[{"MapIndexed", "[", 
          RowBox[{
           RowBox[{
            SubsuperscriptBox["D", 
             RowBox[{"#2", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "#1"], " ", "&"}], ",", 
           RowBox[{"{", "a", "}"}]}], "]"}]}], ",", 
        SubscriptBox["A", "i"]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["u_", 
        RowBox[{"i_", ",", "j_"}]], "[", "__", "]"}], "->", 
      SubscriptBox["u", 
       RowBox[{"i", ",", "j"}]]}], ",", 
     RowBox[{
      RowBox[{
       SubscriptBox["A_", "i_"], "[", "__", "]"}], "->", 
      SubscriptBox["A", "i"]}]}], "}"}]}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1]
}, Closed]],

Cell[CellGroupData[{

Cell["Perturbation equations", "Section",
 CellChangeTimes->{{3.564691876461494*^9, 3.564691881016098*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell["Ordering of the dampings", "Text",
 CellChangeTimes->{{3.425736517807783*^9, 3.425736553483668*^9}, {
  3.431240222139191*^9, 3.431240223639584*^9}, {3.431935755599774*^9, 
  3.431935773078864*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"damprule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Nu]", "->", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", "\[Nu]"}]}], ",", 
     RowBox[{"\[Mu]", "->", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", "\[Mu]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4251043292719707`*^9, 3.425104393779907*^9}, {
   3.425117922311624*^9, 3.425117924343356*^9}, 3.532704143794887*^9, {
   3.564680097615533*^9, 3.5646801009172907`*^9}, {3.5646808642811823`*^9, 
   3.5646808655618467`*^9}, {3.5646894802945433`*^9, 3.5646894814492702`*^9}}],

Cell["Rescaling", "Text",
 CellChangeTimes->{{3.425736517807783*^9, 3.425736553483668*^9}, {
  3.431240222139191*^9, 3.431240223639584*^9}, {3.431935755599774*^9, 
  3.431935773078864*^9}, {3.564691918257083*^9, 3.564691920101303*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"scaling", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["u", "1"], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SubscriptBox["u", "1"], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "2"], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SubscriptBox["u", "2"], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "3"], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SubscriptBox["u", "3"], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "4"], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SubscriptBox["u", "4"], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u", "1"], "'"}], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", "1"], "'"}], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u", "2"], "'"}], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", "2"], "'"}], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u", "3"], "'"}], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", "3"], "'"}], "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u", "4"], "'"}], "[", "t", "]"}], "->", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["u", "4"], "'"}], "[", "t", "]"}]}]}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{
  3.40724029025*^9, {3.425117829652022*^9, 3.4251178915034437`*^9}, {
   3.4251233791633663`*^9, 3.42512340476985*^9}, {3.426486326807131*^9, 
   3.426486356431104*^9}, {3.468936645635673*^9, 3.468936678502692*^9}, {
   3.5646648970746183`*^9, 3.564664930005307*^9}, {3.5646663319077377`*^9, 
   3.5646663404617023`*^9}, {3.5646682680135603`*^9, 3.564668269298279*^9}, {
   3.564694671082449*^9, 3.5646946974874077`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "1"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["u", "1"], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "2"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["u", "2"], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "3"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["u", "3"], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "4"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["u", "4"], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["u", "1"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "1"], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["u", "2"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "2"], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["u", "3"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "3"], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["u", "4"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["u", "4"], "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5646685063395977`*^9, 3.5646801166110773`*^9, 
  3.564680886333046*^9, 3.564680924043511*^9, 3.564681255022109*^9, 
  3.564682431798584*^9, 3.564689553680932*^9, 3.56469062331208*^9, 
  3.564693015509358*^9, 3.564693202293594*^9, 3.5646947187480383`*^9, 
  3.5646949442915773`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"detuning", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]b", "2"], "->", 
     RowBox[{
      SubscriptBox["\[Omega]", "2"], "+", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", "\[Sigma]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5646683138579063`*^9, 3.5646683789275713`*^9}, {
  3.5646895400005617`*^9, 3.56468954111586*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "We seek a second-order uniform expansion of the solution of         ",
 StyleBox["EOM",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " in the form"
}], "Text",
 CellMargins->{{12, Inherited}, {Inherited, Inherited}},
 CellChangeTimes->{{3.5646919293100348`*^9, 3.564691936158931*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"solRule", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["u", "i_"], "->", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", 
           RowBox[{"j", "-", "1"}]], " ", 
          RowBox[{
           SubscriptBox["u", 
            RowBox[{"i", ",", 
             RowBox[{"j", "-", "1"}]}]], "[", 
           RowBox[{"#1", ",", "#2", ",", "#3"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "3"}], "}"}]}], "]"}], " ", "&"}], ")"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.564664942291052*^9, 3.564664958675078*^9}, 
   3.564694709529498*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Expressing  the time derivative in    ",
 StyleBox["EOM ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " in terms  of the time scales  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "0"], ",", 
    SubscriptBox["T", "1"], ","}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "2"], TraditionalForm]]],
 ", we have"
}], "Text",
 CellChangeTimes->{{3.564691944536255*^9, 3.5646919648816357`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"multiScales", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["u_", "i_"], "[", "t", "]"}], "->", 
      RowBox[{
       SubscriptBox["u", "i"], "[", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "n_", "]"}], "[", 
        SubscriptBox["u_", "i_"], "]"}], "[", "t", "]"}], ":>", 
      RowBox[{
       RowBox[{"dt", "[", "n", "]"}], "[", 
       RowBox[{
        SubscriptBox["u", "i"], "[", 
        RowBox[{
         SubscriptBox["T", "0"], ",", 
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], "]"}]}], ",", 
     RowBox[{"t", "->", 
      SubscriptBox["T", "0"]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.5646660966648197`*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Substituting ",
 StyleBox["multiScales",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " and ",
 StyleBox["solRule",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " into ",
 StyleBox["EOM",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ", expanding the result for small \[Epsilon], and discarding terms of order \
higher than    ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Epsilon]", "3"], TraditionalForm]]],
 ", we obtain"
}], "Text",
 CellMargins->{{12, Inherited}, {Inherited, Inherited}},
 CellChangeTimes->{{3.564691969159915*^9, 3.564691977596836*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqa1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"EOM", "/.", "scaling"}], "/.", "detuning"}], "/.", 
         "multiScales"}], "/.", "damprule"}], "/.", "solRule"}], "//", 
      "ExpandAll"}], ")"}], "/.", 
    RowBox[{
     SuperscriptBox["\[Epsilon]", 
      RowBox[{"n_", "/;", 
       RowBox[{"n", ">", "3"}]}]], "->", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.56466527917138*^9, 3.5646652820297813`*^9}, 
   3.564665390031139*^9, {3.5646664144796963`*^9, 3.56466641824089*^9}, {
   3.5646684889251623`*^9, 3.564668491722618*^9}, {3.564691972385579*^9, 
   3.564691983469825*^9}, 3.564693162084754*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
Equating coefficients of like powers of \[Epsilon], we obtain\
\>", "Text",
 CellChangeTimes->{{3.564693170654913*^9, 3.564693171677878*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqEps", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Rest", "[", 
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"CoefficientList", "[", 
          RowBox[{
           RowBox[{"Subtract", " ", "@@", " ", "#"}], ",", "\[Epsilon]"}], 
          "]"}], "==", "0"}], "]"}], "]"}], "&"}], " ", "/@", " ", "eqa1"}], "//",
     "Transpose"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.564691989590975*^9, 3.5646919906611032`*^9}, 
   3.564693167401888*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell["\<\
To place the linear operators  on one side and the nonhomogeneous  terms  on \
the other side, we define\
\>", "Text",
 CellChangeTimes->{{3.564691996907053*^9, 3.564692005320677*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqOrder", "[", "i_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], " ", "&"}], " ", "/@", " ", 
       RowBox[{"eqEps", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
      RowBox[{
       SubscriptBox["u_", 
        RowBox[{"k_", ",", "0"}]], "->", 
       SubscriptBox["u", 
        RowBox[{"k", ",", 
         RowBox[{"i", "-", "1"}]}]]}]}], ")"}], "==", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", "&"}], " ", "/@", " ", 
        RowBox[{"eqEps", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
       RowBox[{
        SubscriptBox["u_", 
         RowBox[{"k_", ",", "0"}]], "->", 
        SubscriptBox["u", 
         RowBox[{"k", ",", 
          RowBox[{"i", "-", "1"}]}]]}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], " ", "&"}], " ", "/@", " ", 
       RowBox[{"eqEps", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}]}], "//", 
   "Thread"}]}]], "Input",
 CellChangeTimes->{{3.56466519780506*^9, 3.564665223712633*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Using ",
 StyleBox["eqOrder[i]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " and ",
 StyleBox["displayRule",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ", we rewrite  ",
 StyleBox["eqEps",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " in a concise way as"
}], "Text",
 CellChangeTimes->{{3.5646652269261293`*^9, 3.564665228053516*^9}, 
   3.564692015682623*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"eqOrder", "[", "1", "]"}], "/.", "displayRule"}], "//", 
  "TableForm"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eqOrder", "[", "2", "]"}], "/.", "displayRule"}], "//", 
  "TableForm"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"eqOrder", "[", "3", "]"}], "/.", "displayRule"}], "//", 
  "TableForm"}]}], "Input",
 CellChangeTimes->{{3.564665565509755*^9, 3.564665587083441*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 1, 0]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"2", ",", "0"}]]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"2", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 2, 0]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"1", ",", "0"}]]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"3", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 3, 0]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"4", ",", "0"}]]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"4", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 4, 0]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"3", ",", "0"}]]}]}], "\[Equal]", "0"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.56466375518375*^9, 3.564663904779903*^9, 3.564664013814*^9, 
   3.564664351441021*^9, 3.564665138046818*^9, {3.564665229757763*^9, 
   3.56466523782148*^9}, 3.564665294735588*^9, {3.564665568943987*^9, 
   3.564665587858069*^9}, 3.5646663721470213`*^9, 3.564666427487932*^9, 
   3.564668506586281*^9, 3.564680116871058*^9, 3.5646808865311117`*^9, 
   3.5646809242183228`*^9, 3.564681255436285*^9, 3.564682468240679*^9, 
   3.5646895538088617`*^9, 3.564690623447426*^9, 3.564693015594648*^9, 
   3.564693202463546*^9, 3.5646947188757*^9, 3.56469494440762*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "1"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 1, 1]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"2", ",", "1"}]]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           SubscriptBox["D", "1"], "\[InvisibleSpace]", 
           SubscriptBox["u", 
            RowBox[{"1", ",", "0"}]]}],
          SequenceForm[
           Subscript[D, 1], 
           Subscript[$CellContext`u, 1, 0]],
          Editable->False], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"2", ",", "1"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 2, 1]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"1", ",", "1"}]]}]}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            SubscriptBox["D", "1"], "\[InvisibleSpace]", 
            SubscriptBox["u", 
             RowBox[{"2", ",", "0"}]]}],
           SequenceForm[
            Subscript[D, 1], 
            Subscript[$CellContext`u, 2, 0]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         SubscriptBox["b", "0"], " ", 
         SubsuperscriptBox["u", 
          RowBox[{"2", ",", "0"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]]}], "+", 
        RowBox[{
         SubscriptBox["b", "0"], " ", 
         SubsuperscriptBox["u", 
          RowBox[{"4", ",", "0"}], "2"]}]}]}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"3", ",", "1"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 3, 1]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"4", ",", "1"}]]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           SubscriptBox["D", "1"], "\[InvisibleSpace]", 
           SubscriptBox["u", 
            RowBox[{"3", ",", "0"}]]}],
          SequenceForm[
           Subscript[D, 1], 
           Subscript[$CellContext`u, 3, 0]],
          Editable->False], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"4", ",", "1"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 4, 1]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"3", ",", "1"}]]}]}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            SubscriptBox["D", "1"], "\[InvisibleSpace]", 
            SubscriptBox["u", 
             RowBox[{"4", ",", "0"}]]}],
           SequenceForm[
            Subscript[D, 1], 
            Subscript[$CellContext`u, 4, 0]],
           Editable->False], ")"}]}], "-", 
        RowBox[{
         SubscriptBox["b", "0"], " ", 
         SubsuperscriptBox["u", 
          RowBox[{"2", ",", "0"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]]}], "-", 
        RowBox[{
         SubscriptBox["b", "0"], " ", 
         SubsuperscriptBox["u", 
          RowBox[{"4", ",", "0"}], "2"]}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.56466375518375*^9, 3.564663904779903*^9, 3.564664013814*^9, 
   3.564664351441021*^9, 3.564665138046818*^9, {3.564665229757763*^9, 
   3.56466523782148*^9}, 3.564665294735588*^9, {3.564665568943987*^9, 
   3.564665587858069*^9}, 3.5646663721470213`*^9, 3.564666427487932*^9, 
   3.564668506586281*^9, 3.564680116871058*^9, 3.5646808865311117`*^9, 
   3.5646809242183228`*^9, 3.564681255436285*^9, 3.564682468240679*^9, 
   3.5646895538088617`*^9, 3.564690623447426*^9, 3.564693015594648*^9, 
   3.564693202463546*^9, 3.5646947188757*^9, 3.564694944424275*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "2"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 1, 2]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"2", ",", "2"}]]}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            SubscriptBox["D", "1"], "\[InvisibleSpace]", 
            SubscriptBox["u", 
             RowBox[{"1", ",", "1"}]]}],
           SequenceForm[
            Subscript[D, 1], 
            Subscript[$CellContext`u, 1, 1]],
           Editable->False], ")"}]}], "-", 
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "2"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 2], 
          Subscript[$CellContext`u, 1, 0]],
         Editable->False]}]}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"2", ",", "2"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 2, 2]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"1", ",", "2"}]]}]}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            SubscriptBox["D", "1"], "\[InvisibleSpace]", 
            SubscriptBox["u", 
             RowBox[{"2", ",", "1"}]]}],
           SequenceForm[
            Subscript[D, 1], 
            Subscript[$CellContext`u, 2, 1]],
           Editable->False], ")"}]}], "-", 
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "2"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"2", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 2], 
          Subscript[$CellContext`u, 2, 0]],
         Editable->False], "-", 
        RowBox[{"c", " ", 
         SubsuperscriptBox["u", 
          RowBox[{"1", ",", "0"}], "3"]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]]}], "-", 
        RowBox[{
         SubscriptBox["b", "1"], " ", 
         SubsuperscriptBox["u", 
          RowBox[{"2", ",", "0"}], "3"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "1"}]]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "1"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "1"}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "1"}]]}]}]}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"3", ",", "2"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 3, 2]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"4", ",", "2"}]]}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            SubscriptBox["D", "1"], "\[InvisibleSpace]", 
            SubscriptBox["u", 
             RowBox[{"3", ",", "1"}]]}],
           SequenceForm[
            Subscript[D, 1], 
            Subscript[$CellContext`u, 3, 1]],
           Editable->False], ")"}]}], "-", 
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "2"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"3", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 2], 
          Subscript[$CellContext`u, 3, 0]],
         Editable->False]}]}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"4", ",", "2"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 4, 2]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"3", ",", "2"}]]}]}], "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          InterpretationBox[
           RowBox[{
            SubscriptBox["D", "1"], "\[InvisibleSpace]", 
            SubscriptBox["u", 
             RowBox[{"4", ",", "1"}]]}],
           SequenceForm[
            Subscript[D, 1], 
            Subscript[$CellContext`u, 4, 1]],
           Editable->False], ")"}]}], "-", 
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "2"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"4", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 2], 
          Subscript[$CellContext`u, 4, 0]],
         Editable->False], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "1"}]]}], "-", 
        RowBox[{"2", " ", "\[Sigma]", " ", 
         SubscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"3", ",", "0"}]]}], "-", 
        RowBox[{"c", " ", 
         SubsuperscriptBox["u", 
          RowBox[{"3", ",", "0"}], "3"]}], "+", 
        RowBox[{"\[Nu]", " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "1"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]]}], "-", 
        RowBox[{
         SubscriptBox["b", "2"], " ", 
         SubsuperscriptBox["u", 
          RowBox[{"4", ",", "0"}], "3"]}], "+", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "1"}]]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["b", "0"], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]], " ", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "1"}]]}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.56466375518375*^9, 3.564663904779903*^9, 3.564664013814*^9, 
   3.564664351441021*^9, 3.564665138046818*^9, {3.564665229757763*^9, 
   3.56466523782148*^9}, 3.564665294735588*^9, {3.564665568943987*^9, 
   3.564665587858069*^9}, 3.5646663721470213`*^9, 3.564666427487932*^9, 
   3.564668506586281*^9, 3.564680116871058*^9, 3.5646808865311117`*^9, 
   3.5646809242183228`*^9, 3.564681255436285*^9, 3.564682468240679*^9, 
   3.5646895538088617`*^9, 3.564690623447426*^9, 3.564693015594648*^9, 
   3.564693202463546*^9, 3.5646947188757*^9, 3.564694944426269*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["First-Order Equations", "Section",
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"eqOrder", "[", "1", "]"}], "/.", "displayRule"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.564667637677041*^9, 3.5646676416257153`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"1", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 1, 0]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"2", ",", "0"}]]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"2", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 2, 0]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"1", ",", "0"}]]}]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"3", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 3, 0]],
         Editable->False], "-", 
        SubscriptBox["u", 
         RowBox[{"4", ",", "0"}]]}], "\[Equal]", "0"}]},
     {
      RowBox[{
       RowBox[{
        InterpretationBox[
         RowBox[{
          SubscriptBox["D", "0"], "\[InvisibleSpace]", 
          SubscriptBox["u", 
           RowBox[{"4", ",", "0"}]]}],
         SequenceForm[
          Subscript[D, 0], 
          Subscript[$CellContext`u, 4, 0]],
         Editable->False], "+", 
        RowBox[{
         SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
         SubscriptBox["u", 
          RowBox[{"3", ",", "0"}]]}]}], "\[Equal]", "0"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.564667453564372*^9, 3.564667642098157*^9, 
  3.564668506611751*^9, 3.5646801468317204`*^9, 3.5646808865885077`*^9, 
  3.5646809242765636`*^9, 3.5646812555319138`*^9, 3.564682503415593*^9, 
  3.564689553879161*^9, 3.564690623551717*^9, 3.56469301560948*^9, 
  3.564693202479288*^9, 3.564694727433031*^9, 3.564694944474662*^9}]
}, Open  ]],

Cell[TextData[{
 "The generating  system of     ",
 StyleBox["EOM",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " can be defined as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["D", "0"], "x"}], "=", 
    RowBox[{"A", " ", "x"}]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " is the state  vector; that is,"
}], "Text",
 CellChangeTimes->{
  3.564682372091111*^9, {3.56469206857449*^9, 3.564692095022616*^9}, {
   3.564693292454776*^9, 3.564693302221212*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"states0t", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"1", ",", "0"}]], "[", 
      RowBox[{
       SubscriptBox["T", "0"], ",", 
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], ",", 
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"2", ",", "0"}]], "[", 
      RowBox[{
       SubscriptBox["T", "0"], ",", 
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], ",", 
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"3", ",", "0"}]], "[", 
      RowBox[{
       SubscriptBox["T", "0"], ",", 
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], ",", 
     RowBox[{
      SubscriptBox["u", 
       RowBox[{"4", ",", "0"}]], "[", 
      RowBox[{
       SubscriptBox["T", "0"], ",", 
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.564666982353447*^9, 3.564666985912054*^9}, 
   3.564667516891424*^9, {3.5646675950910263`*^9, 3.564667625656012*^9}, 
   3.564667720330432*^9, {3.5646947325385323`*^9, 3.5646947406443167`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Using these  states,  we find that the coefficient matrix ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 " of the linear part of ",
 StyleBox["EOM",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " is given by"
}], "Text",
 CellChangeTimes->{{3.5646921015211687`*^9, 3.564692107170789*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixA", "=", 
  RowBox[{"Outer", "[", 
   RowBox[{"D", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}], " ", "/@", " ", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"eqOrder", "[", "1", "]"}], ",", 
        RowBox[{"D", "[", 
         RowBox[{"states0t", ",", 
          SubscriptBox["T", "0"]}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ",", "states0t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.564665028058777*^9, 3.5646650732612267`*^9}, {
   3.56466752411493*^9, 3.5646675693444977`*^9}, 3.56466772313266*^9, 
   3.5646685216213493`*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}], ",", "0", ",", "0", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.564663748903603*^9, 3.564663864356523*^9, 3.56466397844934*^9, 
   3.564664351002364*^9, 3.564665010366095*^9, {3.564665056574111*^9, 
   3.564665074250499*^9}, 3.564665869474844*^9, {3.564665970042775*^9, 
   3.564665995063422*^9}, 3.564666358804944*^9, 3.5646675701954*^9, 
   3.5646676286815367`*^9, 3.5646677241741734`*^9, {3.5646685119507103`*^9, 
   3.5646685217820797`*^9}, 3.564680146991777*^9, 3.5646808866371098`*^9, 
   3.5646809243374367`*^9, 3.5646812555817413`*^9, 3.5646825151214314`*^9, 
   3.5646895539228773`*^9, 3.564690623593854*^9, 3.5646930156667967`*^9, 
   3.564693202518033*^9, 3.564694754531436*^9, 3.564694944572001*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "The eigenvalues and eigenvectors of      ",
 StyleBox["matrixA",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " can be obtained as"
}], "Text",
 CellChangeTimes->{{3.564692112931876*^9, 3.564692117320375*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"matrixA", "//", "Eigensystem"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Omega]", "1"]}], ",", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Omega]", "1"]}], ",", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], ",", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Omega]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["\[ImaginaryI]", 
        SubscriptBox["\[Omega]", "1"]], ",", "1", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[ImaginaryI]", 
         SubscriptBox["\[Omega]", "1"]]}], ",", "1", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       FractionBox["\[ImaginaryI]", 
        SubscriptBox["\[Omega]", "2"]], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", 
        FractionBox["\[ImaginaryI]", 
         SubscriptBox["\[Omega]", "2"]]}], ",", "1"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.564663748983965*^9, 3.564663864445772*^9, 3.5646639866344976`*^9, 
   3.564664351155571*^9, 3.564665081961643*^9, 3.5646658696533957`*^9, {
   3.564665973524682*^9, 3.564665995238461*^9}, 3.5646663589956217`*^9, 
   3.564667647645026*^9, 3.564668523242385*^9, 3.564680147044898*^9, 
   3.564680886697628*^9, 3.5646809243945017`*^9, 3.564681255634386*^9, 
   3.564682527298017*^9, 3.564689553973531*^9, 3.564690623642322*^9, 
   3.5646930157147093`*^9, 3.564693202553708*^9, 3.564694754639584*^9, 
   3.56469494462435*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "Hence, the right eigenvectors of ",
 StyleBox["matrixA",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " corresponding to the eigenvalues ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", 
    SubscriptBox["\[Omega]", "1"]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", 
    SubscriptBox["\[Omega]", "2"]}], TraditionalForm]]],
 ", respectively, are"
}], "Text",
 CellMargins->{{12, Inherited}, {Inherited, Inherited}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rightVec", "=", 
  RowBox[{
   RowBox[{"Eigenvectors", "[", "matrixA", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "]"}], "]"}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["\[ImaginaryI]", 
       SubscriptBox["\[Omega]", "1"]]}], ",", "1", ",", "0", ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox["\[ImaginaryI]", 
       SubscriptBox["\[Omega]", "2"]]}], ",", "1"}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.564663748993981*^9, 3.564663864495126*^9, 3.564663986666234*^9, 
   3.564664351189712*^9, 3.564665087847369*^9, 3.564665869695387*^9, {
   3.56466597460743*^9, 3.564665995300309*^9}, 3.564666359125144*^9, 
   3.564667652346407*^9, 3.5646685244705*^9, 3.564680147087213*^9, 
   3.5646808867407827`*^9, 3.564680924446506*^9, 3.564681255679369*^9, 
   3.564682530938323*^9, 3.564689554024417*^9, 3.5646906236787977`*^9, 
   3.5646930157536707`*^9, 3.564693202581328*^9, 3.564694754685954*^9, 
   3.564694944657092*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "Moreover, the left eigenvectors of ",
 StyleBox["matrixA",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " corresponding to the eigenvalues ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", 
    SubscriptBox["\[Omega]", "1"]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", 
    SubscriptBox["\[Omega]", "2"]}], TraditionalForm]]],
 ", respectively, are"
}], "Text",
 CellMargins->{{12, Inherited}, {Inherited, Inherited}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"leftVec", "=", 
  RowBox[{
   RowBox[{"Eigenvectors", "[", 
    RowBox[{"hermitian", "[", "matrixA", "]"}], "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "]"}], "]"}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Omega]", "1"]}], ",", "1", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.564663749001904*^9, 3.564663864536893*^9, 3.5646639866966543`*^9, 
   3.5646643511990957`*^9, 3.564665091097185*^9, 3.564665869749061*^9, {
   3.564665975694614*^9, 3.564665995343318*^9}, 3.56466635919989*^9, 
   3.5646676547443047`*^9, 3.564668525817102*^9, 3.564680147096035*^9, 
   3.564680886831175*^9, 3.564680924495885*^9, 3.5646812557315197`*^9, 
   3.564682533807024*^9, 3.564689554070621*^9, 3.564690623714017*^9, 
   3.5646930157929497`*^9, 3.564693202635111*^9, 3.564694754732997*^9, 
   3.564694944691668*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell["whose complex conjugate is", "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ccleftVec", "=", 
  RowBox[{"leftVec", "/.", "conjugateRule"}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Omega]", "1"]}], ",", "1", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Omega]", "2"]}], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.56466374901026*^9, 3.564663864578473*^9, 3.564663986723171*^9, 
   3.564664351205175*^9, 3.564665093968079*^9, 3.564665869790929*^9, {
   3.564665977078115*^9, 3.564665995375169*^9}, 3.564666359207015*^9, 
   3.56466765725867*^9, 3.564668528184423*^9, 3.564680147131571*^9, 
   3.564680886883924*^9, 3.564680924546475*^9, 3.5646812557839737`*^9, 
   3.56468253500313*^9, 3.5646895541592903`*^9, 3.564690623751957*^9, 
   3.5646930158335457`*^9, 3.564693202668919*^9, 3.56469475478032*^9, 
   3.564694944724277*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "The homogeneous solution of    ",
 StyleBox["eqOrder[1]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " can be obtained by using"
}], "Text",
 CellChangeTimes->{{3.564692134947513*^9, 3.564692135426495*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenForm", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"#", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", 
       SubscriptBox["T", "0"]}], "]"}]}], " ", "&"}], " ", "/@", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Eigensystem", "[", "matrixA", "]"}], "]"}]}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}]]}], 
      SubscriptBox["\[Omega]", "1"]], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "1"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]]}], 
       SubscriptBox["\[Omega]", "1"]]}], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "1"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]]}], 
      SubscriptBox["\[Omega]", "2"]], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]]}], 
       SubscriptBox["\[Omega]", "2"]]}], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5646637552339697`*^9, 3.564663904821207*^9, 
  3.564664017410387*^9, 3.564664351485818*^9, 3.564666805325334*^9, 
  3.564667665854149*^9, 3.564668529057103*^9, 3.564680147170458*^9, 
  3.56468088693587*^9, 3.564680924596835*^9, 3.5646812558345327`*^9, 
  3.564682536611555*^9, 3.5646895543518457`*^9, 3.564690623788856*^9, 
  3.5646930158731127`*^9, 3.564693202701886*^9, 3.564694754826804*^9, 
  3.5646949447680397`*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol1hForm", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"I", " ", 
       SubscriptBox["\[Omega]", "i"], 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["A", "_"], "i"], "[", 
           RowBox[{
            SubscriptBox["T", "1"], ",", 
            SubscriptBox["T", "2"]}], "]"}]}], ",", 
         RowBox[{
          SubscriptBox["A", "i"], "[", 
          RowBox[{
           SubscriptBox["T", "1"], ",", 
           SubscriptBox["T", "2"]}], "]"}]}], "}"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "2"}], "}"}]}], "]"}], "]"}], ".", 
   "eigenForm"}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "1"]}]], " ", 
     RowBox[{
      SubscriptBox["A", "1"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "1"]}]], " ", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "1"]}]], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     RowBox[{
      SubscriptBox["A", "1"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "1"]}]], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "2"]}]], " ", 
     RowBox[{
      SubscriptBox["A", "2"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "2"]}]], " ", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "2"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "2"]}]], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     RowBox[{
      SubscriptBox["A", "2"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SubscriptBox["T", "0"], " ", 
       SubscriptBox["\[Omega]", "2"]}]], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "2"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.564663755244216*^9, 3.564663904855659*^9, 
  3.564664019085596*^9, 3.564664351525044*^9, 3.564666829019044*^9, 
  3.56466767084085*^9, 3.56466853213101*^9, 3.564680147209749*^9, 
  3.564680886976735*^9, 3.564680924748386*^9, 3.5646812560003967`*^9, 
  3.5646825388554983`*^9, 3.564689554394766*^9, 3.564690623797687*^9, 
  3.5646930159239807`*^9, 3.5646932027355967`*^9, 3.564694754878564*^9, 
  3.5646949448140783`*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"states0", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["u", 
      RowBox[{"1", ",", "0"}]], ",", 
     SubscriptBox["u", 
      RowBox[{"2", ",", "0"}]], ",", 
     SubscriptBox["u", 
      RowBox[{"3", ",", "0"}]], ",", 
     SubscriptBox["u", 
      RowBox[{"4", ",", "0"}]]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.564666982353447*^9, 3.564666985912054*^9}, 
   3.564667516891424*^9, {3.5646675950910263`*^9, 3.564667625656012*^9}, {
   3.56466773519526*^9, 3.564667742627421*^9}, {3.564694760310902*^9, 
   3.56469476548763*^9}, 3.564694931139571*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Since the first-order equations are homogeneous, the solution of ",
 StyleBox["eqOrder[1]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " can be expressed as"
}], "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol1", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"states0", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "->", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["T", "0"], ",", 
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "}"}], ",", 
       RowBox[{
        RowBox[{"sol1hForm", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "//", "Evaluate"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.5646677158473263`*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"1", ",", "0"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        RowBox[{
         SubscriptBox["A", "1"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["A", "_"], "1"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}]}]}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"2", ",", "0"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        RowBox[{
         SubscriptBox["A", "1"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["A", "_"], "1"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}]}]}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"3", ",", "0"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        RowBox[{
         SubscriptBox["A", "2"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["A", "_"], "2"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}]}]}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"4", ",", "0"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        RowBox[{
         SubscriptBox["A", "2"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["A", "_"], "2"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}]}]}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.56466375526934*^9, 3.564663904874391*^9, 3.5646640240773487`*^9, 
   3.5646643515700912`*^9, 3.564666837403286*^9, 3.5646669873096333`*^9, 
   3.564667748521541*^9, 3.5646685348499527`*^9, 3.564680147224185*^9, 
   3.5646808870236397`*^9, 3.564680924761325*^9, 3.56468125607276*^9, 
   3.56468254835098*^9, 3.56468955440991*^9, 3.564690623840152*^9, 
   3.5646930159932833`*^9, 3.564693202769405*^9, {3.564694754933835*^9, 
   3.56469476845063*^9}, 3.5646949449032803`*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Second-Order Equations", "Section",
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "To describe  quantitatively the nearness   of the ",
 StyleBox["two-to-one internal resonance  ",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[TildeTilde]", 
    RowBox[{"2", 
     SubscriptBox["\[Omega]", "1"]}]}], TraditionalForm]]],
 ", we introduce the  resonance   condition defined by"
}], "Text",
 CellChangeTimes->{{3.564692157552149*^9, 3.564692240503962*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"ResonanceCond", "=", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "==", 
     RowBox[{"2", 
      SubscriptBox["\[Omega]", "1"]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.564668412597142*^9, 3.5646684128352222`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"omgList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SubscriptBox["\[Omega]", "i"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.564666862508688*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["\[Omega]", "1"], ",", 
   SubscriptBox["\[Omega]", "2"]}], "}"}]], "Output",
 CellChangeTimes->{3.5646668628795137`*^9, 3.564667758438147*^9, 
  3.5646685374005327`*^9, 3.564680147298057*^9, 3.56468088721463*^9, 
  3.564680924821311*^9, 3.5646812561506147`*^9, 3.564682554094233*^9, 
  3.564689554460368*^9, 3.564690624036944*^9, 3.5646930160909452`*^9, 
  3.56469320279937*^9, 3.564694816098275*^9, 3.56469496568571*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"omgRule", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"ResonanceCond", ",", 
       RowBox[{"Drop", "[", 
        RowBox[{"omgList", ",", 
         RowBox[{"{", "#", "}"}]}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], " ", "&"}], " ", "/@", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Rule]", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Omega]", "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Rule]", 
     FractionBox[
      SubscriptBox["\[Omega]", "2"], "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.564663750560822*^9, 3.5646638893922253`*^9, 
  3.564664117216507*^9, 3.564664351629444*^9, 3.5646668650992517`*^9, 
  3.564667759357246*^9, 3.564668538520166*^9, 3.564680147343339*^9, 
  3.564680887222184*^9, 3.5646809248695173`*^9, 3.5646812562006483`*^9, 
  3.564682555510475*^9, 3.5646895544667788`*^9, 3.564690624113062*^9, 
  3.5646930160975122`*^9, 3.564693202806539*^9, 3.564694816104844*^9, 
  3.564694965692423*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"omgRuleM", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"ResonanceCond", ",", 
       RowBox[{"Drop", "[", 
        RowBox[{"omgList", ",", 
         RowBox[{"{", "#", "}"}]}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], " ", "&"}], " ", "/@", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "2", ",", "2"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.564670140756266*^9, 3.564670148490336*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Rule]", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Omega]", "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "\[Rule]", 
     RowBox[{"2", " ", 
      SubscriptBox["\[Omega]", "1"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Rule]", 
     FractionBox[
      SubscriptBox["\[Omega]", "2"], "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "\[Rule]", 
     FractionBox[
      SubscriptBox["\[Omega]", "2"], "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.56467014932024*^9, 3.564680147387738*^9, 
  3.564680887228938*^9, 3.5646809249169083`*^9, 3.5646812562857323`*^9, 
  3.564682557318736*^9, 3.564689554508338*^9, 3.5646906241499567`*^9, 
  3.564693016136994*^9, 3.5646932028264933`*^9, 3.56469481615457*^9, 
  3.5646949657483273`*^9}]
}, Open  ]],

Cell["\<\
To convert small-divisor terms into secular terms, we define the rules\
\>", "Text",
 CellChangeTimes->{3.564692284674822*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"expRule1", "[", "j_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", "arg_", "]"}], ":>", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"arg", "/.", 
       RowBox[{"omgRule", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "/.", 
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       SubscriptBox["T", "0"]}], "->", 
      SubscriptBox["T", "1"]}]}], "]"}]}]}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"expRule1M", "[", "j_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", "arg_", "]"}], ":>", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"arg", "/.", 
       RowBox[{"omgRuleM", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "/.", 
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       SubscriptBox["T", "0"]}], "->", 
      SubscriptBox["T", "1"]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.56467019033263*^9, 3.5646701931331882`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"expRule2", "=", 
   RowBox[{
    RowBox[{"Exp", "[", "a_", "]"}], ":>", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"a", "/.", 
        RowBox[{"(", 
         RowBox[{"ResonanceCond", "/.", 
          RowBox[{"Equal", "->", "Rule"}]}], ")"}]}], "]"}], "/.", 
      RowBox[{
       RowBox[{"\[Epsilon]", " ", 
        SubscriptBox["T", "0"]}], "->", 
       SubscriptBox["T", "1"]}]}], "]"}]}]}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"expRule3", "=", 
   RowBox[{
    RowBox[{"Exp", "[", "a_", "]"}], ":>", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"a", "/.", 
       RowBox[{
        SubscriptBox["T", "1"], "->", 
        RowBox[{"\[Epsilon]", " ", 
         SubscriptBox["T", "0"]}]}]}], "//", "Expand"}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.564680157377717*^9, 3.5646801580662203`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell["Second order equations", "Text",
 CellChangeTimes->{{3.564692296947694*^9, 3.564692324607373*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqOrder", "[", "2", "]"}], "/.", "displayRule"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"1", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 1, 1]],
      Editable->False], "-", 
     SubscriptBox["u", 
      RowBox[{"2", ",", "1"}]]}], "\[Equal]", 
    RowBox[{"-", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["u", 
         RowBox[{"1", ",", "0"}]]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`u, 1, 0]],
       Editable->False], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"2", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 2, 1]],
      Editable->False], "+", 
     RowBox[{
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox["u", 
       RowBox[{"1", ",", "1"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["u", 
          RowBox[{"2", ",", "0"}]]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`u, 2, 0]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["u", 
       RowBox[{"2", ",", "0"}], "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["u", 
       RowBox[{"2", ",", "0"}]], " ", 
      SubscriptBox["u", 
       RowBox[{"4", ",", "0"}]]}], "+", 
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["u", 
       RowBox[{"4", ",", "0"}], "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"3", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 3, 1]],
      Editable->False], "-", 
     SubscriptBox["u", 
      RowBox[{"4", ",", "1"}]]}], "\[Equal]", 
    RowBox[{"-", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["u", 
         RowBox[{"3", ",", "0"}]]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`u, 3, 0]],
       Editable->False], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"4", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 4, 1]],
      Editable->False], "+", 
     RowBox[{
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox["u", 
       RowBox[{"3", ",", "1"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["u", 
          RowBox[{"4", ",", "0"}]]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`u, 4, 0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["u", 
       RowBox[{"2", ",", "0"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["u", 
       RowBox[{"2", ",", "0"}]], " ", 
      SubscriptBox["u", 
       RowBox[{"4", ",", "0"}]]}], "-", 
     RowBox[{
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["u", 
       RowBox[{"4", ",", "0"}], "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.564666931084361*^9, 3.5646677661093607`*^9, 
  3.564668549231532*^9, 3.5646801656810217`*^9, 3.564680887300418*^9, 
  3.5646809250056477`*^9, 3.564681256365556*^9, 3.5646825721507473`*^9, 
  3.564682860085431*^9, 3.564689554577887*^9, 3.564690624261777*^9, 
  3.564693016232958*^9, 3.5646932028687763`*^9, 3.5646948162767057`*^9, 
  3.564694965821574*^9}]
}, Open  ]],

Cell[TextData[{
 "Substituting the first-order solution into the second-order equations     , \
",
 StyleBox["eqOrder[2]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ", yields"
}], "Text",
 CellChangeTimes->{{3.564692296947694*^9, 3.564692298609028*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"order2Eq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"eqOrder", "[", "2", "]"}], "/.", "sol1"}], "//", 
    "ExpandAll"}]}], ";"}], "\n", 
 RowBox[{"order2Eq", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"1", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 1, 1]],
      Editable->False], "-", 
     SubscriptBox["u", 
      RowBox[{"2", ",", "1"}]]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}]]}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "1"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 1]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox[
          OverscriptBox["A", "_"], "1"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[
          OverBar[$CellContext`A], 1]],
        Editable->False], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"2", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 2, 1]],
      Editable->False], "+", 
     RowBox[{
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox["u", 
       RowBox[{"1", ",", "1"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "1"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 1]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox[
          OverscriptBox["A", "_"], "1"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[
          OverBar[$CellContext`A], 1]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "1", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "2", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"3", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 3, 1]],
      Editable->False], "-", 
     SubscriptBox["u", 
      RowBox[{"4", ",", "1"}]]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]]}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "2"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 2]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox[
          OverscriptBox["A", "_"], "2"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[
          OverBar[$CellContext`A], 2]],
        Editable->False], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"4", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 4, 1]],
      Editable->False], "+", 
     RowBox[{
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox["u", 
       RowBox[{"3", ",", "1"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "2"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 2]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox[
          OverscriptBox["A", "_"], "2"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[
          OverBar[$CellContext`A], 2]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "1", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}], "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "2", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5646637553326683`*^9, 3.564663904909318*^9, 
  3.564664026469718*^9, 3.564664120824704*^9, 3.564664351734034*^9, 
  3.5646668818413143`*^9, 3.564666997493284*^9, 3.5646677701816*^9, 
  3.564668553099382*^9, 3.564680176356387*^9, 3.5646808873417597`*^9, 
  3.56468092508057*^9, 3.56468125641079*^9, 3.564682869500146*^9, 
  3.5646895546436462`*^9, 3.564690624300035*^9, 3.564693016276746*^9, 
  3.564693202902751*^9, 3.5646948163209953`*^9, 3.564694965891078*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "Next, we substitute  the ",
 StyleBox["expRule1[i]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " into the right-hand sides  of ",
 StyleBox["order2Eq",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " to transform  the small-divisor  terms  into secular  terms,  collect the \
terms  responsible  for secular  terms, and obtain"
}], "Text",
 CellChangeTimes->{{3.5646923347068567`*^9, 3.564692363058218*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ST11", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", 
        RowBox[{"expRule1", "[", "1", "]"}]}], ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"I", " ", 
         SubscriptBox["\[Omega]", "1"], " ", 
         SubscriptBox["T", "0"]}], "]"}]}], "]"}], " ", "&"}], " ", "/@", " ",
     "order2Eq"}]}], ";"}], "\n", 
 RowBox[{"ST11", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "1"], "\[InvisibleSpace]", 
       SubscriptBox["A", "1"]}],
      SequenceForm[
       Subscript[D, 1], 
       Subscript[$CellContext`A, 1]],
      Editable->False], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{"2", " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}]}], ",", "0", ",", 
   RowBox[{"2", " ", 
    SubscriptBox["A", "2"], " ", 
    SubscriptBox["b", "0"], " ", 
    SubscriptBox["\[Omega]", "1"], " ", 
    SubscriptBox["\[Omega]", "2"], " ", 
    SubscriptBox[
     OverscriptBox["A", "_"], "1"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.564663755391294*^9, 3.564663904949698*^9, 
  3.564664029116377*^9, 3.564664125310927*^9, 3.564664351773012*^9, 
  3.564667032803384*^9, 3.564667774139648*^9, 3.564668573351467*^9, 
  3.564680176483263*^9, 3.564680887388289*^9, 3.5646809251381063`*^9, 
  3.564681256456585*^9, 3.56468291966075*^9, 3.564689554684321*^9, 
  3.564690624346911*^9, 3.564693016322997*^9, 3.5646932029333687`*^9, 
  3.564694816370245*^9, 3.5646949659517612`*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ST12", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", 
        RowBox[{"expRule1", "[", "2", "]"}]}], ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"I", " ", 
         SubscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["T", "0"]}], "]"}]}], "]"}], " ", "&"}], " ", "/@", " ",
     "order2Eq"}]}], ";"}], "\n", 
 RowBox[{"ST12", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{"-", 
     SubsuperscriptBox["A", "1", "2"]}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], ",", 
   RowBox[{"-", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "1"], "\[InvisibleSpace]", 
       SubscriptBox["A", "2"]}],
      SequenceForm[
       Subscript[D, 1], 
       Subscript[$CellContext`A, 2]],
      Editable->False], ")"}]}], ",", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubscriptBox["b", "0"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "2"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}], " ", 
     SubscriptBox["\[Omega]", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.564663755444175*^9, 3.564663904990671*^9, 
  3.564664129112464*^9, 3.564664351810748*^9, 3.564667036341309*^9, 
  3.56466777890394*^9, 3.564668574595525*^9, 3.5646801765265408`*^9, 
  3.5646808874265327`*^9, 3.564680925200529*^9, 3.564681256504753*^9, 
  3.564682923288876*^9, 3.5646895547312927`*^9, 3.5646906243931637`*^9, 
  3.564693016366235*^9, 3.564693202961041*^9, 3.5646948164253263`*^9, 
  3.56469496600632*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "The solvability conditions of the second-order  equations demands  that ",
 StyleBox["ST11",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " and ",
 StyleBox["ST12",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " be orthogonal to every solution of the adjoint homogeneous  problems,  \
namely the components of    ",
 StyleBox["ccleftVec",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ". Imposing these conditions, we obtain"
}], "Text",
 CellChangeTimes->{{3.5646923756015368`*^9, 3.564692393790834*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SCond1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ccleftVec", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ".", "ST11"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"ccleftVec", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ".", "ST12"}], "==", "0"}]}], "}"}]}],
   ";"}], "\n", 
 RowBox[{"SCond1", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "1"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 1]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}], "-", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "2"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 2]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "2"]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",\

 CellChangeTimes->{3.564663755456287*^9, 3.564663905060137*^9, 
  3.564664131278886*^9, 3.564664351845056*^9, 3.564667782860558*^9, 
  3.564668576129939*^9, 3.56468017656819*^9, 3.564680887479815*^9, 
  3.564680925246972*^9, 3.564681256549488*^9, 3.564682929486671*^9, 
  3.564689554774973*^9, 3.564690624401664*^9, 3.564693016373867*^9, 
  3.564693202988373*^9, 3.564694816470851*^9, 3.564694966050591*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell["or", "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SCond1Rule1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"SCond1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["A", "1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           SubscriptBox["T", "1"], ",", 
           SubscriptBox["T", "2"]}], "]"}], ",", 
         RowBox[{
          SubsuperscriptBox["A", "2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           SubscriptBox["T", "1"], ",", 
           SubscriptBox["T", "2"]}], "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Expand"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SCond1Rule1", "/.", "displayRule"}], "//", "TableForm"}]}], "Input",\

 CellChangeTimes->{{3.564680915771821*^9, 3.564680917694396*^9}, 
   3.5646829451636133`*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "1"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 1]],
        Editable->False], "\[Rule]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}]}]},
     {
      RowBox[{
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "1"], "\[InvisibleSpace]", 
         SubscriptBox["A", "2"]}],
        SequenceForm[
         Subscript[D, 1], 
         Subscript[$CellContext`A, 2]],
        Editable->False], "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SubsuperscriptBox["A", "1", "2"], " ", 
          SubscriptBox["b", "0"], " ", 
          SubsuperscriptBox["\[Omega]", "1", "2"]}], 
         RowBox[{"2", " ", 
          SubscriptBox["\[Omega]", "2"]}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5646637555003433`*^9, 3.5646639051270113`*^9, 3.564664133027191*^9, 
   3.564664351883218*^9, 3.564667792945758*^9, 3.564668577544389*^9, 
   3.564680176611541*^9, 3.564680887520808*^9, 3.564680925305896*^9, 
   3.56468125659439*^9, {3.564682933333799*^9, 3.564682945858219*^9}, 
   3.5646895548163567`*^9, 3.564690624439253*^9, 3.564693016413869*^9, 
   3.564693203014338*^9, 3.56469481651543*^9, 3.5646949660936327`*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell["whose complex conjugate is", "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"ccSCond1Rule1", "=", 
   RowBox[{"SCond1Rule1", "/.", "conjugateRule"}]}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Using these solvability conditions and    ",
 StyleBox["expRule3",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ", we rewrite   ",
 StyleBox["order2Eq",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " as"
}], "Text",
 CellChangeTimes->{{3.564692405710905*^9, 3.564692411678752*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"order2Eqm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"order2Eq", "[", 
           RowBox[{"[", "#", "]"}], "]"}], "/.", "SCond1Rule1"}], "/.", 
         "ccSCond1Rule1"}], "/.", 
        RowBox[{"expRule1M", "[", "#", "]"}]}], ")"}], "&"}], "/@", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "//", 
    "ExpandAll"}]}], ";"}], "\n", 
 RowBox[{"order2Eqm", "/.", "displayRule"}]}], "Input",
 CellChangeTimes->{{3.5646699472337627`*^9, 3.5646699585798683`*^9}, {
  3.564670058030806*^9, 3.564670082556245*^9}, {3.564670159740549*^9, 
  3.5646701699495907`*^9}, {3.564670207924733*^9, 3.564670243765964*^9}, {
  3.564679810362653*^9, 3.5646798136020107`*^9}, {3.564679856161293*^9, 
  3.5646798638910847`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"1", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 1, 1]],
      Editable->False], "-", 
     SubscriptBox["u", 
      RowBox[{"2", ",", "1"}]]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"2", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 2, 1]],
      Editable->False], "+", 
     RowBox[{
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox["u", 
       RowBox[{"1", ",", "1"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "1"]}]]}], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"3", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "1", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "1"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "2", "2"]}]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"3", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 3, 1]],
      Editable->False], "-", 
     SubscriptBox["u", 
      RowBox[{"4", ",", "1"}]]}], "\[Equal]", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]], " ", 
       SubsuperscriptBox["A", "1", "2"], " ", 
       SubscriptBox["b", "0"], " ", 
       SubsuperscriptBox["\[Omega]", "1", "2"]}], 
      RowBox[{"2", " ", 
       SubscriptBox["\[Omega]", "2"]}]], "-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["T", "0"], " ", 
         SubscriptBox["\[Omega]", "2"]}]], " ", 
       SubscriptBox["b", "0"], " ", 
       SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
       SubsuperscriptBox[
        OverscriptBox["A", "_"], "1", "2"]}], 
      RowBox[{"2", " ", 
       SubscriptBox["\[Omega]", "2"]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "0"], "\[InvisibleSpace]", 
       SubscriptBox["u", 
        RowBox[{"4", ",", "1"}]]}],
      SequenceForm[
       Subscript[D, 0], 
       Subscript[$CellContext`u, 4, 1]],
      Editable->False], "+", 
     RowBox[{
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox["u", 
       RowBox[{"3", ",", "1"}]]}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "1", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3", "2"]}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["T", "0"], " ", 
        SubscriptBox["\[Omega]", "2"]}]], " ", 
      SubscriptBox["b", "0"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubsuperscriptBox[
       OverscriptBox["A", "_"], "2", "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5646702445567636`*^9, 3.564679823080402*^9, {3.5646798601110563`*^9, 
   3.564679864517165*^9}, 3.564680176733273*^9, 3.564680887660142*^9, 
   3.564680925488336*^9, 3.564681256754727*^9, 3.564682991150391*^9, 
   3.5646895548893213`*^9, 3.564690624506175*^9, 3.5646930165334044`*^9, 
   3.5646932030902452`*^9, 3.564694816588654*^9, 3.564694966167761*^9}]
}, Open  ]],

Cell["\<\
Assumptions for the parameters to be real\
\>", "Text",
 CellChangeTimes->{{3.564692431771633*^9, 3.564692466748796*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Omega]", "1"], ",", 
     SubscriptBox["\[Omega]", "2"], ",", 
     SubscriptBox["b", "0"], ",", "c", ",", "\[Mu]", ",", "\[Nu]", ",", 
     SubscriptBox["b", "1"], ",", 
     SubscriptBox["b", "2"], ",", "\[Sigma]"}], "}"}], "\[Element]", "Reals", 
   " "}]}]], "Input",
 CellChangeTimes->{{3.420989945068742*^9, 3.420989956576477*^9}, {
  3.42099035235305*^9, 3.420990372716331*^9}, {3.425125083003879*^9, 
  3.425125086153509*^9}, {3.426936445183179*^9, 3.426936537639694*^9}, {
  3.500038235451017*^9, 3.500038236024522*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "|", 
    SubscriptBox["\[Omega]", "2"], "|", 
    SubscriptBox["b", "0"], "|", "c", "|", "\[Mu]", "|", "\[Nu]", "|", 
    SubscriptBox["b", "1"], "|", 
    SubscriptBox["b", "2"], "|", "\[Sigma]"}], ")"}], "\[Element]", 
  "Reals"}]], "Output",
 CellChangeTimes->{3.5646691148306932`*^9, 3.564679914236521*^9, 
  3.564680176788144*^9, 3.564680887707892*^9, 3.5646809255542383`*^9, 
  3.564681256809093*^9, 3.5646846990123777`*^9, 3.5646895551322308`*^9, 
  3.564690624712241*^9, 3.5646930165784883`*^9, 3.564693203121561*^9, 
  3.564694816636057*^9, 3.5646949662172623`*^9}]
}, Open  ]],

Cell["\<\
Application of the resonance conditions\
\>", "Text",
 CellChangeTimes->{{3.5646924941506042`*^9, 3.564692546371655*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"order2Eqmf", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"order2Eqm", "[", 
        RowBox[{"[", "#", "]"}], "]"}], "/.", 
       RowBox[{"omgRuleM", "[", 
        RowBox[{"[", "#", "]"}], "]"}]}], ")"}], "&"}], "/@", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5646838852771273`*^9, 3.564683933340288*^9}, {
  3.5646839964889402`*^9, 3.564684003844564*^9}}],

Cell[TextData[{
 "Transforming ",
 StyleBox["order2Eqm",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " into a set of ordinary-differential equations (just for thechnical \
reasons) and using    ",
 StyleBox["DSolve",
  FontWeight->"Bold"],
 ", we obtain the particular solutions as"
}], "Text",
 CellChangeTimes->{{3.5646924941506042`*^9, 3.564692511780141*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"sol2p", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"DSolve", "[", 
         RowBox[{
          RowBox[{"order2Eqmf", "/.", 
           RowBox[{
            SubscriptBox["u_", 
             RowBox[{"i_", ",", "1"}]], "->", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["u", 
                RowBox[{"i", ",", "1"}]], "[", "#1", "]"}], " ", "&"}], 
             ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"1", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], ",", 
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"2", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], ",", 
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"3", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], ",", 
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"4", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}]}], "}"}], ",", 
          SubscriptBox["T", "0"]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"C", "[", "_", "]"}], "->", "0"}]}], "//", "Simplify"}]}], 
    ";"}], ")"}], "//", "Timing"}]], "Input",
 CellChangeTimes->{{3.564668699559326*^9, 3.564668709203971*^9}, 
   3.564684008576469*^9, {3.564694799316291*^9, 3.564694806715062*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.0905299999999998`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.5646637631518793`*^9, 3.564663908237197*^9, 
  3.5646642205075293`*^9, 3.564664355064864*^9, 3.564668851881585*^9, 
  3.564669205060506*^9, 3.564679923094872*^9, 3.56468018096721*^9, 
  3.564680891838608*^9, 3.56468092966256*^9, 3.564681260888352*^9, 
  3.564684015737961*^9, 3.564684709973032*^9, 3.564689559471373*^9, 
  3.564690628866355*^9, 3.564693019780541*^9, 3.56469320633278*^9, 
  3.5646949692778053`*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell["The second-order states are", "Text",
 CellChangeTimes->{{3.5646925751705103`*^9, 3.564692612694563*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"states1", "=", 
  RowBox[{"states0", "/.", 
   RowBox[{
    SubscriptBox["u_", 
     RowBox[{"i_", ",", "0"}]], "->", 
    SubscriptBox["u", 
     RowBox[{"i", ",", "1"}]]}]}]}]], "Input",
 CellChangeTimes->{{3.564668866944923*^9, 3.5646688773383923`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["u", 
    RowBox[{"1", ",", "1"}]], ",", 
   SubscriptBox["u", 
    RowBox[{"2", ",", "1"}]], ",", 
   SubscriptBox["u", 
    RowBox[{"3", ",", "1"}]], ",", 
   SubscriptBox["u", 
    RowBox[{"4", ",", "1"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.564663763320923*^9, 3.564663908410207*^9, 
  3.56466422300767*^9, 3.564664355282803*^9, 3.564668877726985*^9, 
  3.564669210136207*^9, 3.564679927841024*^9, 3.564680181184905*^9, 
  3.564680892026189*^9, 3.5646809298265123`*^9, 3.564681261050205*^9, 
  3.5646840196169567`*^9, 3.5646847137529*^9, 3.5646895600325747`*^9, 
  3.564690629208818*^9, 3.5646930199088573`*^9, 3.56469320654221*^9, 
  3.564694972167561*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "Hence, the second-order solutions of      ",
 StyleBox["order2Eqm",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " can be expressed as"
}], "Text",
 CellChangeTimes->{{3.5646925751705103`*^9, 3.5646925765705633`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"states1", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "->", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["T", "0"], ",", 
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "}"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"Expand", "[", 
           RowBox[{"sol2p", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], "]"}], "/.", 
          RowBox[{
           RowBox[{"Exp", "[", "a_", "]"}], ":>", 
           RowBox[{"Exp", "[", 
            RowBox[{"a", "//", "Expand"}], "]"}]}]}], "//", "Evaluate"}]}], 
       "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"sol2", "/.", "displayRule"}]}], "Input",
 CellChangeTimes->{
  3.5646688858547983`*^9, {3.564669285953652*^9, 3.56466931676127*^9}, {
   3.5646697480012617`*^9, 3.5646697621052933`*^9}, 3.5646799441847067`*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"1", ",", "1"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        FractionBox["1", "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox["A", "1", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"3", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox["A", "2"]}], "+", 
       RowBox[{
        FractionBox["4", "15"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox["A", "2", "2"]}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}], "+", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "+", 
       RowBox[{"8", " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "+", 
       RowBox[{
        FractionBox["4", "15"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "2", "2"]}]}]}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"2", ",", "1"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubsuperscriptBox["A", "1", "2"]}], "-", 
       RowBox[{
        FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"3", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox["A", "2"]}], "+", 
       RowBox[{
        FractionBox["16", "15"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"4", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubsuperscriptBox["A", "2", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "1", "2"]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "+", 
       RowBox[{
        FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "-", 
       RowBox[{
        FractionBox["16", "15"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "1"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "1"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "2", "2"]}]}]}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"3", ",", "1"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        FractionBox["1", "16"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox["A", "1", "2"]}], "+", 
       RowBox[{
        FractionBox["4", "5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox["A", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox["A", "2", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}], "+", 
       RowBox[{
        FractionBox["4", "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "1", "2"]}], "+", 
       RowBox[{
        FractionBox["4", "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "+", 
       RowBox[{
        FractionBox["4", "5"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "2", "2"]}]}]}], "]"}]}], ",", 
   RowBox[{
    SubscriptBox["u", 
     RowBox[{"4", ",", "1"}]], "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], ",", 
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubsuperscriptBox["A", "1", "2"]}], "+", 
       RowBox[{
        FractionBox["6", "5"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["3", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox["A", "2"]}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubsuperscriptBox["A", "2", "2"]}], "+", 
       RowBox[{
        FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubscriptBox["A", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "1", "2"]}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubscriptBox["A", "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "-", 
       RowBox[{
        FractionBox["6", "5"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], " ", 
        SubscriptBox[
         OverscriptBox["A", "_"], "2"]}], "+", 
       RowBox[{
        FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["T", "0"], " ", 
          SubscriptBox["\[Omega]", "2"]}]], " ", 
        SubscriptBox["b", "0"], " ", 
        SubscriptBox["\[Omega]", "2"], " ", 
        SubsuperscriptBox[
         OverscriptBox["A", "_"], "2", "2"]}]}]}], "]"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.564679944645214*^9, 3.564680181281312*^9, 
  3.564680892109331*^9, 3.564680929861546*^9, 3.5646812611037827`*^9, 
  3.564684023178782*^9, 3.5646847163019953`*^9, 3.5646876870511017`*^9, 
  3.564689560127952*^9, 3.564690629301118*^9, 3.564693019948121*^9, 
  3.564693206631372*^9, 3.5646949801839743`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Third-Order Equations", "Section",
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "Substituting the first- and second-order  solutions into the right-hand \
sides  of the third-order equations,  ",
 StyleBox["eqOrder[3]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ", yields"
}], "Text",
 CellChangeTimes->{{3.564692625890571*^9, 3.564692632953727*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{
  RowBox[{"order3Eqrhs", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/.", "sol1"}], "/.", "sol2"}], 
      "]"}], " ", "&"}], " ", "/@", " ", 
    RowBox[{"eqOrder", "[", "3", "]"}]}]}], ";"}]], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "To eliminate the term s that lead to secular  terms  from ",
 StyleBox["order3Eqrhs",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 ", we use  ",
 StyleBox["expRule1[i]",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " to transform the terms that convert small-divisor terms into secular \
terms, calculate the vectors proportional to the   ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["E", 
     RowBox[{"I", " ", 
      SubscriptBox["\[Omega]", "i"], " ", 
      SubscriptBox["T", "0"]}]], ","}], TraditionalForm]]],
 " and obtain"
}], "Text",
 CellChangeTimes->{{3.564692638050734*^9, 3.564692657424363*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ST21", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"order3Eqrhs", "/.", 
      RowBox[{"expRule1", "[", "1", "]"}]}], ",", 
     RowBox[{"Exp", "[", 
      RowBox[{"I", " ", 
       SubscriptBox["\[Omega]", "1"], " ", 
       SubscriptBox["T", "0"]}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"ST21", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "2"], "\[InvisibleSpace]", 
        SubscriptBox["A", "1"]}],
       SequenceForm[
        Subscript[D, 2], 
        Subscript[$CellContext`A, 1]],
       Editable->False], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[
         OverBar[$CellContext`A], 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["b", "0"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "2"], "\[InvisibleSpace]", 
        SubscriptBox["A", "1"]}],
       SequenceForm[
        Subscript[D, 2], 
        Subscript[$CellContext`A, 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["\[Omega]", "1"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Mu]", " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[
         OverBar[$CellContext`A], 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{"3", " ", "c", " ", 
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "+", 
    RowBox[{
     FractionBox["4", "3"], " ", 
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{"3", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubscriptBox["b", "1"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "3"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "+", 
    RowBox[{
     FractionBox["1", "8"], " ", 
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "+", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}], "+", 
    RowBox[{
     FractionBox["56", "15"], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["4", "3"]}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[
         OverBar[$CellContext`A], 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["b", "0"]}], "-", 
    RowBox[{
     FractionBox["4", "3"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "3"]}], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox[
         OverscriptBox["A", "_"], "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[
         OverBar[$CellContext`A], 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "-", 
    RowBox[{
     FractionBox["4", "3"], " ", 
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{
     FractionBox["1", "8"], " ", 
     SubsuperscriptBox["A", "1", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}], "-", 
    RowBox[{
     FractionBox["56", "15"], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.564663763559461*^9, 3.5646639085567427`*^9, 
  3.5646642305860577`*^9, 3.564664355489233*^9, 3.564680361090624*^9, 
  3.5646808922280293`*^9, 3.5646809299544153`*^9, 3.5646812612147713`*^9, 
  3.564687694064165*^9, 3.5646895602187767`*^9, 3.564690629387579*^9, 
  3.564693020109251*^9, 3.5646932067467203`*^9, 3.564694988885334*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ST22", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"order3Eqrhs", "/.", 
      RowBox[{"expRule1", "[", "2", "]"}]}], ",", 
     RowBox[{"Exp", "[", 
      RowBox[{"I", " ", 
       SubscriptBox["\[Omega]", "2"], " ", 
       SubscriptBox["T", "0"]}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"ST22", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["2", "3"]}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{
       SubscriptBox["D", "1"], "\[InvisibleSpace]", 
       SubscriptBox["A", "1"]}],
      SequenceForm[
       Subscript[D, 1], 
       Subscript[$CellContext`A, 1]],
      Editable->False], ")"}], " ", 
    SubscriptBox["A", "1"], " ", 
    SubscriptBox["b", "0"]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["4", "3"]}], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "1"]}], "-", 
    RowBox[{"5", " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{
     FractionBox["16", "15"], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{
     FractionBox["32", "15"], " ", 
     SubsuperscriptBox["A", "2", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}], "-", 
    RowBox[{
     FractionBox["4", "3"], " ", 
     SubsuperscriptBox["A", "2", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "2"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 2], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "8"], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["b", "0"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "2"], "\[InvisibleSpace]", 
        SubscriptBox["A", "2"]}],
       SequenceForm[
        Subscript[D, 2], 
        Subscript[$CellContext`A, 2]],
       Editable->False], ")"}], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Nu]", " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "-", 
    RowBox[{"2", " ", "\[Sigma]", " ", 
     SubscriptBox["A", "2"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        SubscriptBox["D", "1"], "\[InvisibleSpace]", 
        SubscriptBox["A", "1"]}],
       SequenceForm[
        Subscript[D, 1], 
        Subscript[$CellContext`A, 1]],
       Editable->False], ")"}], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["b", "0"], " ", 
     SubscriptBox["\[Omega]", "2"]}], "+", 
    RowBox[{"5", " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "+", 
    RowBox[{
     FractionBox["16", "15"], " ", 
     SubscriptBox["A", "1"], " ", 
     SubscriptBox["A", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "1"]}], "-", 
    RowBox[{"3", " ", "c", " ", 
     SubsuperscriptBox["A", "2", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}], "+", 
    RowBox[{
     FractionBox["32", "15"], " ", 
     SubsuperscriptBox["A", "2", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubscriptBox["\[Omega]", "1"], " ", 
     SubscriptBox["\[Omega]", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}], "+", 
    RowBox[{
     FractionBox["4", "3"], " ", 
     SubsuperscriptBox["A", "2", "2"], " ", 
     SubsuperscriptBox["b", "0", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}], "-", 
    RowBox[{"3", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["A", "2", "2"], " ", 
     SubscriptBox["b", "2"], " ", 
     SubsuperscriptBox["\[Omega]", "2", "3"], " ", 
     SubscriptBox[
      OverscriptBox["A", "_"], "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.564663763619652*^9, 3.564663908592157*^9, 
  3.564664232740574*^9, 3.564664355538875*^9, 3.564680389571558*^9, 
  3.564680892311282*^9, 3.564680929997673*^9, 3.5646812612854443`*^9, 
  3.564687696947345*^9, 3.564689560319585*^9, 3.5646906294555683`*^9, 
  3.564693020144123*^9, 3.564693206831481*^9, 3.564694988952509*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell[TextData[{
 "Hence, demanding that ",
 StyleBox["ST21",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " and ",
 StyleBox["ST22",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " be orthogonal to the components of ",
 StyleBox["ccleftVec",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " yields the solvability conditions"
}], "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SCond2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"ccleftVec", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ".", "ST21"}], "]"}], "==", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"ccleftVec", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ".", "ST22"}], "]"}], "==", "0"}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{"SCond2", "/.", "displayRule"}]}], "Input",
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "2"], "\[InvisibleSpace]", 
         SubscriptBox["A", "1"]}],
        SequenceForm[
         Subscript[D, 2], 
         Subscript[$CellContext`A, 1]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Mu]", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{"3", " ", "c", " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{
      FractionBox["4", "3"], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "1"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "3"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{
      FractionBox["1", "8"], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{
      FractionBox["56", "15"], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         SubscriptBox["D", "2"], "\[InvisibleSpace]", 
         SubscriptBox["A", "2"]}],
        SequenceForm[
         Subscript[D, 2], 
         Subscript[$CellContext`A, 2]],
        Editable->False], ")"}], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Nu]", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{"2", " ", "\[Sigma]", " ", 
      SubscriptBox["A", "2"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{"5", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "+", 
     RowBox[{
      FractionBox["16", "15"], " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{"3", " ", "c", " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{
      FractionBox["32", "15"], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     RowBox[{
      FractionBox["4", "3"], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox["b", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "3"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}]}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.564663763663185*^9, 3.564663908610907*^9, 
  3.564664234597106*^9, 3.564664355573535*^9, 3.564680396472337*^9, 
  3.564680892366789*^9, 3.564680930043231*^9, 3.564681261331236*^9, 
  3.564687698312578*^9, 3.564689560394346*^9, 3.564690629501367*^9, 
  3.564693020172621*^9, 3.564693206913537*^9, 3.564694989025519*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]],

Cell["or", "Text",
 TextAlignment->Left,
 TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SCond2Rule1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"SCond2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["A", "1", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           SubscriptBox["T", "1"], ",", 
           SubscriptBox["T", "2"]}], "]"}], ",", 
         RowBox[{
          SubsuperscriptBox["A", "2", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{
           SubscriptBox["T", "1"], ",", 
           SubscriptBox["T", "2"]}], "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Expand"}]}], ";"}], "\n", 
 RowBox[{"SCond2Rule1", "/.", "displayRule"}]}], "Input",
 CellChangeTimes->{{3.564680421730624*^9, 3.5646804239290123`*^9}},
 TextAlignment->Left,
 TextJustification->1],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     RowBox[{
      SubscriptBox["D", "2"], "\[InvisibleSpace]", 
      SubscriptBox["A", "1"]}],
     SequenceForm[
      Subscript[D, 2], 
      Subscript[$CellContext`A, 1]],
     Editable->False], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       SubscriptBox["A", "1"]}], "2"], "+", 
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
       SubsuperscriptBox["A", "1", "2"], " ", 
       SubscriptBox[
        OverscriptBox["A", "_"], "1"]}], 
      RowBox[{"2", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubscriptBox["b", "1"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{
      FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["A", "1", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     FractionBox[
      RowBox[{"28", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["A", "1"], " ", 
       SubscriptBox["A", "2"], " ", 
       SubsuperscriptBox["b", "0", "2"], " ", 
       SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
       SubscriptBox[
        OverscriptBox["A", "_"], "2"]}], 
      RowBox[{"15", " ", 
       SubscriptBox["\[Omega]", "1"]}]]}]}], ",", 
   RowBox[{
    InterpretationBox[
     RowBox[{
      SubscriptBox["D", "2"], "\[InvisibleSpace]", 
      SubscriptBox["A", "2"]}],
     SequenceForm[
      Subscript[D, 2], 
      Subscript[$CellContext`A, 2]],
     Editable->False], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Nu]", " ", 
       SubscriptBox["A", "2"]}], "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Sigma]", " ", 
      SubscriptBox["A", "2"]}], "-", 
     RowBox[{
      FractionBox["8", "15"], " ", "\[ImaginaryI]", " ", 
      SubscriptBox["A", "1"], " ", 
      SubscriptBox["A", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "1"]}], "-", 
     FractionBox[
      RowBox[{"5", " ", "\[ImaginaryI]", " ", 
       SubscriptBox["A", "1"], " ", 
       SubscriptBox["A", "2"], " ", 
       SubsuperscriptBox["b", "0", "2"], " ", 
       SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
       SubscriptBox[
        OverscriptBox["A", "_"], "1"]}], 
      RowBox[{"2", " ", 
       SubscriptBox["\[Omega]", "2"]}]], "-", 
     RowBox[{
      FractionBox["16", "15"], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "+", 
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
       SubsuperscriptBox["A", "2", "2"], " ", 
       SubscriptBox[
        OverscriptBox["A", "_"], "2"]}], 
      RowBox[{"2", " ", 
       SubscriptBox["\[Omega]", "2"]}]], "-", 
     RowBox[{
      FractionBox["2", "3"], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}], "-", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      SubsuperscriptBox["A", "2", "2"], " ", 
      SubscriptBox["b", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "2", "2"], " ", 
      SubscriptBox[
       OverscriptBox["A", "_"], "2"]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.564663763670981*^9, 3.56466390866299*^9, 3.564664236284852*^9, 
   3.5646643556161003`*^9, {3.564680400094221*^9, 3.56468042434573*^9}, 
   3.564680892418242*^9, 3.564680930096636*^9, 3.56468126138643*^9, 
   3.5646877001569777`*^9, 3.5646895604609127`*^9, 3.564690629558096*^9, 
   3.564693020206086*^9, 3.5646932069729023`*^9, 3.564694989079442*^9},
 TextAlignment->Left,
 TextJustification->1]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reconstitution", "Section",
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[{
 "We reconstitute  ",
 StyleBox["SCond1Rule1",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " and ",
 StyleBox["SCond2Rule1",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 " and obtain"
}], "Text",
 CellChangeTimes->{3.56469267370253*^9},
 TextAlignment->Left,
 TextJustification->1],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SubscriptBox["dA", "1"], "dt"], "=", 
   RowBox[{"ame", "[", "1", "]"}]}], TraditionalForm]]]], "Text",
 CellChangeTimes->{{3.431939443173417*^9, 3.431939469601864*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ame", "[", "1", "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["A", "1"], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["A", "1"], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}]}], ")"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{"SCond1Rule1", ",", 
      RowBox[{"SCond2Rule1", "/.", 
       RowBox[{"omgRule", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"ame", "[", "1", "]"}], "/.", "displayRule"}]}]], "Input",
 CellChangeTimes->{{3.564680794859891*^9, 3.5646808003880653`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[Mu]", " ", 
    SubscriptBox["A", "1"]}], "2"], "+", 
  FractionBox[
   RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
    SubsuperscriptBox["A", "1", "2"], " ", 
    SubscriptBox[
     OverscriptBox["A", "_"], "1"]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[Omega]", "1"]}]], "-", 
  RowBox[{
   FractionBox["19", "24"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["A", "1", "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SubsuperscriptBox["A", "1", "2"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["A", "2"], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "-", 
  RowBox[{
   FractionBox["127", "15"], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["A", "1"], " ", 
   SubscriptBox["A", "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "2"]}]}]], "Output",
 CellChangeTimes->{3.564680801348435*^9, 3.564680892501409*^9, 
  3.564680930142426*^9, 3.56468126143163*^9, 3.5646877054105167`*^9, 
  3.564689560520239*^9, 3.564690629602162*^9, 3.5646930202297897`*^9, 
  3.564693207033154*^9, 3.564694996635377*^9}]
}, Open  ]],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SubscriptBox["dA", "2"], "dt"], "=", 
   RowBox[{"ame", "[", "2", "]"}]}], TraditionalForm]]]], "Text",
 CellChangeTimes->{{3.431939443173417*^9, 3.431939475122715*^9}, {
  3.489322351463826*^9, 3.489322352542944*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ame", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        SubscriptBox["A", "2"], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}], "+", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["A", "2"], 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}]}], ")"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{"SCond1Rule1", ",", 
      RowBox[{"SCond2Rule1", "/.", 
       RowBox[{"omgRule", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"ame", "[", "2", "]"}], "/.", "displayRule"}]}]], "Input",
 CellChangeTimes->{{3.426490552210117*^9, 3.426490557925002*^9}, {
  3.43193829460993*^9, 3.431938300991336*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[Nu]", " ", 
    SubscriptBox["A", "2"]}], "2"], "+", 
  RowBox[{"\[ImaginaryI]", " ", "\[Sigma]", " ", 
   SubscriptBox["A", "2"]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["A", "1", "2"], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "-", 
  RowBox[{
   FractionBox["107", "60"], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["A", "1"], " ", 
   SubscriptBox["A", "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "+", 
  FractionBox[
   RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
    SubsuperscriptBox["A", "2", "2"], " ", 
    SubscriptBox[
     OverscriptBox["A", "_"], "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "1"]}]], "-", 
  RowBox[{
   FractionBox["12", "5"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["A", "2", "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "2"]}], "-", 
  RowBox[{"6", " ", 
   SubsuperscriptBox["A", "2", "2"], " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "2"]}]}]], "Output",
 CellChangeTimes->{3.564680835706645*^9, 3.564680892560318*^9, 
  3.564680930182087*^9, 3.5646812614758673`*^9, 3.564687707715626*^9, 
  3.564689560708864*^9, 3.564690629610161*^9, 3.564693020239753*^9, 
  3.564693207097386*^9, 3.564694996792712*^9}]
}, Open  ]],

Cell["Better representation", "Text",
 CellChangeTimes->{{3.42648694682091*^9, 3.426486953088364*^9}, {
  3.431938724756412*^9, 3.431938730021414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ame", "[", "1", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "1"], "[", 
       RowBox[{
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SubscriptBox["A", "1"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}], "2"], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["A", "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox["A", "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["A", "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}]}], "}"}]}], "]"}], "/.", 
  "displayRule"}]], "Input",
 CellChangeTimes->{
  3.426942509444053*^9, {3.431938459845747*^9, 3.431938461050296*^9}, {
   3.431938558288744*^9, 3.431938561910417*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"\[Mu]", " ", 
    SubscriptBox["A", "1"]}], "2"], "+", 
  RowBox[{
   SubsuperscriptBox["A", "1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "c"}], 
      RowBox[{"2", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["19", "24"], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      SubscriptBox["b", "1"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["A", "2"], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "-", 
  RowBox[{
   FractionBox["127", "15"], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["A", "1"], " ", 
   SubscriptBox["A", "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "2"]}]}]], "Output",
 CellChangeTimes->{3.426942520389801*^9, 3.431938462649708*^9, 
  3.431938562305906*^9, 3.431939465620606*^9, 3.436618407031842*^9, 
  3.436622160276214*^9, 3.436707553478181*^9, 3.436709418137533*^9, 
  3.436712208482036*^9, 3.468938039412212*^9, 3.468938471725924*^9, 
  3.468939603768267*^9, 3.469126277222127*^9, 3.469126434752149*^9, 
  3.469126879343988*^9, 3.489242057903015*^9, 3.489322359809241*^9, 
  3.500038456042568*^9, 3.532704807482773*^9, 3.532705396507081*^9, 
  3.53270616034481*^9, 3.532706413660706*^9, 3.5646814235239697`*^9, 
  3.564688280651306*^9, 3.564689560750065*^9, 3.564690629655077*^9, 
  3.564693020263133*^9, 3.5646932071649237`*^9, 3.5646949968394747`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ame", "[", "2", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "2"], "[", 
       RowBox[{
        SubscriptBox["T", "1"], ",", 
        SubscriptBox["T", "2"]}], "]"}], ",", 
      SuperscriptBox[
       RowBox[{
        SubscriptBox["A", "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], "2"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SubscriptBox["A", "1"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}], "2"], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["A", "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox["A", "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["A", "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox["A", "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "1"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SubscriptBox["A", "2"], "[", 
         RowBox[{
          SubscriptBox["T", "1"], ",", 
          SubscriptBox["T", "2"]}], "]"}], "2"], " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["A", "_"], "2"], "[", 
        RowBox[{
         SubscriptBox["T", "1"], ",", 
         SubscriptBox["T", "2"]}], "]"}]}]}], "}"}]}], "]"}], "/.", 
  "displayRule"}]], "Input",
 CellChangeTimes->{{3.426942509444053*^9, 3.426942517637142*^9}, {
  3.431938478720717*^9, 3.431938533127783*^9}, {3.500038490596476*^9, 
  3.500038494180174*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Nu]", "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Sigma]"}]}], ")"}], " ", 
   SubscriptBox["A", "2"]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["A", "1", "2"], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "-", 
  RowBox[{
   FractionBox["107", "60"], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["A", "1"], " ", 
   SubscriptBox["A", "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "1"]}], "+", 
  RowBox[{
   SubsuperscriptBox["A", "2", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]", " ", "c"}], 
      RowBox[{"4", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["12", "5"], " ", "\[ImaginaryI]", " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{"6", " ", 
      SubscriptBox["b", "2"], " ", 
      SubsuperscriptBox["\[Omega]", "1", "2"]}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["A", "_"], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.426942521250276*^9, 3.431938480755293*^9, {3.431938514301224*^9, 
   3.4319385337423*^9}, 3.431939465733227*^9, 3.436618412495045*^9, 
   3.436622161280341*^9, 3.436707553616363*^9, 3.436709418256091*^9, 
   3.436712208672198*^9, 3.468938043525165*^9, 3.468938471828288*^9, 
   3.468939603791795*^9, 3.469126279538875*^9, 3.469126434785234*^9, 
   3.469126879374698*^9, 3.489242058350713*^9, 3.489322362538131*^9, 
   3.500038456088236*^9, 3.500038495133546*^9, 3.532704809417939*^9, 
   3.5327053965468397`*^9, 3.532706160400483*^9, 3.5327064137167177`*^9, 
   3.5646814255997753`*^9, 3.5646882825152273`*^9, 3.5646895607904*^9, 
   3.564690629704184*^9, 3.564693020297556*^9, 3.56469320722103*^9, 
   3.56469499689592*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Polar form of the AME", "Section",
 CellChangeTimes->{{3.431938244974906*^9, 3.43193825218591*^9}, {
  3.431938302237283*^9, 3.431938305433413*^9}, {3.436618437235242*^9, 
  3.43661844301521*^9}}],

Cell["\<\
To come back to the true time t\
\>", "Text",
 CellChangeTimes->{{3.436622232873273*^9, 3.436622233732779*^9}, {
  3.564692690653891*^9, 3.5646926993975897`*^9}},
 FontColor->GrayLevel[0]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"traspRule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["A", "1"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], "->", 
     RowBox[{
      SubscriptBox["A", "1"], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], "->", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["A", "2"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], "->", 
     RowBox[{
      SubscriptBox["A", "2"], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "2"], "[", 
      RowBox[{
       SubscriptBox["T", "1"], ",", 
       SubscriptBox["T", "2"]}], "]"}], "->", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "2"], "[", "t", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.426490843634474*^9, 3.426490985061214*^9}, {
  3.426491242668414*^9, 3.426491251591239*^9}, {3.426491470104552*^9, 
  3.426491478084521*^9}, {3.436618566395912*^9, 3.436618595095142*^9}, {
  3.436618710456987*^9, 3.436618741416086*^9}, {3.43661919808697*^9, 
  3.43661924028669*^9}},
 FontColor->GrayLevel[0]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], "[", 
     RowBox[{
      SubscriptBox["T", "1"], ",", 
      SubscriptBox["T", "2"]}], "]"}], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "1"], "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "1"], "[", 
     RowBox[{
      SubscriptBox["T", "1"], ",", 
      SubscriptBox["T", "2"]}], "]"}], "\[Rule]", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "2"], "[", 
     RowBox[{
      SubscriptBox["T", "1"], ",", 
      SubscriptBox["T", "2"]}], "]"}], "\[Rule]", 
    RowBox[{
     SubscriptBox["A", "2"], "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "2"], "[", 
     RowBox[{
      SubscriptBox["T", "1"], ",", 
      SubscriptBox["T", "2"]}], "]"}], "\[Rule]", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "2"], "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.426491056834516*^9, 3.426491068428384*^9}, 
   3.426491276228075*^9, 3.426491492249236*^9, 3.426848720874006*^9, 
   3.426854892609153*^9, 3.426944171878498*^9, 3.427526606556544*^9, 
   3.430746448147942*^9, 3.430912330338752*^9, 3.431096472896158*^9, 
   3.431098380817234*^9, 3.431167331440614*^9, 3.435323069341932*^9, 
   3.435560703661115*^9, 3.435561231512179*^9, 3.436618611626498*^9, {
   3.436618723019219*^9, 3.436618741729192*^9}, 3.436619244000692*^9, 
   3.436622161414223*^9, 3.43670755371575*^9, 3.436709418453115*^9, 
   3.436712208829161*^9, 3.468938057040958*^9, 3.468938471927224*^9, 
   3.468939603814195*^9, 3.469126434915798*^9, 3.4691268794022*^9, 
   3.489242059047265*^9, 3.500038518043396*^9, 3.532704826552602*^9, 
   3.532705396582365*^9, 3.532706160450923*^9, 3.532706413808428*^9, 
   3.5646815190586777`*^9, 3.564688301366819*^9, 3.564689560874926*^9, 
   3.5646906297531643`*^9, 3.564693020322021*^9, 3.5646932072907248`*^9, 
   3.564695023131781*^9},
 FontColor->GrayLevel[0]]
}, Open  ]],

Cell["Rewriting of the AME", "Text",
 CellChangeTimes->{{3.436622268767166*^9, 3.436622272687126*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amem", "[", "1", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ame", "[", "1", "]"}], "/.", "traspRule"}], ")"}], "-", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], "'"}], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.436618617205016*^9, 3.436618637634306*^9}, {
  3.436618727475799*^9, 3.436618757470245*^9}, {3.436619249314138*^9, 
  3.436619312799393*^9}, {3.436619507112686*^9, 3.436619534911646*^9}, {
  3.436619594208297*^9, 3.436619597575817*^9}, {3.436619643066755*^9, 
  3.436619647765481*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "\[Mu]", " ", 
   RowBox[{
    SubscriptBox["A", "1"], "[", "t", "]"}]}], "+", 
  FractionBox[
   RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
    SuperscriptBox[
     RowBox[{
      SubscriptBox["A", "1"], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], 
   RowBox[{"2", " ", 
    SubscriptBox["\[Omega]", "1"]}]], "-", 
  RowBox[{
   FractionBox["19", "24"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SuperscriptBox[
    RowBox[{
     SubscriptBox["A", "1"], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SubscriptBox["A", "1"], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"], " ", 
   RowBox[{
    SubscriptBox["A", "2"], "[", "t", "]"}], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["127", "15"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   RowBox[{
    SubscriptBox["A", "1"], "[", "t", "]"}], " ", 
   RowBox[{
    SubscriptBox["A", "2"], "[", "t", "]"}], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "2"], "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox[
    SubscriptBox["A", "1"], "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.436618624119787*^9, 3.436618638417759*^9}, {
   3.436618723973964*^9, 3.436618758024305*^9}, {3.436619245610537*^9, 
   3.436619263904029*^9}, {3.436619302603197*^9, 3.436619314663416*^9}, {
   3.436619508227217*^9, 3.436619536028203*^9}, 3.436619599055318*^9, 
   3.43661965872014*^9, 3.436622162015237*^9, 3.436707553808666*^9, 
   3.43670941856284*^9, 3.436712209009348*^9, 3.468938059582158*^9, 
   3.468938472093197*^9, 3.468939604298699*^9, 3.469126434947475*^9, 
   3.469126879633716*^9, 3.489242059549571*^9, 3.500038519045404*^9, 
   3.5327048294509697`*^9, 3.5327053966163073`*^9, 3.532706160502035*^9, 
   3.532706413854751*^9, 3.564681519202263*^9, 3.564688301419445*^9, 
   3.564689560921671*^9, 3.56469062976056*^9, 3.564693020346858*^9, 
   3.564693207341494*^9, 3.564695023282341*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amem", "[", "2", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ame", "[", "2", "]"}], "/.", "traspRule"}], ")"}], "-", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "2"], "'"}], "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.436618617205016*^9, 3.436618637634306*^9}, {
  3.436618727475799*^9, 3.436618757470245*^9}, {3.436619249314138*^9, 
  3.436619312799393*^9}, {3.436619507112686*^9, 3.436619534911646*^9}, {
  3.436619594208297*^9, 3.436619611363928*^9}, {3.436619654695127*^9, 
  3.436619657177056*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["b", "0"], " ", 
     SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SubscriptBox["A", "1"], "[", "t", "]"}], "2"]}], 
    RowBox[{"2", " ", 
     SubscriptBox["\[Omega]", "2"]}]]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[Nu]", " ", 
   RowBox[{
    SubscriptBox["A", "2"], "[", "t", "]"}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", "\[Sigma]", " ", 
   RowBox[{
    SubscriptBox["A", "2"], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["107", "60"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   RowBox[{
    SubscriptBox["A", "1"], "[", "t", "]"}], " ", 
   RowBox[{
    SubscriptBox["A", "2"], "[", "t", "]"}], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "1"], "[", "t", "]"}]}], "+", 
  FractionBox[
   RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
    SuperscriptBox[
     RowBox[{
      SubscriptBox["A", "2"], "[", "t", "]"}], "2"], " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "2"], "[", "t", "]"}]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "1"]}]], "-", 
  RowBox[{
   FractionBox["12", "5"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"], " ", 
   SuperscriptBox[
    RowBox[{
     SubscriptBox["A", "2"], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "2"], "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SubscriptBox["A", "2"], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["A", "_"], "2"], "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox[
    SubscriptBox["A", "2"], "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.436619612265745*^9, 3.436619659705381*^9, 
  3.436622162144716*^9, 3.436707553934755*^9, 3.436709418737555*^9, 
  3.436712209392946*^9, 3.468938062701406*^9, 3.46893847222555*^9, 
  3.468939604319161*^9, 3.46912643497652*^9, 3.469126879662962*^9, 
  3.489242060674499*^9, 3.500038519087608*^9, 3.532704831005466*^9, 
  3.532705396650419*^9, 3.532706160561411*^9, 3.532706413896447*^9, 
  3.564681519210717*^9, 3.564688301426681*^9, 3.5646895609617977`*^9, 
  3.564690629768529*^9, 3.564693020370874*^9, 3.564693207486734*^9, 
  3.56469502329138*^9}]
}, Open  ]],

Cell["Polar form of the complex amplitudes", "Text",
 CellChangeTimes->{{3.436620129896754*^9, 3.436620157924276*^9}, {
  3.436620224016758*^9, 3.436620231827214*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"polRule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["A", "1"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["A", "2"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox[
       OverscriptBox["A", "_"], "2"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]]}]}]}], "}"}]}]], "Input",\

 CellChangeTimes->{{3.402202879996776*^9, 3.4022029557215137`*^9}, {
  3.403014879431682*^9, 3.40301488115911*^9}, {3.436619700859584*^9, 
  3.436619868116977*^9}, {3.436620074043967*^9, 3.43662008242586*^9}, {
  3.436620175592699*^9, 3.436620177953277*^9}, {3.436620903053209*^9, 
  3.436620929893393*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
     RowBox[{"a1", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "2"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
     RowBox[{"a2", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "1"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
     RowBox[{"a1", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "2"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
     RowBox[{"a2", "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0n1MzHEcB/ATOVsedn4e6qqpo6xGroQSra+YSte1RLlOTx5qJjmS8lR0
0QPdabsel9bmsJJoTQ9TIVkrq8tTTziE+qZE6IHI++uPz15/fT6ffT57W4ZH
++2bxuPxDqPaN7oPrtpFSYAPf48YLro2ec4RPtszlS6UUZIY7vKWGdv5ZIsp
7C//6+8Ai7cJnjlB2fQMV2fo116+bjeUi4Mj7kHzDQOVb4Io+SLub54rp8Qi
v8VFBpXHHpaFwPXZY00LIyjJ65kYZt56e9vYGJ6yGzpjBoukyZZLYN0re2nx
QUquS8YzmZnZTeoSuK5Bf5uZorYZZGbVcXGl0NOjTzgSTUmaxY6w77C3StTK
nPmxZvY43KThCcwPUzJp1HeQyUsU37X8b4dMBLN+h18WKSi55Ov2nOmSb+dv
BVe2eetyoeG1DNW+o5RU+m96xxxV8V0vwZ+eUnNNDCX1Hl7aXDiuUsyshkcc
FaQBXvVZtkgPz9a3ZnyG3b0bnQahu5nUZE0sJZHadkEILKwdE6bBBVd3zh6G
B9o+UKPj6K+a8WE+zCqapV+egP/WqbJtYEbPRy9baCXTapk2XNQTpriwI8Qd
rn0ar2M+7urlb4YJPVw6M3Ly0XuqpGQsILbKKJkSk3lRaxaep8S0RqKshgUr
fL+9gV5Lj3LGFyjZLog76Qr1k/OLA2GbQZo8CZ4OzlMwUysKLjIVzZm/7FMo
cc67/8cRyl3Pa0Lh6oqOiVOp2C+aZVukQn72S21G4GtrEeetpqTLrWCaBFpE
x9w8BMv4ZR1BOZRI9o/r2+DWyB+WOni9r9PoRR7u5qKsmYlXZA7M7pfb1cy7
MdtsX0JxsdurKVg+J6yRl09Jn85BZACtWhIOxHdibj+/gFlnmG57AiqTQve+
gNErRvOZv2NuxK+eQt5Gh+xauAEyJihNMfEbIF+HNK3MAC1nJ4Sj8gcSZtzE
J6vFqgHiW3LnmBBqGi04UxiorMlh6hwvNpjBWPeRbma/mtaaw39AnctL
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"polRuleD", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"polRule", ",", 
    RowBox[{"D", "[", 
     RowBox[{"polRule", ",", "t"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.402202999851287*^9, 3.4022030233281317`*^9}, {
  3.43662018409652*^9, 3.43662019431144*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
     RowBox[{"a1", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "2"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
     RowBox[{"a2", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "1"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
     RowBox[{"a1", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["A", "_"], "2"], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
     RowBox[{"a2", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["A", "1"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
      RowBox[{
       SuperscriptBox["a1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox["A", "2"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
      RowBox[{
       SuperscriptBox["a2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["A", "_"], "1"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
      RowBox[{
       SuperscriptBox["a1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      SubscriptBox[
       OverscriptBox["A", "_"], "2"], "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
      RowBox[{
       SuperscriptBox["a2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.402203010272373*^9, 3.402203024267536*^9}, 
   3.402203928510666*^9, 3.402212376029849*^9, 3.402683488083468*^9, 
   3.4026841620325203`*^9, 3.402684974552781*^9, 3.4027322001549063`*^9, 
   3.402745496734323*^9, 3.402746356639567*^9, 3.402820029851377*^9, 
   3.4030149710781603`*^9, 3.403609535538419*^9, 3.40370799149554*^9, 
   3.403862494629039*^9, 3.403873662309606*^9, 3.4094894843492203`*^9, 
   3.4094897919301195`*^9, 3.4094942136504655`*^9, 3.4095032235017624`*^9, 
   3.4095086202694798`*^9, 3.412415097944278*^9, 3.4124156399525*^9, 
   3.412417670415811*^9, 3.412417927190172*^9, 3.412418401560819*^9, 
   3.412421569747104*^9, 3.414134999290336*^9, 3.414137610838929*^9, 
   3.414138481118768*^9, 3.41414717395805*^9, 3.414222984056635*^9, 
   3.4142237192520742`*^9, 3.41423249759375*^9, 3.4142338148125*^9, 
   3.414758539292409*^9, 3.414759074083416*^9, 3.414764193496353*^9, 
   3.415002754474527*^9, 3.415944316665611*^9, 3.415944970156716*^9, 
   3.41602558435424*^9, 3.416565994723325*^9, 3.416575274423576*^9, 
   3.416639539648882*^9, 3.4166604915962267`*^9, 3.416717489227337*^9, 
   3.416743030708917*^9, 3.416744386024161*^9, 3.417417930720802*^9, 
   3.417503886641291*^9, 3.41759202397155*^9, 3.417798754795785*^9, 
   3.417857871239018*^9, 3.417872160284414*^9, 3.422109432347723*^9, 
   3.422112956575088*^9, 3.42211439133177*^9, 3.422115117204156*^9, 
   3.42211542753918*^9, 3.422165758895398*^9, 3.4221666599240904`*^9, 
   3.422167103254114*^9, 3.4221681527465124`*^9, 3.425128214303617*^9, 
   3.425197507883065*^9, 3.425741227485804*^9, 3.426077730586629*^9, 
   3.4261543787075815`*^9, 3.4262713877708983`*^9, 3.426350044382009*^9, 
   3.426403664697416*^9, 3.426491113623623*^9, 3.426491277236423*^9, 
   3.426491493458725*^9, 3.426848726378145*^9, 3.426854894706496*^9, 
   3.426944172533972*^9, 3.42752660683572*^9, 3.430746448328685*^9, 
   3.430912330553858*^9, 3.431096473319611*^9, 3.43109838096864*^9, 
   3.431167331773661*^9, 3.435323069536979*^9, 3.435560703832331*^9, 
   3.435561231752121*^9, 3.43661988407746*^9, 3.4366200860398*^9, 
   3.436620194883597*^9, 3.436620931550534*^9, 3.436622162566809*^9, 
   3.436707554200435*^9, 3.436709419217064*^9, 3.436712209760312*^9, 
   3.468938070201562*^9, 3.46893847234707*^9, 3.468939604548976*^9, 
   3.469126435051872*^9, 3.469126879926612*^9, 3.489242062063889*^9, 
   3.500038519481739*^9, 3.532704838736087*^9, 3.532705396721717*^9, 
   3.532706160663794*^9, 3.532706414105845*^9, 3.564681519250945*^9, 
   3.564688301588665*^9, 3.564689561065041*^9, 3.5646906299271*^9, 
   3.564693020407362*^9, 3.564693207632863*^9, 3.56469502334615*^9}]
}, Open  ]],

Cell["Substitution of the complex amplitudes with the polar form", "Text",
 CellChangeTimes->{{3.436620129896754*^9, 3.436620157924276*^9}, {
  3.436620932361229*^9, 3.436620934681111*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "[", "1", "]"}], "=", 
  RowBox[{
   RowBox[{"amem", "[", "1", "]"}], "/.", "polRuleD"}]}]], "Input",
 CellChangeTimes->{{3.402203048073661*^9, 3.4022030573119793`*^9}, {
   3.436619911247679*^9, 3.436619940227935*^9}, 3.436620200695182*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", "\[Mu]", " ", 
   RowBox[{"a1", "[", "t", "]"}]}], "+", 
  FractionBox[
   RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"a1", "[", "t", "]"}], "3"]}], 
   RowBox[{"16", " ", 
    SubscriptBox["\[Omega]", "1"]}]], "-", 
  RowBox[{
   FractionBox["19", "192"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   FractionBox["127", "120"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   FractionBox["3", "16"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]}]], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
   RowBox[{
    SuperscriptBox["a1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.402203068298644*^9, 3.402203276751607*^9, 3.402203928639114*^9, 
   3.402212376082954*^9, 3.402683488175259*^9, 3.4026841621213818`*^9, 
   3.402684974625042*^9, 3.4027322002846737`*^9, 3.402745496788045*^9, 
   3.402746356759693*^9, 3.402820029926194*^9, 3.403014971154327*^9, 
   3.40360953560942*^9, 3.403707991597881*^9, 3.403862494728248*^9, 
   3.403873662373867*^9, 3.4094894851177254`*^9, 3.4094897919906626`*^9, 
   3.409494213774481*^9, 3.4095032235427756`*^9, 3.409508620366153*^9, 
   3.412415098166522*^9, 3.412415640110525*^9, 3.412417670430022*^9, 
   3.41241792728028*^9, 3.412418401661252*^9, 3.412421569812637*^9, 
   3.414134999306941*^9, 3.41413761093846*^9, 3.414138481197647*^9, 
   3.414147173975775*^9, 3.414222984140218*^9, 3.414223719335787*^9, 
   3.414232497640625*^9, 3.41423381484375*^9, 3.414758539360848*^9, 
   3.414759074099231*^9, 3.414764193512591*^9, 3.415002754528674*^9, 
   3.415944316682424*^9, 3.415944970219376*^9, 3.416025584446341*^9, 
   3.416565994740449*^9, 3.416575274441485*^9, 3.416639539729479*^9, 
   3.41666049161164*^9, 3.416717489241271*^9, 3.416743030782284*^9, 
   3.416744386040696*^9, 3.417417930748594*^9, 3.417503886660429*^9, 
   3.417592024038581*^9, 3.417798754859758*^9, 3.417857871335183*^9, 
   3.417872160355747*^9, 3.422109432364794*^9, 3.422112956592133*^9, 
   3.422114391377358*^9, 3.422115117278544*^9, 3.422115427604071*^9, 
   3.422165758954965*^9, 3.4221666599817038`*^9, 3.4221671033234453`*^9, 
   3.422168152806079*^9, 3.4251282144102373`*^9, 3.425197507900219*^9, 
   3.425741227499564*^9, 3.426077730600718*^9, 3.4261543787710543`*^9, 
   3.4262713878353477`*^9, 3.426350044590392*^9, 3.426403664793908*^9, 
   3.426491114775677*^9, 3.426491277356599*^9, 3.426491493857183*^9, 
   3.42684872727907*^9, 3.426854894879419*^9, 3.426944172684347*^9, 
   3.427526606892298*^9, 3.430746448341614*^9, 3.430912330567152*^9, 
   3.431096473465397*^9, 3.431098380981112*^9, 3.431167331833177*^9, 
   3.435323069590293*^9, 3.435560703887847*^9, 3.43556123180391*^9, 
   3.436619995776734*^9, 3.436620087599153*^9, {3.436620208015785*^9, 
   3.436620235085567*^9}, 3.436620936340655*^9, 3.436622163043717*^9, 
   3.436707554319339*^9, 3.436709419385228*^9, 3.436712209893466*^9, 
   3.468938072256114*^9, 3.468938472496391*^9, 3.468939604579407*^9, 
   3.469126435174821*^9, 3.469126879959723*^9, 3.489242062639126*^9, 
   3.500038519532088*^9, 3.532704840509221*^9, 3.532705396768052*^9, 
   3.532706160714841*^9, 3.532706414166621*^9, 3.564681519286262*^9, 
   3.564688301599533*^9, 3.5646895611452007`*^9, 3.5646906300661907`*^9, 
   3.564693020432213*^9, 3.564693207691193*^9, 3.5646950233943768`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "[", "2", "]"}], "=", 
  RowBox[{
   RowBox[{"amem", "[", "2", "]"}], "/.", "polRuleD"}]}]], "Input",
 CellChangeTimes->{{3.402203048073661*^9, 3.4022030640479794`*^9}, {
  3.436619915661211*^9, 3.436619943824866*^9}, {3.436620201954762*^9, 
  3.436620204249854*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", "\[Nu]", " ", 
   RowBox[{"a2", "[", "t", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", "\[Sigma]", " ", 
   RowBox[{"a2", "[", "t", "]"}]}], "+", 
  FractionBox[
   RowBox[{"3", " ", "\[ImaginaryI]", " ", "c", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"a2", "[", "t", "]"}], "3"]}], 
   RowBox[{"32", " ", 
    SubscriptBox["\[Omega]", "1"]}]], "-", 
  RowBox[{
   FractionBox["107", "480"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   FractionBox["3", "10"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   SubsuperscriptBox["b", "0", "2"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"8", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
   RowBox[{
    SuperscriptBox["a2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyTheta]2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.4022030701672697`*^9, 3.402203277969445*^9, 3.402203928781639*^9, 
   3.402212376149685*^9, 3.40268348822799*^9, 3.4026841622131724`*^9, 
   3.4026849746963263`*^9, 3.4027322003997383`*^9, 3.402745496841255*^9, 
   3.4027463568733397`*^9, 3.402820030045104*^9, 3.4030149712334237`*^9, 
   3.403609535678925*^9, 3.403707991714997*^9, 3.40386249482543*^9, 
   3.403873662473669*^9, 3.409489486050283*^9, 3.4094897920512056`*^9, 
   3.4094942138809195`*^9, 3.4095032235837884`*^9, 3.4095086204140015`*^9, 
   3.412415098237814*^9, 3.412415640211785*^9, 3.41241767044437*^9, 
   3.412417927373669*^9, 3.412418401675522*^9, 3.412421569829997*^9, 
   3.414134999353089*^9, 3.41413761095478*^9, 3.414138481212517*^9, 
   3.414147173994119*^9, 3.4142229841581593`*^9, 3.414223719351535*^9, 
   3.414232497703125*^9, 3.414233814875*^9, 3.414758539378127*^9, 
   3.414759074115083*^9, 3.414764193571452*^9, 3.415002754543639*^9, 
   3.415944316701062*^9, 3.415944970235017*^9, 3.416025584464583*^9, 
   3.416565994806758*^9, 3.416575274459507*^9, 3.416639539745885*^9, 
   3.416660491750182*^9, 3.4167174892551403`*^9, 3.416743030851339*^9, 
   3.416744386056834*^9, 3.417417930813587*^9, 3.417503886679319*^9, 
   3.417592024058374*^9, 3.417798754878912*^9, 3.417857871400235*^9, 
   3.417872160471491*^9, 3.422109432381856*^9, 3.422112956609018*^9, 
   3.422114391433008*^9, 3.422115117298118*^9, 3.422115427670234*^9, 
   3.4221657590047665`*^9, 3.422166660042247*^9, 3.4221671033908243`*^9, 
   3.4221681528627157`*^9, 3.425128214518526*^9, 3.425197507917514*^9, 
   3.425741227558801*^9, 3.42607773061472*^9, 3.4261543788364797`*^9, 
   3.426271387905656*^9, 3.426350044697374*^9, 3.426403664894283*^9, 
   3.426491115795658*^9, 3.426491277583563*^9, 3.426491494053124*^9, 
   3.426848744580226*^9, 3.426854895032413*^9, 3.426944172800081*^9, 
   3.427526606948582*^9, 3.430746448401502*^9, 3.430912330622193*^9, 
   3.431096473627816*^9, 3.431098381020513*^9, 3.431167331894586*^9, 
   3.435323069604339*^9, 3.435560703900182*^9, 3.43556123181667*^9, 
   3.436619999201996*^9, 3.436620088659107*^9, {3.436620208874427*^9, 
   3.436620235787332*^9}, 3.436620937261935*^9, 3.436622163261049*^9, 
   3.436707554438744*^9, 3.436709419483186*^9, 3.436712210027205*^9, 
   3.468938075142445*^9, 3.468938472520691*^9, 3.468939604606639*^9, 
   3.469126435206978*^9, 3.469126879991732*^9, 3.489242063781262*^9, 
   3.500038519844605*^9, 3.532704841676141*^9, 3.532705396812182*^9, 
   3.532706160766183*^9, 3.532706414226695*^9, 3.564681519324155*^9, 
   3.564688301649083*^9, 3.564689561217206*^9, 3.564690630075107*^9, 
   3.564693020440134*^9, 3.564693207744528*^9, 3.564695023403842*^9}]
}, Open  ]],

Cell["\<\
Autonomous equations and separations of the real and imaginary parts\
\>", "Text",
 CellChangeTimes->{{3.436620674539189*^9, 3.436620701090837*^9}, {
  3.436620988968196*^9, 3.436621003555728*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexExpand", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"eq", "[", "1", "]"}], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.564693124160666*^9, 3.564693131206956*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", "\[Mu]", " ", 
   RowBox[{"a1", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "16"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c", " ", 
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "3"]}], 
      RowBox[{"16", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["19", "192"], " ", 
      SuperscriptBox[
       RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      FractionBox["127", "120"], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.5646931195691633`*^9, 3.564693131880045*^9}, 
   3.564693207820662*^9, 3.564695023451222*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqa", "[", "1", "]"}], "=", 
  RowBox[{"ComplexExpand", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"eq", "[", "1", "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}]]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.426409068040957*^9, 3.426409078315087*^9}, {
  3.426409201012861*^9, 3.426409202742518*^9}, {3.436620293622695*^9, 
  3.436620295428706*^9}, {3.436620710576008*^9, 3.436620748947751*^9}, {
  3.436620815592559*^9, 3.436620889296066*^9}, {3.436620942233261*^9, 
  3.436620943336986*^9}, {3.564693134840156*^9, 3.564693137695223*^9}, {
  3.5646931869548397`*^9, 3.564693187303644*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", "\[Mu]", " ", 
   RowBox[{"a1", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "16"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c", " ", 
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "3"]}], 
      RowBox[{"16", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["19", "192"], " ", 
      SuperscriptBox[
       RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      FractionBox["127", "120"], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
      SubscriptBox["b", "0"], " ", 
      SubscriptBox["\[Omega]", "2"]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"a1", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.436620890770397*^9, 3.436620943769538*^9, 
  3.436622163472599*^9, 3.436707554580701*^9, 3.436709419657994*^9, 
  3.43671221019633*^9, 3.468938076882218*^9, 3.468938472580033*^9, 
  3.468939604667069*^9, 3.469126435396923*^9, 3.469126880256125*^9, 
  3.489242064421871*^9, 3.50003852019294*^9, 3.532704844063994*^9, 
  3.532705396874321*^9, 3.532706160895954*^9, 3.532706414302125*^9, 
  3.564681520804027*^9, 3.564688301702908*^9, 3.56468956128511*^9, 
  3.564690630110475*^9, 3.5646930204953413`*^9, 3.564693207890357*^9, 
  3.564695023497444*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqa", "[", "2", "]"}], "=", 
  RowBox[{"ComplexExpand", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"eq", "[", "2", "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.436620955073112*^9, 3.436620965395225*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "4"], " ", "\[Nu]", " ", 
   RowBox[{"a2", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
      RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"8", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "\[Sigma]", " ", 
      RowBox[{"a2", "[", "t", "]"}]}], "+", 
     FractionBox[
      RowBox[{"3", " ", "c", " ", 
       SuperscriptBox[
        RowBox[{"a2", "[", "t", "]"}], "3"]}], 
      RowBox[{"32", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["107", "480"], " ", 
      SuperscriptBox[
       RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      FractionBox["3", "10"], " ", 
      SuperscriptBox[
       RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
         RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
       SubscriptBox["b", "0"], " ", 
       SubsuperscriptBox["\[Omega]", "1", "2"]}], 
      RowBox[{"8", " ", 
       SubscriptBox["\[Omega]", "2"]}]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyTheta]2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.436620966091561*^9, 3.436622163583775*^9, 
  3.436707554700066*^9, 3.436709419818201*^9, 3.436712210570921*^9, 
  3.468938080967169*^9, 3.468938472624108*^9, 3.468939604897269*^9, 
  3.469126435445427*^9, 3.469126880333789*^9, 3.489242065240761*^9, 
  3.500038520681035*^9, 3.5327048502997303`*^9, 3.532705396930068*^9, 
  3.532706160979087*^9, 3.5327064143626413`*^9, 3.564681520937854*^9, 
  3.564688301754631*^9, 3.564689561348549*^9, 3.564690630152676*^9, 
  3.564693020538094*^9, 3.564693207912775*^9, 3.564695023552718*^9}]
}, Open  ]],

Cell["\<\
Definition of \[CurlyPhi] (depending on the resonance condition)\
\>", "Text",
 CellChangeTimes->{{3.436621139575629*^9, 3.4366211435026*^9}, {
  3.564692725133171*^9, 3.564692738323265*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phiRule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "->", 
    RowBox[{"\[CurlyPhi]", "[", "t", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.436621060814314*^9, 3.43662110754473*^9}, {
  3.436621342546573*^9, 3.43662134281099*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
    RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "\[Rule]", 
   RowBox[{"\[CurlyPhi]", "[", "t", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.436621103117938*^9, 3.436621108248657*^9}, 
   3.436621343896047*^9, 3.436622163675598*^9, 3.436707554769043*^9, 
   3.436709420166297*^9, 3.436712210687213*^9, 3.468938086352319*^9, 
   3.46893847272551*^9, 3.468939604915722*^9, 3.469126435469792*^9, 
   3.469126880553527*^9, 3.489242065329093*^9, 3.500038520898063*^9, 
   3.53270485222013*^9, 3.532705396974391*^9, 3.532706161034081*^9, 
   3.532706414422423*^9, 3.5646815209764013`*^9, 3.564688301797173*^9, 
   3.564689561451047*^9, 3.564690630194578*^9, 3.564693020564538*^9, 
   3.5646932079291677`*^9, 3.5646950235991993`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phiRuleD", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CurlyTheta]2", "'"}], "[", "t", "]"}], "->", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"\[CurlyTheta]1", "'"}], "[", "t", "]"}]}], "-", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "'"}], "[", "t", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.436621060814314*^9, 3.43662110754473*^9}, {
  3.436621342546573*^9, 3.43662134281099*^9}, {3.436621553069361*^9, 
  3.436621630902978*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CurlyTheta]2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.436621559775754*^9, 3.436621600015207*^9, 
  3.436621631439951*^9, 3.436622164230526*^9, 3.436707554830176*^9, 
  3.436709420307222*^9, 3.436712210823707*^9, 3.468938087591101*^9, 
  3.468938472740937*^9, 3.468939604933873*^9, 3.469126435588643*^9, 
  3.469126880575515*^9, 3.489242065370095*^9, 3.500038520929166*^9, 
  3.532704852914063*^9, 3.532705396977828*^9, 3.5327061610518084`*^9, 
  3.532706414426218*^9, 3.564681520985797*^9, 3.564688301805786*^9, 
  3.564689561531686*^9, 3.564690630228701*^9, 3.564693020572857*^9, 
  3.5646932080323353`*^9, 3.564695023605397*^9}]
}, Open  ]],

Cell["Polar Amplitude Modulation Equations", "Text",
 CellChangeTimes->{{3.436621667855548*^9, 3.436621675409525*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amep", "[", "1", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"Re", "[", 
      RowBox[{"2", " ", 
       RowBox[{"eqa", "[", "1", "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       RowBox[{"a2", "[", "t", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022100987584057`*^9, 3.402210108308756*^9}, {
  3.402212316595549*^9, 3.4022123169941883`*^9}, {3.412416262943011*^9, 
  3.412416282352505*^9}, {3.412416774974301*^9, 3.412416775866172*^9}, {
  3.412417617389204*^9, 3.412417617689712*^9}, {3.414135570882179*^9, 
  3.41413557103164*^9}, {3.426944339484262*^9, 3.42694433966615*^9}, {
  3.436621166733484*^9, 3.436621238985397*^9}, {3.468938112627579*^9, 
  3.468938117026736*^9}, {3.532704867138217*^9, 3.532704884121711*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "\[Mu]", " ", 
   RowBox[{"a1", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "8"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["a1", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.412416283015412*^9, 3.412416821806568*^9, 3.412417689854166*^9, 
   3.412417932416847*^9, 3.412418406648827*^9, 3.412421573342473*^9, 
   3.414135607034031*^9, 3.414138486345531*^9, 3.414147179084407*^9, 
   3.414222992179082*^9, 3.414223725020575*^9, 3.4142325020625*^9, 
   3.4142338195625*^9, 3.414758544918347*^9, 3.414759078945646*^9, 
   3.414764198165712*^9, 3.415002759262765*^9, 3.415944323266595*^9, 
   3.415944974914075*^9, 3.41602558904081*^9, 3.416660514080572*^9, 
   3.416717506711254*^9, 3.41674304996391*^9, 3.416744403570876*^9, 
   3.417417953039098*^9, 3.417503903914387*^9, 3.41759204022638*^9, 
   3.417798773613913*^9, 3.417857890847779*^9, 3.417872177495402*^9, 
   3.42210945033659*^9, 3.422112976644072*^9, 3.422114407784677*^9, 
   3.422115134590084*^9, 3.422115446692017*^9, 3.422165780848095*^9, 
   3.4221666792851562`*^9, 3.4221671229540253`*^9, 3.422168171694518*^9, 
   3.425128286527762*^9, 3.425197528008176*^9, 3.425741242621484*^9, 
   3.426077744594826*^9, 3.4261543946440616`*^9, 3.426350067448919*^9, 
   3.426403674822978*^9, 3.426491139100973*^9, 3.426491297516635*^9, 
   3.426491512631507*^9, 3.42684876609424*^9, 3.426854904062136*^9, 
   3.426944315967558*^9, 3.42694437985068*^9, 3.427526612956412*^9, 
   3.430746450753034*^9, 3.431098383677435*^9, 3.435323074830615*^9, 
   3.435560708744511*^9, 3.435561235574947*^9, {3.436621183281914*^9, 
   3.436621193356792*^9}, 3.436621241164539*^9, 3.436621462230787*^9, 
   3.436622164405076*^9, 3.43670755493621*^9, 3.436709420447777*^9, 
   3.436712210970528*^9, {3.468938089477602*^9, 3.468938117861302*^9}, 
   3.468938472775905*^9, 3.468939604969404*^9, 3.469126435668811*^9, 
   3.469126880615069*^9, 3.489242066482069*^9, 3.500038521129704*^9, {
   3.532704873244575*^9, 3.532704884686593*^9}, 3.5327053970214653`*^9, 
   3.532706161111682*^9, 3.532706414486105*^9, 3.564681521021495*^9, 
   3.5646883018471413`*^9, 3.564689562405888*^9, 3.5646906302657013`*^9, 
   3.564693020599558*^9, 3.564693208091153*^9, 3.56469502365309*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amep", "[", "2", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"Re", "[", 
      RowBox[{"2", " ", 
       RowBox[{"eqa", "[", "2", "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       RowBox[{"a2", "[", "t", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022100987584057`*^9, 3.402210108308756*^9}, {
   3.402212316595549*^9, 3.4022123169941883`*^9}, {3.412416262943011*^9, 
   3.412416282352505*^9}, {3.412416774974301*^9, 3.412416775866172*^9}, {
   3.412417617389204*^9, 3.412417617689712*^9}, {3.414135570882179*^9, 
   3.41413557103164*^9}, {3.426944339484262*^9, 3.42694433966615*^9}, {
   3.436621166733484*^9, 3.436621238985397*^9}, {3.43662129035534*^9, 
   3.436621293960829*^9}, {3.436621450545782*^9, 3.436621451789484*^9}, 
   3.468938130653416*^9, {3.5327049017693768`*^9, 3.532704917907922*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "\[Nu]", " ", 
   RowBox[{"a2", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
      RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "-", 
  RowBox[{
   SuperscriptBox["a2", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.436621296861449*^9, 3.43662146346362*^9, 
  3.436622164583531*^9, 3.436707555039897*^9, 3.436709420591192*^9, 
  3.436712211115013*^9, 3.468938093621018*^9, 3.468938131823959*^9, 
  3.468938472818482*^9, 3.468939605206336*^9, 3.469126435805748*^9, 
  3.469126880850875*^9, 3.489242067142476*^9, 3.5000385213772*^9, 
  3.532704919202764*^9, 3.532705397114093*^9, 3.532706161174399*^9, 
  3.532706414558936*^9, 3.5646815210606956`*^9, 3.564688301891053*^9, 
  3.564689563446857*^9, 3.564690630303804*^9, 3.564693020641873*^9, 
  3.5646932081689577`*^9, 3.5646950236990767`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amep", "[", "3", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"Im", "[", 
      RowBox[{"2", " ", 
       RowBox[{"eqa", "[", "1", "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       RowBox[{"a2", "[", "t", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022100987584057`*^9, 3.402210108308756*^9}, {
   3.402210256739339*^9, 3.402210256827496*^9}, {3.402210357777293*^9, 
   3.4022103590171347`*^9}, {3.40221232000497*^9, 3.4022123209118156`*^9}, {
   3.412416288385836*^9, 3.412416297631829*^9}, {3.412416779973189*^9, 
   3.412416782885601*^9}, {3.41241761913783*^9, 3.412417619396356*^9}, {
   3.414135572600542*^9, 3.414135577111132*^9}, {3.426944341778721*^9, 
   3.42694434352878*^9}, {3.436621257739624*^9, 3.436621272654007*^9}, 
   3.43662145298974*^9, 3.468938144582135*^9, {3.53270493149787*^9, 
   3.532704959472052*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c"}], 
      RowBox[{"8", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["19", "96"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["127", "60"]}], " ", 
      SuperscriptBox[
       RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{
      SuperscriptBox["\[CurlyTheta]1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->CompressedData["
1:eJwdxWlI02EcAOC/FZVaQxxTW5uwSYqTtNJS11J/aPsQDmQYs9SyMXOkQ0XN
o8PSZabZNhvNG2LJVjLCCiGGQq0DNKd4xMrKAxXeORAy0zRYv7cPD49AWSzP
92EYJhN9n5MvPysiMBY4Ed6Hcz6kPKRrF1r76VOJXzz0oWRblQ0vXF2+/LOY
gHJp1LmGi2dU+zfx2hS/QH4JAavJrKEzjGNA8P+ybCGesShoFZYS2Iqbm6Kr
oz9mHsLlCvd4O16luaLPLyPwRz07T1fWmZNa6DnSNEc5geTScyGzuLkn1bCC
DzVWiD14giGMd/wqAV6Jl30R32vz5Tfh1QEDrFV8PTTX419J4OWTI8uBePyr
9PmIWgI7x4I6IvHbudvpIjygaNpCF9hcTro+qluZiv+OWJmgn/Xm+aXhFYaq
FvqFSMZDtAQKmqPs/ncIDAcr4jkNBEL/Jja8xkMkWWs/8AyW7WbSXQKjsoK+
LJzcmr9Uj0uCTpTTzzRxdfTt4TfMsUYC/Td2eeNwy1GtJQ/PSDU+p8cYzVvX
7xHo1GeLHusI3D+84SPTEzjdk+PKbiOg+No+N4arg8qE4/jTwTr7dAcBbrV4
kr5gN4k+4731qm9efFVqes90EqiUqIU78HczS5pqF4FfA+JyuuQTv5se67CK
anC+4ppqGh95wOuiZybU1cR6CWz4nIwZYbvh7e5t0wG5G6y8XiddXxgRzcV9
mydldPGpsPBgnRtYnKEKLi598Yh9ED+/ONxGd60bHTzcatkzQ9fu2xzk4/8A
9vlWiA==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amep", "[", "4", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{"Im", "[", 
      RowBox[{"2", " ", 
       RowBox[{"eqa", "[", "2", "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       RowBox[{"a2", "[", "t", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022100987584057`*^9, 3.402210108308756*^9}, {
   3.402210256739339*^9, 3.402210256827496*^9}, {3.402210357777293*^9, 
   3.4022103590171347`*^9}, {3.40221232000497*^9, 3.4022123209118156`*^9}, {
   3.412416288385836*^9, 3.412416297631829*^9}, {3.412416779973189*^9, 
   3.412416782885601*^9}, {3.41241761913783*^9, 3.412417619396356*^9}, {
   3.414135572600542*^9, 3.414135577111132*^9}, {3.426944341778721*^9, 
   3.42694434352878*^9}, {3.436621257739624*^9, 3.436621294913405*^9}, 
   3.468938156505759*^9, {3.5327049647680883`*^9, 3.532704974389184*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c"}], 
      RowBox[{"16", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "-", 
     RowBox[{
      FractionBox["3", "5"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["107", "240"]}], " ", 
      RowBox[{"a2", "[", "t", "]"}], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "-", 
         RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
       SubscriptBox["b", "0"], " ", 
       SubsuperscriptBox["\[Omega]", "1", "2"]}], 
      RowBox[{"4", " ", 
       SubscriptBox["\[Omega]", "2"]}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Sigma]", "-", 
     RowBox[{
      SuperscriptBox["\[CurlyTheta]2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.436621297591411*^9, 3.436621466931075*^9, 
  3.436622165196866*^9, 3.436707555379577*^9, 3.436709420867563*^9, 
  3.436712211583414*^9, 3.468938102031767*^9, 3.468938157783628*^9, 
  3.468938472970893*^9, 3.468939605493361*^9, 3.469126435898387*^9, 
  3.469126880933883*^9, 3.489242068812039*^9, 3.500038522098291*^9, 
  3.532704974774045*^9, 3.532705397213377*^9, 3.532706161291284*^9, 
  3.5327064146528893`*^9, 3.5646815211440763`*^9, 3.564688301988367*^9, 
  3.564689565096818*^9, 3.564690630374309*^9, 3.564693020661189*^9, 
  3.564693208302888*^9, 3.564695023803327*^9}]
}, Open  ]],

Cell["Reduced Amplitude Modulation Equations", "Text",
 CellChangeTimes->{{3.436621667855548*^9, 3.436621685751375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rame", "[", "1", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"amep", "[", "1", "]"}], "/.", "phiRule"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       RowBox[{"a2", "[", "t", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022100987584057`*^9, 3.402210108308756*^9}, {
  3.402210213732935*^9, 3.40221021742765*^9}, {3.402210371054392*^9, 
  3.402210371107463*^9}, {3.402212322953887*^9, 3.402212323728519*^9}, {
  3.412416294818538*^9, 3.412416319236002*^9}, {3.412416796783313*^9, 
  3.412416798366268*^9}, {3.412417620473468*^9, 3.412417620760667*^9}, {
  3.414135578272273*^9, 3.414135578427157*^9}, {3.426944344843121*^9, 
  3.426944345087182*^9}, {3.436621317092452*^9, 3.436621353740145*^9}, {
  3.436621389298492*^9, 3.43662139779999*^9}, {3.468938171116186*^9, 
  3.468938175761915*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "\[Mu]", " ", 
   RowBox[{"a1", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "8"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["a1", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.412416326629266*^9, 3.412416823373574*^9, 3.412417690185235*^9, 
   3.412417932756659*^9, 3.412418406897496*^9, 3.412421573487355*^9, 
   3.414135607620107*^9, 3.414138486514824*^9, 3.414147179212039*^9, 
   3.414222992552465*^9, 3.414223725216445*^9, 3.414232502140625*^9, 
   3.414233819640625*^9, 3.414758545136146*^9, 3.414759079222133*^9, 
   3.414764198285801*^9, 3.415002759381391*^9, 3.415944323386894*^9, 
   3.415944975048649*^9, 3.4160255891798773`*^9, 3.416660514231596*^9, 
   3.416717506894795*^9, 3.416743050276509*^9, 3.416744403767077*^9, 
   3.41741795318553*^9, 3.417503904009418*^9, 3.417592040369812*^9, 
   3.417798773767388*^9, 3.417857890972924*^9, 3.417872177592164*^9, 
   3.422109450455476*^9, 3.422112977237558*^9, 3.422114407924473*^9, 
   3.422115134745833*^9, 3.422115446848868*^9, 3.422165780980899*^9, 
   3.422166679412101*^9, 3.422167123102453*^9, 3.4221681718468523`*^9, 
   3.425128289726781*^9, 3.425197530167817*^9, 3.425741243009017*^9, 
   3.426077746764696*^9, 3.4261543948745155`*^9, 3.426350074220186*^9, 
   3.426403675347157*^9, 3.426491153464737*^9, 3.426491297835276*^9, 
   3.426491513022652*^9, 3.426848777371273*^9, 3.426854904219042*^9, 
   3.426944316300829*^9, 3.426944381368563*^9, 3.427526613313951*^9, 
   3.430746450978671*^9, 3.431098383770395*^9, 3.435323074952814*^9, 
   3.43556070887548*^9, 3.435561235660163*^9, 3.436621355015943*^9, {
   3.436621393221645*^9, 3.436621398285272*^9}, 3.436621474628199*^9, 
   3.436622165241767*^9, 3.436707555428627*^9, 3.436709421139493*^9, 
   3.436712211678149*^9, {3.468938162203789*^9, 3.46893817194761*^9}, 
   3.468938472990892*^9, 3.468939605514673*^9, 3.469126436031965*^9, 
   3.469126881168949*^9, 3.489242069778004*^9, 3.500038522133014*^9, 
   3.532705080419628*^9, 3.532705397257434*^9, 3.53270616133936*^9, 
   3.53270641469727*^9, 3.564681521177504*^9, 3.5646883020352583`*^9, 
   3.564689565558073*^9, 3.564690630408342*^9, 3.564693020687477*^9, 
   3.564693208378159*^9, 3.564695023850039*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rame", "[", "2", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"amep", "[", "2", "]"}], "/.", "phiRule"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       RowBox[{"a2", "[", "t", "]"}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4022100987584057`*^9, 3.402210108308756*^9}, {
  3.402210213732935*^9, 3.40221021742765*^9}, {3.402210371054392*^9, 
  3.402210371107463*^9}, {3.402212322953887*^9, 3.402212323728519*^9}, {
  3.412416294818538*^9, 3.412416319236002*^9}, {3.412416796783313*^9, 
  3.412416798366268*^9}, {3.412417620473468*^9, 3.412417620760667*^9}, {
  3.414135578272273*^9, 3.414135578427157*^9}, {3.426944344843121*^9, 
  3.426944345087182*^9}, {3.436621317092452*^9, 3.436621378716702*^9}, {
  3.436621442250029*^9, 3.436621473002329*^9}, {3.468938177620689*^9, 
  3.468938183829459*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "\[Nu]", " ", 
   RowBox[{"a2", "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "-", 
  RowBox[{
   SuperscriptBox["a2", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.436621379805983*^9, 3.436621444836007*^9, 
  3.436621475406078*^9, 3.436622165274587*^9, 3.436707555474088*^9, 
  3.43670942120383*^9, 3.436712211768749*^9, 3.468938184711363*^9, 
  3.468938473013146*^9, 3.468939605539684*^9, 3.469126436060617*^9, 
  3.469126881196638*^9, 3.489242069872519*^9, 3.500038522165671*^9, 
  3.532705090046114*^9, 3.532705397302253*^9, 3.532706161386734*^9, 
  3.532706414752276*^9, 3.56468152118503*^9, 3.5646883020744133`*^9, 
  3.564689565895548*^9, 3.5646906304156227`*^9, 3.564693020728938*^9, 
  3.564693208548707*^9, 3.56469502385686*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rame", "[", "3", "]"}], "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"a2", "[", "t", "]"}], 
          RowBox[{"amep", "[", "3", "]"}]}], "-", 
         RowBox[{
          RowBox[{"a1", "[", "t", "]"}], 
          RowBox[{"amep", "[", "4", "]"}]}]}], ")"}], "/.", "phiRule"}], "/.",
       "phiRuleD"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "[", "t", "]"}], ",", 
      RowBox[{"a2", "[", "t", "]"}], ",", 
      SuperscriptBox[
       RowBox[{"a1", "[", "t", "]"}], "3"], ",", 
      SuperscriptBox[
       RowBox[{"a2", "[", "t", "]"}], "3"], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "2"], 
       RowBox[{"a2", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       SuperscriptBox[
        RowBox[{"a2", "[", "t", "]"}], "2"]}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "3"], 
       RowBox[{"a2", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], 
       SuperscriptBox[
        RowBox[{"a2", "[", "t", "]"}], "3"]}], ",", 
      SubscriptBox["b", "0"], ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], ",", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.436621408746337*^9, 3.436621420389296*^9}, {
  3.436621485842045*^9, 3.436621520567405*^9}, {3.436621565920873*^9, 
  3.436621567399584*^9}, {3.43662165171012*^9, 3.43662165812937*^9}, {
  3.500038567806106*^9, 3.50003857491961*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a1", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "c"}], 
       RowBox[{"16", " ", 
        SubscriptBox["\[Omega]", "1"]}]]}], "-", 
     RowBox[{
      FractionBox["109", "30"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c"}], 
      RowBox[{"4", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "+", 
     RowBox[{
      FractionBox["1", "20"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"a1", "[", "t", "]"}], "3"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "+", 
  RowBox[{
   RowBox[{"a1", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Sigma]"}], "-", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.43662149790497*^9, 3.43662152107335*^9}, 
   3.436621568368391*^9, 3.436621607787533*^9, {3.43662164039695*^9, 
   3.436621658819079*^9}, 3.436622165408048*^9, 3.436707555520472*^9, 
   3.436709421342097*^9, 3.436712211892333*^9, 3.468938189804775*^9, 
   3.468938473120163*^9, 3.46893960576404*^9, 3.469126436093696*^9, 
   3.469126881226755*^9, 3.489242070348204*^9, 3.500038522199374*^9, 
   3.500038576714037*^9, 3.5327050913369207`*^9, 3.532705397347233*^9, 
   3.532706161434857*^9, 3.532706414808765*^9, 3.564681521216538*^9, 
   3.5646883021229467`*^9, 3.564689566278571*^9, 3.564690630448559*^9, 
   3.564693020791642*^9, 3.564693208655546*^9, 3.564695023902474*^9}]
}, Open  ]],

Cell["Rule to obtain equilibria", "Text",
 CellChangeTimes->{{3.41241684880821*^9, 3.412416851181118*^9}, {
  3.43662175763755*^9, 3.436621760362171*^9}, {3.436622339189991*^9, 
  3.436622344027241*^9}, {3.564692763459413*^9, 3.5646927780176764`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fixRule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "[", "t", "]"}], "->", "a1"}], ",", 
    RowBox[{
     RowBox[{"a2", "[", "t", "]"}], "->", "a2"}], ",", 
    RowBox[{
     RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "->", "\[CurlyPhi]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.436622389405782*^9, 3.436622412757191*^9}, {
  3.436622449593359*^9, 3.436622456725383*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a1", "[", "t", "]"}], "\[Rule]", "a1"}], ",", 
   RowBox[{
    RowBox[{"a2", "[", "t", "]"}], "\[Rule]", "a2"}], ",", 
   RowBox[{
    RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "\[Rule]", "\[CurlyPhi]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.436622413618651*^9, 3.436622457426867*^9, 
  3.436707555596229*^9, 3.436709421402105*^9, 3.436712211978794*^9, 
  3.468938197856329*^9, 3.468938473136537*^9, 3.468939605779137*^9, 
  3.469126436208979*^9, 3.469126881496282*^9, 3.489242071043767*^9, 
  3.500038522560532*^9, 3.532705096046451*^9, 3.532705397391309*^9, 
  3.532706161439702*^9, 3.5327064148672867`*^9, 3.5646815212590513`*^9, 
  3.564688302164208*^9, 3.564689566288995*^9, 3.564690630483721*^9, 
  3.564693020982428*^9, 3.564693208666198*^9, 3.5646950239505873`*^9}]
}, Open  ]],

Cell["Equations to find equilibria", "Text",
 CellChangeTimes->{{3.41241684880821*^9, 3.412416851181118*^9}, {
  3.43662175763755*^9, 3.436621760362171*^9}, {3.436622339189991*^9, 
  3.436622344027241*^9}, {3.564692813221426*^9, 3.56469281597641*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fix", "[", "1", "]"}], "=", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"rame", "[", "1", "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"a1", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"a2", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"\[CurlyPhi]", "'"}], "[", "t", "]"}], "\[Rule]", "0"}]}],
          "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], ",", 
       RowBox[{"a2", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], 
        RowBox[{"a2", "[", "t", "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "3"], ",", 
       SuperscriptBox[
        RowBox[{"a2", "[", "t", "]"}], "3"], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a1", "[", "t", "]"}], "2"], 
        RowBox[{"a2", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], 
        SuperscriptBox[
         RowBox[{"a2", "[", "t", "]"}], "2"]}]}], "}"}]}], "]"}], "/.", 
   "fixRule"}]}]], "Input",
 CellChangeTimes->{{3.412416860101929*^9, 3.412416893347879*^9}, {
  3.412417636674036*^9, 3.412417636969024*^9}, {3.4251974550078583`*^9, 
  3.42519746473699*^9}, {3.426077899038585*^9, 3.426077923131429*^9}, {
  3.426403769031065*^9, 3.426403845339056*^9}, {3.426944360052837*^9, 
  3.42694436035072*^9}, {3.426944404464315*^9, 3.426944417180202*^9}, {
  3.43662178220989*^9, 3.436621792591711*^9}, {3.43662183688895*^9, 
  3.436621838032804*^9}, {3.436622418552773*^9, 3.436622420810661*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a1", " ", "\[Mu]"}], "2"], "-", 
  RowBox[{
   FractionBox["3", "8"], " ", 
   SuperscriptBox["a1", "3"], " ", 
   SubscriptBox["b", "1"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", "a1", " ", "a2", " ", 
   RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.412416894986884*^9, 3.412417691378105*^9, 3.412417933944885*^9, 
   3.41241840771632*^9, 3.412421573690788*^9, 3.414135609034617*^9, 
   3.414138486884346*^9, 3.41414717945407*^9, 3.414222993121348*^9, 
   3.41422372552423*^9, 3.414232502375*^9, 3.414233819875*^9, 
   3.414758545408348*^9, 3.414759079456228*^9, 3.41476419849147*^9, 
   3.415002759606266*^9, 3.4159443236913*^9, 3.415944975357353*^9, 
   3.41602558944776*^9, 3.416660514622374*^9, 3.416717507127604*^9, 
   3.416743050965689*^9, 3.416744404105163*^9, 3.417417953520002*^9, 
   3.417503906204225*^9, 3.417592040640507*^9, 3.417798774151804*^9, 
   3.417857891289836*^9, 3.417872177897562*^9, 3.422109451244846*^9, 
   3.422112978284717*^9, 3.422114408141899*^9, 3.422115134983927*^9, 
   3.422115447200836*^9, 3.4221657813998175`*^9, 3.4221666798271136`*^9, 
   3.4221671236102333`*^9, 3.4221681723741627`*^9, 3.425197533619651*^9, 
   3.426077923763769*^9, 3.426154395683058*^9, 3.426350123005224*^9, 
   3.426350655166945*^9, 3.426403677048559*^9, {3.42640377330758*^9, 
   3.426403797755233*^9}, 3.426403846227973*^9, 3.426491345961655*^9, 
   3.426491514500509*^9, 3.426848882650397*^9, 3.426854905108227*^9, 
   3.426944317994546*^9, {3.426944394071025*^9, 3.426944417679212*^9}, 
   3.427526615038491*^9, 3.43074668718883*^9, 3.431098384541195*^9, 
   3.435323075941372*^9, 3.435560709892399*^9, 3.43556123664373*^9, 
   3.436621796050363*^9, 3.436621839746555*^9, 3.43662216567953*^9, 
   3.436622421216003*^9, 3.436622460691283*^9, 3.436707555747238*^9, 
   3.43670942157284*^9, 3.436712212173608*^9, 3.468938202514041*^9, 
   3.468938473367994*^9, 3.468939606122415*^9, 3.469126436552756*^9, 
   3.469126881944754*^9, 3.489242072156052*^9, 3.500038523241233*^9, 
   3.532705103439921*^9, 3.532705397454772*^9, 3.532706161499784*^9, 
   3.532706414967001*^9, 3.564681521341989*^9, 3.564688302277297*^9, 
   3.564689566365117*^9, 3.564690630519938*^9, 3.564693021373925*^9, 
   3.5646932087238493`*^9, 3.564695023997651*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fix", "[", "2", "]"}], "=", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"rame", "[", "2", "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"a1", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"a2", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"\[CurlyPhi]", "'"}], "[", "t", "]"}], "\[Rule]", "0"}]}],
          "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], ",", 
       RowBox[{"a2", "[", "t", "]"}], ",", 
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "3"], ",", 
       SuperscriptBox[
        RowBox[{"a2", "[", "t", "]"}], "3"], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a1", "[", "t", "]"}], "2"], 
        RowBox[{"a2", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], 
        SuperscriptBox[
         RowBox[{"a2", "[", "t", "]"}], "2"]}], ",", 
       SubscriptBox["b", "0"], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}]}], "}"}]}], "]"}], "/.",
    "fixRule"}]}]], "Input",
 CellChangeTimes->{{3.412416860101929*^9, 3.412416904329425*^9}, {
   3.412417638507388*^9, 3.412417638764129*^9}, {3.425197470346201*^9, 
   3.425197478068222*^9}, {3.426078053254418*^9, 3.426078058548515*^9}, {
   3.426403862892871*^9, 3.426403881058446*^9}, {3.426944366039863*^9, 
   3.426944366313679*^9}, {3.426944435639747*^9, 3.426944436983296*^9}, 
   3.426944657397969*^9, {3.43662180827302*^9, 3.436621845763282*^9}, 
   3.436622465779949*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"a2", " ", "\[Nu]"}], "2"], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox["a2", "3"], " ", 
   SubscriptBox["b", "2"], " ", 
   SubsuperscriptBox["\[Omega]", "1", "2"]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a1", "2"], " ", 
    RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.41241690477562*^9, 3.412417691657984*^9, 3.412417934116945*^9, 
   3.41241840781179*^9, 3.412421573772698*^9, 3.41413560914596*^9, 
   3.414138486898906*^9, 3.414147179511359*^9, 3.414222993233423*^9, 
   3.414223725536952*^9, 3.41423250240625*^9, 3.41423381990625*^9, 
   3.414758545472941*^9, 3.414759079510045*^9, 3.414764198507867*^9, 
   3.415002759660651*^9, 3.415944323706381*^9, 3.415944975372249*^9, 
   3.416025589460429*^9, 3.41666051463652*^9, 3.416717507141342*^9, 
   3.416743050991406*^9, 3.416744404121027*^9, 3.417417953537909*^9, 
   3.417503906260341*^9, 3.417592040658854*^9, 3.417798774215209*^9, 
   3.417857891348489*^9, 3.417872177914177*^9, 3.422109451302502*^9, 
   3.422112978301464*^9, 3.422114408206334*^9, 3.42211513505692*^9, 
   3.422115447217119*^9, 3.4221657814554777`*^9, 3.4221666799052334`*^9, 
   3.4221671236746817`*^9, 3.422168172449353*^9, 3.425197534759989*^9, 
   3.426078060518153*^9, 3.4261543957904725`*^9, 3.426350124929889*^9, 
   3.426350657494067*^9, 3.426403677156372*^9, {3.426403867991042*^9, 
   3.426403881473764*^9}, 3.426491347985238*^9, 3.426491514698346*^9, 
   3.426848883641248*^9, 3.426854905190222*^9, 3.426944318250415*^9, 
   3.426944438795501*^9, 3.426944659057347*^9, 3.42752661528841*^9, 
   3.430746687703188*^9, 3.43109838470764*^9, 3.435323076110963*^9, 
   3.435560710243634*^9, 3.435561236812263*^9, {3.4366218145927*^9, 
   3.436621846423383*^9}, 3.43662216616497*^9, 3.436622466730531*^9, 
   3.43670755603267*^9, 3.436709421915176*^9, 3.436712212515*^9, 
   3.468938204773983*^9, 3.468938474147836*^9, 3.468939606629573*^9, 
   3.469126436888734*^9, 3.469126882357376*^9, 3.489242073083713*^9, 
   3.500038523764022*^9, 3.532705105187714*^9, 3.532705397637566*^9, 
   3.5327061616724567`*^9, 3.53270641520157*^9, 3.564681521475525*^9, 
   3.5646883024615927`*^9, 3.5646895664495792`*^9, 3.564690630580942*^9, 
   3.56469302142101*^9, 3.564693208816657*^9, 3.564695024078024*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fix", "[", "3", "]"}], "=", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"rame", "[", "3", "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"a1", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"a2", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"\[CurlyPhi]", "'"}], "[", "t", "]"}], "\[Rule]", "0"}]}],
          "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1", "[", "t", "]"}], ",", 
       RowBox[{"a2", "[", "t", "]"}], ",", 
       SuperscriptBox[
        RowBox[{"a1", "[", "t", "]"}], "3"], ",", 
       SuperscriptBox[
        RowBox[{"a2", "[", "t", "]"}], "3"], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a1", "[", "t", "]"}], "2"], 
        RowBox[{"a2", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], 
        SuperscriptBox[
         RowBox[{"a2", "[", "t", "]"}], "2"]}], ",", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a1", "[", "t", "]"}], "3"], 
        RowBox[{"a2", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], 
        SuperscriptBox[
         RowBox[{"a2", "[", "t", "]"}], "3"]}], ",", 
       SubscriptBox["b", "0"], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "]"}]}], "}"}]}], "]"}], "/.",
    "fixRule"}]}]], "Input",
 CellChangeTimes->{{3.412416860101929*^9, 3.412416908974229*^9}, {
   3.412417641136319*^9, 3.41241764138889*^9}, {3.425197441628467*^9, 
   3.425197442336934*^9}, {3.425197472362688*^9, 3.425197479565279*^9}, {
   3.426078063831169*^9, 3.426078080627018*^9}, {3.426403887284716*^9, 
   3.426403893632804*^9}, {3.426944368592076*^9, 3.426944368842483*^9}, {
   3.426944475057284*^9, 3.4269445538296*^9}, {3.436621848608814*^9, 
   3.436621871156702*^9}, 3.436622468241397*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "a1"}], " ", "a2", " ", "\[Sigma]"}], "+", 
  RowBox[{"a1", " ", 
   SuperscriptBox["a2", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "c"}], 
       RowBox[{"16", " ", 
        SubscriptBox["\[Omega]", "1"]}]]}], "-", 
     RowBox[{
      FractionBox["109", "30"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["a1", "3"], " ", "a2", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "c"}], 
      RowBox[{"4", " ", 
       SubscriptBox["\[Omega]", "1"]}]], "+", 
     RowBox[{
      FractionBox["1", "20"], " ", 
      SubsuperscriptBox["b", "0", "2"], " ", 
      SubscriptBox["\[Omega]", "1"]}]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a1", "3"], " ", 
    RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
    SubscriptBox["b", "0"], " ", 
    SubsuperscriptBox["\[Omega]", "1", "2"]}], 
   RowBox[{"4", " ", 
    SubscriptBox["\[Omega]", "2"]}]], "+", 
  RowBox[{"a1", " ", 
   SuperscriptBox["a2", "2"], " ", 
   RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.412416909447633*^9, 3.412417691831183*^9, 3.412417934339594*^9, 
   3.41241840791309*^9, 3.412421573851486*^9, 3.414135609327553*^9, 
   3.414138486977741*^9, 3.414147179527376*^9, 3.414222993284216*^9, 
   3.414223725550202*^9, 3.4142325024375*^9, 3.4142338199375*^9, 
   3.414758545494084*^9, 3.414759079525952*^9, 3.414764198523883*^9, 
   3.415002759714959*^9, 3.415944323759243*^9, 3.415944975433085*^9, 
   3.416025589473392*^9, 3.4166605147282476`*^9, 3.416717507155252*^9, 
   3.416743051129979*^9, 3.416744404193885*^9, 3.417417953602141*^9, 
   3.417503906327046*^9, 3.417592040677412*^9, 3.41779877423506*^9, 
   3.417857891368822*^9, 3.417872177976667*^9, 3.422109451318271*^9, 
   3.422112978365513*^9, 3.42211440822306*^9, 3.422115135131516*^9, 
   3.422115447296221*^9, 3.4221657815169973`*^9, 3.42216667996187*^9, 
   3.422167123739131*^9, 3.4221681725157547`*^9, 3.425197535982526*^9, 
   3.426078081524413*^9, 3.4261543958920283`*^9, 3.426350126910029*^9, 
   3.426350658778621*^9, 3.426403677237506*^9, 3.426403894442936*^9, 
   3.426491349272931*^9, 3.426491514982065*^9, 3.426848885265862*^9, 
   3.42685490529845*^9, 3.426944318621536*^9, {3.426944456739825*^9, 
   3.426944488347297*^9}, {3.426944526485301*^9, 3.426944554428739*^9}, 
   3.427526615650282*^9, 3.430746688040532*^9, 3.431098384999341*^9, 
   3.435323076391241*^9, 3.435560710523539*^9, 3.435561237186541*^9, 
   3.436621873439961*^9, 3.436622167733266*^9, 3.436622469028237*^9, 
   3.436707556926484*^9, 3.436709423117848*^9, 3.436712213667024*^9, 
   3.468938208147044*^9, 3.468938476169545*^9, 3.46893960797456*^9, 
   3.469126438199091*^9, 3.469126883932603*^9, 3.489242074801607*^9, 
   3.500038526160338*^9, 3.532705106617587*^9, 3.532705398084552*^9, 
   3.53270616209514*^9, 3.532706415654373*^9, 3.5646815219722652`*^9, 
   3.5646883030940866`*^9, 3.564689566857251*^9, 3.564690630923194*^9, 
   3.564693021461276*^9, 3.5646932091879873`*^9, 3.564695024475424*^9}]
}, Open  ]],

Cell["Reconstitution of the solution", "Text",
 CellChangeTimes->{{3.436621915631349*^9, 3.436621954884517*^9}, 
   3.436622328324856*^9, {3.436622474413479*^9, 3.43662247485474*^9}, {
   3.43671196034342*^9, 3.436711965304971*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["ur", "1"], "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["A", "1"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}], 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Omega]", "1"], "t"}]]}], "+", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             OverscriptBox["A", "_"], "1"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}], 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubscriptBox["\[Omega]", "1"], "t"}]]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"1", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], "/.", "sol2p"}], ")"}]}], ")"}], "/.",
         "traspRule"}], "/.", "polRule"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], "->", "t"}], "}"}]}], "]"}], "//", 
    "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.436710993939026*^9, 3.436711162891084*^9}, {
   3.436711196531536*^9, 3.436711201558584*^9}, {3.436711277480484*^9, 
   3.43671128957409*^9}, {3.43671144687672*^9, 3.436711516182336*^9}, {
   3.436711811728409*^9, 3.436711871462266*^9}, {3.436711913547705*^9, 
   3.436711943394715*^9}, 3.468938253908092*^9, 3.532706032858567*^9, {
   3.564681581214275*^9, 3.5646815817355824`*^9}, {3.564681794272504*^9, 
   3.564681805232904*^9}, {3.564682037055098*^9, 3.5646820376830883`*^9}, {
   3.564688913518771*^9, 3.5646889242851458`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
   SubscriptBox["b", "0"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
   SubscriptBox["b", "0"]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], ")"}]}], "]"}], " ", 
   SubscriptBox["b", "0"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], "+", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"]}], "-", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"3", " ", "t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], "+", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"]}], "+", 
  RowBox[{
   FractionBox["2", "15"], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"4", " ", "t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]}], "]"}], " ", 
   SubscriptBox["b", "0"]}]}]], "Output",
 CellChangeTimes->{
  3.5646820426901703`*^9, 3.5646883032594223`*^9, {3.564688916890568*^9, 
   3.5646889252481003`*^9}, 3.5646895680383797`*^9, 3.5646906316307163`*^9, 
   3.564693021925734*^9, 3.564693209666072*^9, 3.564695025119184*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["ur", "2"], "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["T", "0"], " ", 
             SubscriptBox["\[Omega]", "1"]}]], " ", 
           SubscriptBox["\[Omega]", "1"], " ", 
           RowBox[{
            SubscriptBox["A", "1"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubscriptBox["T", "0"], " ", 
             SubscriptBox["\[Omega]", "1"]}]], " ", 
           SubscriptBox["\[Omega]", "1"], " ", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["A", "_"], "1"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["v", 
              RowBox[{"1", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], "/.", "sol2p"}], ")"}]}], ")"}], "/.",
         "traspRule"}], "/.", "polRule"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], "->", "t"}], "}"}]}], "]"}], "//", 
    "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.436710993939026*^9, 3.436711162891084*^9}, {
   3.436711196531536*^9, 3.436711201558584*^9}, {3.436711277480484*^9, 
   3.43671128957409*^9}, {3.43671144687672*^9, 3.436711516182336*^9}, {
   3.436711811728409*^9, 3.436711871462266*^9}, {3.436711913547705*^9, 
   3.436711943394715*^9}, 3.468938253908092*^9, 3.532706032858567*^9, {
   3.564681581214275*^9, 3.5646815817355824`*^9}, {3.564681794272504*^9, 
   3.564681805232904*^9}, {3.564682037055098*^9, 3.5646820376830883`*^9}, {
   3.564688913518771*^9, 3.5646889242851458`*^9}, {3.564692841435548*^9, 
   3.564692845219335*^9}, 3.564692880546224*^9, {3.564695008355384*^9, 
   3.5646950121674557`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"a1", "[", "t", "]"}]}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   SubscriptBox["v", 
    RowBox[{"1", ",", "1"}]], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.564692896636765*^9, 3.564693022417555*^9, 
  3.564693210277562*^9, 3.564695025167651*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["ur", "3"], "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["A", "2"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}], 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Omega]", "2"], "t"}]]}], "+", 
          RowBox[{
           RowBox[{
            SubscriptBox[
             OverscriptBox["A", "_"], "2"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}], 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubscriptBox["\[Omega]", "2"], "t"}]]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"2", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], "/.", "sol2p"}], ")"}]}], ")"}], "/.",
         "traspRule"}], "/.", "polRule"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], "->", "t"}], "}"}]}], "]"}], "//", 
    "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.436711191363988*^9, 3.436711209357088*^9}, {
   3.436711294646353*^9, 3.436711296180162*^9}, 3.43671132660482*^9, {
   3.436711526246183*^9, 3.436711537978677*^9}, {3.436711809639925*^9, 
   3.436711820219827*^9}, {3.436711924524995*^9, 3.436711948656139*^9}, 
   3.468938258660156*^9, 3.532706035755659*^9, {3.564681583602504*^9, 
   3.5646815842876167`*^9}, {3.564681647799231*^9, 3.564681685543866*^9}, {
   3.564688942105474*^9, 3.564688957334457*^9}, 3.564695013940901*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    RowBox[{"a1", "[", "t", "]"}], "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"t", " ", 
        SubscriptBox["\[Omega]", "1"]}], "+", 
       RowBox[{"\[CurlyTheta]1", "[", "t", "]"}]}], ")"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "-", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], "+", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "+", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   RowBox[{"a1", "[", "t", "]"}], " ", 
   RowBox[{"a2", "[", "t", "]"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"3", " ", "t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], "+", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "1"]}], "-", 
  RowBox[{
   FractionBox["8", "15"], " ", 
   SuperscriptBox[
    RowBox[{"a2", "[", "t", "]"}], "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"4", " ", "t", " ", 
      SubscriptBox["\[Omega]", "1"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}]}], "]"}], " ", 
   SubscriptBox["b", "0"], " ", 
   SubscriptBox["\[Omega]", "1"]}]}]], "Output",
 CellChangeTimes->{3.5646889589188433`*^9, 3.564689568580461*^9, 
  3.564690632166548*^9, 3.564693022966402*^9, 3.564693210908062*^9, 
  3.564695025839282*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["ur", "4"], "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ComplexExpand", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["T", "0"], " ", 
             SubscriptBox["\[Omega]", "2"]}]], " ", 
           SubscriptBox["\[Omega]", "2"], " ", 
           RowBox[{
            SubscriptBox["A", "2"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubscriptBox["T", "0"], " ", 
             SubscriptBox["\[Omega]", "2"]}]], " ", 
           SubscriptBox["\[Omega]", "2"], " ", 
           RowBox[{
            SubscriptBox[
             OverscriptBox["A", "_"], "2"], "[", 
            RowBox[{
             SubscriptBox["T", "1"], ",", 
             SubscriptBox["T", "2"]}], "]"}]}], "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["v", 
              RowBox[{"2", ",", "1"}]], "[", 
             SubscriptBox["T", "0"], "]"}], "/.", "sol2p"}], ")"}]}], ")"}], "/.",
         "traspRule"}], "/.", "polRule"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["T", "0"], "->", "t"}], "}"}]}], "]"}], "//", 
    "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.436710993939026*^9, 3.436711162891084*^9}, {
   3.436711196531536*^9, 3.436711201558584*^9}, {3.436711277480484*^9, 
   3.43671128957409*^9}, {3.43671144687672*^9, 3.436711516182336*^9}, {
   3.436711811728409*^9, 3.436711871462266*^9}, {3.436711913547705*^9, 
   3.436711943394715*^9}, 3.468938253908092*^9, 3.532706032858567*^9, {
   3.564681581214275*^9, 3.5646815817355824`*^9}, {3.564681794272504*^9, 
   3.564681805232904*^9}, {3.564682037055098*^9, 3.5646820376830883`*^9}, {
   3.564688913518771*^9, 3.5646889242851458`*^9}, {3.564692841435548*^9, 
   3.564692856565099*^9}, 3.564692890727542*^9, {3.5646950163186903`*^9, 
   3.564695018141102*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"a2", "[", "t", "]"}]}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"t", " ", 
      SubscriptBox["\[Omega]", "2"]}], "+", 
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "]"}], " ", 
   SubscriptBox["\[Omega]", "2"]}], "+", 
  RowBox[{
   SubscriptBox["v", 
    RowBox[{"2", ",", "1"}]], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.564692900560162*^9, 3.564693023520461*^9, 
  3.5646932115290127`*^9, 3.564695025975356*^9}]
}, Open  ]],

Cell[TextData[{
 "Equilibrium paths in the specific case     ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["a", "2"], "=", "0"}], TraditionalForm]]],
 ", mono-modal solution (from now on, use your skills to study the \
solutions!!!)"
}], "Text",
 CellChangeTimes->{{3.436621915631349*^9, 3.436621954884517*^9}, 
   3.436622328324856*^9, {3.436622474413479*^9, 3.43662247485474*^9}, {
   3.469126786505431*^9, 3.46912678650555*^9}, {3.532705133109107*^9, 
   3.532705160655665*^9}, {3.532705871286998*^9, 3.5327058887054358`*^9}, {
   3.564692906729291*^9, 3.564692939674261*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ep", "[", "1", "]"}], "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"fix", "[", "1", "]"}], "/.", 
         RowBox[{"a2", "\[Rule]", "0"}]}], ")"}], "\[Equal]", "0"}], ",", 
      "a1"}], "]"}], ",", 
    RowBox[{"\[Omega]1", ">", "0"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436621939341448*^9, 3.43662196370485*^9}, {
  3.436621994235294*^9, 3.436621999747808*^9}, {3.436622472864189*^9, 
  3.43662247707848*^9}, {3.469126789402011*^9, 3.469126793285997*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a1", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SqrtBox["\[Mu]"]}], 
       RowBox[{
        SqrtBox["3"], " ", 
        SqrtBox[
         SubscriptBox["b", "1"]], " ", 
        SubscriptBox["\[Omega]", "1"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox["\[Mu]"]}], 
      RowBox[{
       SqrtBox["3"], " ", 
       SqrtBox[
        SubscriptBox["b", "1"]], " ", 
       SubscriptBox["\[Omega]", "1"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.436621970674487*^9, 3.436622000495503*^9}, 
   3.436622168773223*^9, 3.436622478349909*^9, 3.436707557180153*^9, 
   3.436709423482729*^9, 3.436712213985122*^9, 3.46893823872662*^9, 
   3.468938476347086*^9, 3.468939608221579*^9, 3.469126438358244*^9, 
   3.469126884899743*^9, 3.489242075815082*^9, 3.500038526627087*^9, 
   3.532705114546361*^9, 3.532705398294405*^9, 3.532706162344171*^9, 
   3.532706415796131*^9, 3.5646815222187147`*^9, 3.5646883034929132`*^9, 
   3.5646891781259193`*^9, 3.5646895690373907`*^9, 3.564690632328849*^9, 
   3.5646930235627604`*^9, 3.564693211606209*^9, 3.564695026051409*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical integrations", "Section",
 CellChangeTimes->{{3.436711972668522*^9, 3.436711977721894*^9}}],

Cell["Numerical values", "Text",
 CellChangeTimes->{{3.436707444111488*^9, 3.436707461772749*^9}, {
   3.436709316192282*^9, 3.436709317295154*^9}, 3.532705621400423*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vals", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Omega]", "1"], "->", "1"}], ",", 
    RowBox[{
     SubscriptBox["\[Omega]", "2"], "->", "2"}], ",", 
    RowBox[{
     SubscriptBox["b", "0"], "->", 
     FractionBox["1", "2"]}], ",", 
    RowBox[{
     SubscriptBox["b", "1"], "->", "1"}], ",", 
    RowBox[{
     SubscriptBox["b", "2"], "->", "1"}], ",", 
    RowBox[{"c", "->", "1"}], ",", 
    RowBox[{"\[Sigma]", "->", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.436707717565321*^9, 3.436707765367975*^9}, {
   3.436707832529172*^9, 3.436707898641399*^9}, {3.436707932362024*^9, 
   3.436707958775376*^9}, 3.436708583220225*^9, {3.436708880638231*^9, 
   3.43670888486349*^9}, {3.436709272266559*^9, 3.436709277440893*^9}, {
   3.532705415242352*^9, 3.532705482446965*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Omega]", "1"], "\[Rule]", "1"}], ",", 
   RowBox[{
    SubscriptBox["\[Omega]", "2"], "\[Rule]", "2"}], ",", 
   RowBox[{
    SubscriptBox["b", "0"], "\[Rule]", 
    FractionBox["1", "2"]}], ",", 
   RowBox[{
    SubscriptBox["b", "1"], "\[Rule]", "1"}], ",", 
   RowBox[{
    SubscriptBox["b", "2"], "\[Rule]", "1"}], ",", 
   RowBox[{"c", "\[Rule]", "1"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.436707939223261*^9, 3.436707959599964*^9}, 
   3.43670858394567*^9, 3.436708885301851*^9, 3.436709423562667*^9, 
   3.436712214291098*^9, 3.468938271192771*^9, 3.468938476720624*^9, 
   3.468939608503281*^9, 3.469126438749503*^9, 3.469126887132672*^9, 
   3.489242094266257*^9, 3.500038599216642*^9, 3.532705206911141*^9, 
   3.5327054825679626`*^9, 3.532706162392892*^9, 3.532706415830217*^9, 
   3.564681531896508*^9, 3.564689190525998*^9, 3.56468956917715*^9, 
   3.5646906323852262`*^9, 3.564693023598587*^9, 3.564693211670637*^9, 
   3.564695070195166*^9}]
}, Open  ]],

Cell["Section of the bifurcation diagram (mono-modal solution)", "Text",
 CellChangeTimes->{{3.532705580618668*^9, 3.5327055914356823`*^9}, {
  3.532705763987216*^9, 3.5327057695102367`*^9}, {3.53270583878056*^9, 
  3.532705843345649*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ep", "[", "1", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a1", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        SqrtBox["\[Mu]"]}], 
       RowBox[{
        SqrtBox["3"], " ", 
        SqrtBox[
         SubscriptBox["b", "1"]], " ", 
        SubscriptBox["\[Omega]", "1"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", "\[Rule]", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox["\[Mu]"]}], 
      RowBox[{
       SqrtBox["3"], " ", 
       SqrtBox[
        SubscriptBox["b", "1"]], " ", 
       SubscriptBox["\[Omega]", "1"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.532706460198596*^9, 3.564681531940484*^9, 
  3.564689194192356*^9, 3.564689569184304*^9, 3.564690632460966*^9, 
  3.5646930236274233`*^9, 3.564693211723537*^9, 3.5646950703239403`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"a1", "/.", 
     RowBox[{"ep", "[", "1", "]"}]}], "/.", "vals"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", 
     RowBox[{"-", "0.1"}], ",", "0.1"}], "}"}], ",", 
   RowBox[{"PlotStyle", "->", "Thick"}], ",", 
   RowBox[{"AxesLabel", "->", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Mu]\>\"", ",", "\"\<a1\>\""}], "}"}]}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.53270549376547*^9, 3.5327055646237173`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxF1I0vFHAcBvCbrC3zMknOyyldRHNlyV2SxWgS5a1TZF7Oec2cZqUrbq6d
vIRy7sSdu+twuqFz3l920WHUait3qBxTVxKTmexck6k2fX/P9uzZ5x94HCi0
8CQDDAZz8W//reMb86Kamr5BzE6iOYsZHC5yeYwy7GEFsm45y7agGHnU5J0s
i46cHFI+GRCFLFUZ4XVYZNePuwbCq3vBObO0lRRmDzjI3WlWn9sNrlAQhZK8
LrCNtzJKltoJPmZWpT6R3AFmffgaYHGpHRw8WVZu5tUGFuKZlYWn5eAk1Yxj
z3kZuA4TLI70bQEPc2lKgn8TOM26cEphKwXjfdxT/bCNYApZvcJcrAffHz9i
ox8Rg+9+dmC9LhGB139rnu/34IO5sYOroS6Pwb6CEpPNUTb4ekTegvNaKbhB
T2r0XGKBta2sG5fTb4NPmebptCHxYFxTBXn8UNzZ/zb4nsLgWdDBmU6JCRQ+
CzwmHGq1ii4Dv/SWemxssMGG387xfuqrwMS2zX35oXywD7GoChcrAr/QkRck
zWKw5ku2aYG6HqwlbPVmTEnA1GJ2Zq2hFKzyrXw6YdIEjqmc85o0bgEn6Ega
HEkGdtFsMUj2cvDc8Lwli9gGxtOzpzsD28GzM92f0i50gMmB+ctD8Z1gP+q2
5xNqF3gg6HBXQmI3WOf11mMspwfcMH1cL6f3gtMpNJ4bA9ltSXZGfg9Z8YvA
bH2APIF1NZIJkA2vONs1K5Gp6oM+kj194KPX4rWHTZFXtSJWw17k3DX7V/W2
yBxzXHgdAXkkxJoqCkMueX9194FI5NC4aqkwGnkm0+qHIBF5vczyVu1N5H5L
MtbuDnK+gNPPZyAbP7PY5hUiq05GiG1KkasVbD/eI+RYf9W8NRd557/AfwCC
cTym
     "]], LineBox[CompressedData["
1:eJwVkGk8lAkcgF21iRJlZaMa5NodpFyJv5Q2x9ZEKM1ijErkGLqmJOxM62i2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     "]], LineBox[CompressedData["
1:eJwVkGlcjAkAh7tYKdqiTaswla7dqUSX1D+R7cIoFZmtpolN6ZiyGJK0M7bD
7FJNTacpXSsdNGreoXFGCds5Lx0oilXtWo10kLUfnt/z7fnwUEJjfPYqKSgo
BH/hfz93c4tyrU11duBJpDSeCywSjvupGL11DpLmz+77LQ61NKWR8uklmHdY
yb+klAOzYp89xu8paLpWGbGyJh2zuqWb2ONmMBM85tGKz2Bf64z2yDsr9NSX
6TxTzsSfXMM0jX/WQT5++qycwoe9q/ec/ag9ljas331ocQ6K5w7Ghb7aAImw
WWG8WwDuwLaJZpYLdJI97n9OyAPhyKzujXFFaFQsoaleAIOpdIrKgS3wtWat
1f27CP7+wr5lEe54LTV+amsoRLpIxKeGe6J2rJWV0CKEPHZANSBsG1xWZRp7
KJYg69XUoM0aGtTUme9m+CWo+UYZLlY7EBDPLjM3Po8XB3Wmd1r4glnzYl/y
+lJ4r3GJSjQPQEKB8c2ljuXYF+J5P8VsF174nttqLipH0u87TTJNd8Migkm5
Z14B0Xj4YIXxHmzffkTVVLMS+hfO+nUYBOM79r8mXc1/YObt1/3Xl4eANcUb
22N3ASPquxfplIfA70PxSsWKC5Bu/iumWcJA/IcdrI9JVYgSqdoYvGSCRbLX
9lOq8SDT83qfbTiEcVmPnbXqIK7NeGt9MxzVLT9cGUEdStt6KWle+xF59W61
RlQdEpQjOfYhEbjXWvhG3lyH7+LTPfipB9DWcoLJirsEN7OR/SbRsRi6zbHu
Fl/Gers0Jd/6WDhOD7YseX4ZVm4W+YlTsXhKj41Q+qoeeoxDD3qSWQh4Pxcj
962HXDDfkpMTB9VJ5jj9TT1KF5jIn984iAMHTzgIFl6B0uufEvOWsKFSU+Gq
T2lENoNtYrKTjbaMwIlHzo0w60trr89iY3iaPxxIbwTtUbXBQ+2j8K50albO
aUSRaOLuZ51jEApz1lYuFMPh5AmNvXrHQedZTVaMimHP82rPyUiCxHg2nJEj
QbQxkxGaz8G0luncQHkTaKUFtj9KOVjvGqswd70JawxkarsGOeB/OtS/4EkT
5PoeDVtNuHhJpbx/tlAKtralmkM9F52jERtzo6TgqMyKNNpOoXO1+eFQy+vI
G8pY0DSTgttFymFSnxu4V3SrVieQh+PS6otXL91Ei1OlzYcPGZB+vLPgtv4d
qIy45U1MZYOq+zjL1fAubC/NLk2i5SNl/saSi4YtcLFNydYPOgdVgYWDz9NW
3Jj0e1VWVYzFQUc+Ov/chr4X8Yu5XeexjR+5vFb7IYaon8QHZGVIp2+JdDr1
CGGpGdEFKpUY3uv9U6piOzo3ZlZ0L7qAwELFnuqqdtAznzn2qF+Eoo3WqJF3
BxiTdn36djXwJZk9Tyc6vvz/lGi3og4+r8dMNNM78ez2sDbH9hJOERbiCrMu
GLLje0Uel6F+UnsD50YXBvobnu/3rIen8NYtL49u+Hkkjd0KEYErEWeUPenG
prDPDsKwK/Bvp++fpvdA6mV0hcFsALbcPyzp7cGk45829w43wj2e/7VaiAyl
vZZTdWwxOoIZaqInMkSExuRZJYphraef+rBPBqs3NRvqksX4UZ7YMzIgw7Vp
6snadDHmuUf2LhuSoXvZ9wtrCsWIpjGyj76RQSXAVK/qphgzXtyhdbMyhHWt
cilTJTDMO2nK1SNhvidkyGgxAZZif5ZgBYm3Q+c4pVoEtI7/0lG1ikTCuxWt
55cTGBoYu9phRCJLU9+nhEpA4PS7/3IqiTvbdcPO7SCQybWsKXMikUbumr/S
n8AZa5/VDSBBCxZUFgUSiM49HXV3I4n+aJ3xQuaXXsJR1ogbCTlP+1DBzwSU
pNnuRttISLT9lukdJRDI6fJYSyORVJglyU8kkO+WrufqQ0K9esnnvF8JJP9b
YBvsT6JznW/xt6cJjEZoJEbtIiG4lrEp7wyBRx+pOccCSQRt7hzW5RNYNKiS
nEonsfqBZkpuLgGqt9A5J4jEf1en1es=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"\[Mu]\"", TraditionalForm], 
    FormBox["\"a1\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{-0.1, 0.1}, {-0.3651483642181031, 0.3651483642181031}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5327053626433496`*^9, 3.532705398375677*^9, {3.532705519624855*^9, 
   3.532705564983632*^9}, 3.532706162442306*^9, 3.532706415903709*^9, 
   3.5646815321542273`*^9, 3.5646891954363003`*^9, 3.56468956932051*^9, 
   3.56469063254399*^9, 3.564693023685421*^9, 3.5646932118045464`*^9, 
   3.56469507039674*^9}]
}, Open  ]],

Cell["Time of integration", "Text",
 CellChangeTimes->{{3.436709322978369*^9, 3.436709327000911*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ti", "=", "200"}], ";"}]], "Input",
 CellChangeTimes->{{3.436708632790919*^9, 3.436708665844516*^9}, {
   3.436708953796423*^9, 3.436708961998025*^9}, 3.468939907190359*^9}],

Cell["Numerical Intergations of the RAME", "Text",
 CellChangeTimes->{{3.436707444111488*^9, 3.436707461772749*^9}, {
  3.436709334864331*^9, 3.436709336846146*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solrame", "[", "1", "]"}], "=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Mu]", "=", "0.05"}], ",", 
      RowBox[{"\[Nu]", "=", "0.05"}]}], "}"}], ",", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"rame", "[", "1", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"rame", "[", "2", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"rame", "[", "3", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"a1", "[", "0", "]"}], "==", "0.1"}], ",", 
        RowBox[{
         RowBox[{"a2", "[", "0", "]"}], "==", "0.1"}], ",", 
        RowBox[{
         RowBox[{"\[CurlyPhi]", "[", "0", "]"}], "==", "0.1"}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], ",", 
        RowBox[{"a2", "[", "t", "]"}], ",", 
        RowBox[{"\[CurlyPhi]", "[", "t", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "ti"}], "}"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.436707561368821*^9, 3.436707607657047*^9}, {
  3.436707641996551*^9, 3.436707699807487*^9}, {3.436707965718594*^9, 
  3.436707969218277*^9}, {3.436708279093091*^9, 3.436708279669862*^9}, {
  3.436708627544259*^9, 3.436708640158691*^9}, {3.532705602695711*^9, 
  3.532705655460495*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"a2", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.436707584095343*^9, {3.436707942345193*^9, 3.436707971567758*^9}, 
   3.436708281314834*^9, 3.436708585128214*^9, 3.436708627927498*^9, 
   3.436708666955983*^9, 3.436708887569437*^9, {3.436708955018372*^9, 
   3.436708962913422*^9}, 3.436709423753747*^9, 3.43671221440215*^9, 
   3.468938278775205*^9, 3.468938477011898*^9, 3.468939608901255*^9, 
   3.46893990884368*^9, 3.469126439119998*^9, 3.469126887220164*^9, 
   3.489242100061748*^9, 3.500038605739614*^9, 3.532705214938409*^9, 
   3.532705657292829*^9, 3.532706162466455*^9, 3.532706415930481*^9, 
   3.564681532373323*^9, 3.5646892030119*^9, 3.564689569427803*^9, 
   3.564690632620352*^9, 3.564693023751787*^9, 3.5646932118318872`*^9, 
   3.564695070510117*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a1", "[", "t", "]"}], "/.", 
         RowBox[{"solrame", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t\>\"", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(1\)]\)(t)\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a2", "[", "t", "]"}], "/.", 
         RowBox[{"solrame", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.6"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t\>\"", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(2\)]\)(t)\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[CurlyPhi]", "[", "t", "]"}], "/.", 
         RowBox[{"solrame", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"AxesOrigin", "->", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{"\"\<t\>\"", ",", "\"\<\[CurlyPhi](t)\>\""}], "}"}]}]}], 
      "]"}]}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.43670797401342*^9, 3.436707974839756*^9}, {
  3.436708018211059*^9, 3.436708163439754*^9}, {3.436708284280279*^9, 
  3.43670829162185*^9}, {3.436708649998939*^9, 3.436708704732867*^9}, {
  3.436708933513278*^9, 3.436708942188644*^9}, {3.436709068857664*^9, 
  3.436709074238786*^9}, {3.436709107254534*^9, 3.436709117207737*^9}, {
  3.532705228790683*^9, 3.5327052403657093`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwl1Xk4FW0UAHApWqgQoiSFIrIVWXuPnWu/9+JSluxbSLKvKSJESbYILUhF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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.8, 0.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwl1Hc8Vl8cB3CEFEXIFoWMZJXI6Hzx2PMxHg8S2aFIEiKKrFRCQtJQGSkj
/LJnRsbzRNFAUURIkZnxu5e/7uv9up/vOfd87zlnr5OPuSsdDQ1NPS0NDf7c
d3M1K3PP22Nl3kfz09LK0X9MkkKnPQrQWxU536/3ylF94IvHEh61yN6lVFDq
UTlqljvrzuhBQXumCjWb88pRa3y33pz7F5TFKmOwr6octalElE+6T6MYi0nC
mS/l6M2tz2fH3NeR6KIhY7hEBYpJTWlLkqeBjNff1mUOViBpD2R7qIAGXGh+
Ph2Sr0B+W29d9MujhWwjOz5z1Qq0pn245veDLdAa6u3paFKBeBqDtaaub4WE
a3D16PkKZFC91WTUnRXO13K08jRXIPl1pzmu36wQGW8VW91egeKFHbpE1Ngg
z3Vt2P1tBfJ3qjhv2cQGXjNpSZ39FYgw6ttU+m4XyM0GkQdnK9Dw1MDJwDkO
6DPUCd0rUomEV//LWD3CA1VeIiIpUZWIM9P19+6LPCCxI7Ji2/VKxIQ4CDK1
PEC9F0CJTKpE0+FnJk7o8gJx6X7FrQeVqIZeTKXOmg9U/tYnM1VWInuWxL4r
gQJguyRTG/ynEnXuOLKN3l4YAt4zTqy6VKFuQ/bUrhBhmKzSm2b0rkIfYn/t
T8sQBo3iV//xnKtC3xmyCTL9wvC2OWyIdLkKraxyh5Pt9gJ762AhyqxCUr+W
5vNt9sH+LWIj7z5WoZiu6u9WJFHI+XyO+xG5Gt1gST8nHCAKUvHjDyYcq1Gy
QQDdxG1R8GOgvw+nqtH9Zhnh8PeiIEfXTN4RXI3Kau7b5VmKwQ8V/pOHM6rR
yIvL3Wvm+6El4E5i13A10rypXZdtKgHKIdOtY0E1KNygJLf7jAS4X74h8CCi
BtUwiCStXpeAifmo267Xa5BKCI2bRYcERHTTOfM/rEGHTlUyr+tJwtucjOOK
bTVIVEvemqQpBZxq6k4qArWIcUHgF72iNBiiLE+DrlpEKL7WJ2spDTZDwmf/
faxFV04v19mek4YjTu3sNSO1aO1bX1JhkTTwoM7UwNVatEBNPHpc5iA8GtP4
PsxVh8bymK6+FJcBccXfzyb16pCr7PIO+R1yMP3zaqpFSR0y+hz9hGePHAhN
LWsvV9ahw9G71Wlk5eDK61XL5411iP6LnDfFTA6S0yTeK/fUoUc33N+cTpYD
t/wcph8zdejL1LuoPH55aLB5HPv8cD2yyS9YF5FSgJtnc8I0GuoRkNXvMKsq
QI4sX+rN9nokQd8uM2uoAGSTgqcT7+rRot2ofcNpBdAr/N3c+aMepTALVjkW
KYBzcfqiys4G1OMZF3hP+RA8zS0Xr7FvQMaSrn+4dA9DtGkPg//WRrR87Xzl
AOkwTNXfJLzZ1Yhyfl29+tjtMDRlujZLCzQi+pKnvApRh0EkevwSl3wjqjg2
pmH8+jAki/VlX7RrRPstvRIjtBRBblDCIKK4EdGEnT30Gx0BJ3VeHYlTTaj4
Xej5NmVlWP9SyEadfY1U2aUK6MPUoPGNdHfOpTbURWvb1nlTDdrCtN/si29D
jn9iv6U8UINu6mxPUlobiqSOc0s2qMGkwDMF2xIsfyM33JhBHfYrlVeeHcfy
zJLmKdfUgWGXzel04hsUSS8xJ556DMbcpkZP87Qjrr/WrH9yjkHQ6IefTqLt
KOdbtGRF+THIEln6rCfXjjobftgbfT4GX+IPzo/qYvnL2c2+exC8j80W8Qho
R7mr+1PLHyNwjHe640xtR+7/Eu89IQN8fXH7W8qFDpRsMtkY5AiQtFXauz28
A9U91P5p7AFwcOWB2+/YDsSjt3hk/gJAL7vhfeaMDtSabE/VuQPAUEdbGVXb
gSRlJLaMvQfgyWVnur6lE5EuX5asGgCw+2tt0sLcia68+2SaMILVjxyc/sPR
iT4FX89QngMYuKqhxyPaieJaZhRjOTVA1SW7KlerE2Fn1EPKQgNuVSd4jYR1
Ip4SrptrthoQlpneLB7diQhbfUu7nTQg88nTH7Y3OlHG8310F/004GZPU05S
RicyWo6+235LA/g8uZ3MXnWi50nmXd5UDYg3N4ynnepEPs0/DhUYawKrz2mW
F4ZdqA7yvaRJmvCh6nJ0GrELsVX6ZuWe0IS98v2u5627UGHBEvtjH00QaFot
WnPqQjOpzDOptzSBh/OAqW1QFwrwki288l4THsrfPGaU1YWaR2Z/rA9oQr55
F4NBThfidnwlFDqqCYcsfHqOPu9Cryw1bl5Y0ISC/uKp6bIutKRuccabVwu2
pa7vLW/rQiFsF6RJ9lrQn62R1TfZhTriVF16XLWg5YZsId2fLiTIQJNhdkYL
3GZzLu6d60I1SzHMhmFaQD2UWKmy2oVovqX/RA+14FVEXP8gCwVFlNbkSI5o
gaOGyCUGKQp6Jxvx9emUFsgG9x8JOkhBonm6PKLzWvB4Yd5+WI6CmjKp0Xu2
EkD+1BvH20oUxBgz7MYhSQCm89r8lwkUFGfLKLbqTYCotIz+q8cp6Jgcy/y4
PwG+TXy9Le1AQX8Y2Ft6Qwjwu/FbUPtJCiIXCZ4qjCfAyTh/9hk3ChJjUnzu
nE+ArMNzxd99Kaiu1FnxzQQBTk9PcftGUJD/tVOM/80S4Krhj0uPrlKQ+Emf
vqx/BNiv73GsK5qC3ecXg0KZtaHHL5GNPZ6C7JwTq+UOaEOK/MFxo2QKmmer
177jqQ0mvQ/m7mVRUN5oM1eknzY8HNs1cfoJBdlXdfzwDdYGceoHHeVsbL3u
H2IN4rTB/VqMT1UeBd2qme5czdUGleGIfZFFFCTtvYfkMq4NzHsqZwVrKOir
hqg48Y82fNqTpXO3loKSuKUW1Ze0QZ7P4ydHPQUtNyimc2/TARZBI/JCIwW1
8hoPvpHQgfv83UoxbRTk3HLRTd5DB0p/fbMa6KEgF7X9JvM+OqDm8O0J63sK
ciuiKlZe0AGVRSGlY70U5HFXjEE7WgcKotN1Ez5Q0BkfShb5qQ7ssUnX2zZA
QcHcIkNh33WANv00HXmEgkLiO1sJkzpg7WlqZjFKQaG0gYXb/uqA3A75K4Y/
KCh8oiMsaYsupH1VLFMYp6Co2oA92ft0IcaG035gkoIS3d/YdTnqglhhcMSz
WQpK7vfXSvLQBeP2TxpBfynoNlHoANlXF6pWDpwhzFFQqqr/8lCYLnQoB8v2
zFNQJuuetLlMXZBTKJbuWcL6/9/ZXoEBXeh7W1LivE5B+dICNUPfdSFwy/oU
Aw0VPX/Y/OTppC4MXUmbIWMuvMZ/Xm5FFyTLKz//w1zm8JqDwK8HbfUMsYp0
VFS/lZfoZaMHcg6huy/SU9FolozBx5N6MBAnGPYaMwsQtHQ99WCX1+LwTgYq
Igf6KIpc1IOzlc7ZmZinx17zfs7Qg8qqI1eLGalI8I3fsMFXPbAO077wgomK
NN1iPr8a04OKML7dPzF70GW+2/9HD7LmZb6KbqOiEpW2Zjo6fUjperctFbPh
M6FnFSL60P3wzor/dioKiu84J+WuDyIOxMfMLFSUKTHsneqjD7zTbnaqmJua
FlwZA/UhoM/mlCdmttV95OEYfWj78CSpGXP26SC19Dx9qEwTc7ywg4rem+xn
2P5LH6L88/OrdlLR8k/VtQvz+jB4abl3GLNwNHFhZE0fruQlBDGxUpF3bch4
PasBtG39LWOOeYtcT2eQvAGEaM1e/4JZfld4yrg/9j657ME3NiqqYOqTaAkx
AJotofw0u7D108hUPo40AI3ul0oCmC2nP39xSDaAVA1ZGwvMAZ1Kkr0vDUCe
zdexGnNV7HRlw4wBCH3quXSZnYq0L+uYPFg2gDcZymmpmLsC730NpTOEdKnn
bgWYv7gbMhxlNwS12JY9/ZjpdLJNCuQNoVenUEiBg4r06ByG7voagpXke/m3
mN8ulZ4LCjSEkoWaX98w2/5hYbQONwT1Qy6n5zF7fa2QYk8whGHWhWI+Tiq6
UcPlH1NgCAz1B/wdMb8L7mI8/8sQhEIOBwxhtvcTSzOfN4QYSnfOb8yjp0IO
yK0ZAtfUcM465gWylNnEDiNwH+/mENxNRXxKUWknDxqBVbrBUyvMjrPq0ibe
RkBOW9OtwbyDnYb6zt8Iyn7HPGrHXCHXcM4u1AheB33v+ICZ84xOpccNI0j5
W5Q0g7l1zMQgotAINEl8KyJcVCQ36ODx6q8RSCZMtlzCPLCylwWtGsGAsrl3
LOY4/u8FrxmM4U+/2c8kzN/JHgvdXMYg1Gp0Pgdzao9v1JSyMbz/m9NLwUzT
dvnxvlBjcKhlPcLDjZ2vH1p6uVeNAXG9KBLGbMvIOCl7wxgEOBt3SmIu0Yo7
pH7fGESuK/kcxexRk9hgXW8M4qw735MxU19mfY1nMIErTTwxiZhDu10jOXaa
wDaNM4ZpmKX+iEukc5nAhXLf+fuYI2XyfbLFTSCMcZn+OWbl3JK1en0TiApP
39GM+WHma4GF6yYgyPaM9S/mjOPSfVYpJqDOqm63hDmVL+lWSaYJeDwVSV7D
fCPFkdGvwATcNFgpTDxUFHzj3/Qk1QRUZETOCmA2vyTfOMxhCskiJ1MBs7Fa
aqiGgCkIh5T0EjDrLa8pPRA1hbDAnYz6mI8FdOTbK5rCyK1CZSLmA2fcUz6Q
TMG98vGsI2b6E/dOdaWZwp7jxyZDMa/z04sefGQKr+G7+WXMyx89B6/lmULF
QvzzSMy/rZQt9CtNQXflJrqGud+4R62p3xRoj618uoP5UyY90wCrGdRfceQo
wPxhVcmVhdMMaodInUWY3x/3alDlMYOamLLQEsxUvu6QdGEzaA5UbCjH3Jxy
/4+1vBnouHcMNGJ+eUPlc7e5GXyLog/pxex0dydDBckMvu4wivqAmT1nWOah
rRkIsYzFfsLsWx93xcfJDDIe+IQOYpb++0mSxc8MtseucI9ifmxzMVD7lhm8
tGA6+BezhZvpI+nbZiAoe7R3DjPdOZEOjjQzCHvMELyA2TG+XWj4gRnMyxYW
LWMWqOVvuVRoBjOJK8M0vFSULFq1+xXFDAR6Fm1ZMGvJJ6D7PWZwgEu8dAfm
GXWXU1F9ZlCQMradFbOZNUu15RdsfhHn3F2YWeKOu/z5ZQbjR3685MIcOb1S
LLWTCLXpv5iFMR9aofbvYieCTY3Q/r2Yh5meMC7tJkLYf6/U9mGGfca2LYJE
oOEwcRDFvGJ5j9blIBG+vjl6UQKzf4W62T0jIhzZU8gth7nUtoXuoxkRnlv2
sMljnl82K+W0IsLym2uMCpiDVF344u2JMBjy98chzJeq4r4HnyFCueNchBLm
6Jq+QHICEaz3HpI8hrn1xMkDyclEEJP49Bv39vWfA5RUIkg9rClFmOPRmqbu
QyJovHRX0sCcUCe640gxEXw/mvETMKc3nH3I8Y4IearsZ/Qxf3b6Z2H6gQj2
Qrw7DTALbLnKeK2fCHtpp57hztRK9aIbIQIHmWfIEHNWU43inzksH6mtYII5
v5n5TRe3OagdVw0wxzzldjtku4A5KHN5z+OW2SokqyNsjt2n/f4WmIt0FZKr
Jczhsewdb0vMZa3kE/lHzcHhlpQeCXPtmyczsXbmIEHPW2KDuZiHejbUwRyW
RAQ5bTE/dlv+7etsDnxcI3644+hMp629zCG5jypth9lSZXFC7CI23t24xOOY
f+YajNSnm8NWMT5JB8z9C/4upZnm8LYDLuCmaN//lvPIHKKYPJpwlwzNDt3M
M4ebdE12jpjDeO8N2leYg9hZ+rCTmDljp/uWPppD/iuVdGfMjH281lMD5sA8
1f4R95IooffrkDm0UON5XDAP1qW+axk3h6Onc5Nw5y5qvL29ZA5Mng/CXTEf
80h+I89rATriz5XcMcuX1eiLCVqAmr+fF25R+vFWnr0WQPx8PRP3tgfqLesS
FtDgQ6HzwPyub7SxU9kCuJZeNeI+pXu0+hTZAg61rkt4Yv4lwfu66LgF3EWP
Sbj9ti91LDlagOGR3AjcIZ2v+mNPWYBx9cBn3AkWyiu5wRbgUyly1Qv/Pw5K
qj8zLIB1f2mVN2ZVDW4thYcWcLZTcwh33b4Fg+AnFkAgmjCcxtw2Uma7/YUF
XOQbNcTd73UkWKrWAibHDHpw0wUqlnsOWYD+k8iOM/j+ttldXzxiAe3OzeO4
WVTnWpfHLUAi+wGjD+bdayUf4mYsQHxcBOGWiDy8mLfFEpSSYp/hNk04pDQh
ZgnuurN+vng/znKgQ1KWMJJAjsNNtpjVuShjCeq8Xg9xO3G9JDErWcKV8cwu
3AEZCgEH9CwhNuiE2FnMGTnypV6eltA8tPM17taPzq33z1iCw47zfbj/bk/5
3OOHjb/v7jhuw9PLtGoXLUE5RWqHH+Zl+UYTlnhLyHX3IeK2qbQcy39uCVuz
yRTckZNR/74WWYLXotgg7kLB8p27yywhn6tuEjdTuKBiaI0lJCvYbzuH+RVh
9LIxxRKuKxoBbq6uC/y/flvC3XfRT3BrrufK7JuzhP/4vYtwn5Hr1yAtWcIX
dvFq3M2J4FFDawUSmiLvcJ+33lZ6g90KyBqaNP54v76mm8getoLRpFgibhr2
zpPOylawk363HW5prXX/O2pW8Io/zAV3xBPnu+sEK1BR+xOAW8FTeoxiZQW3
BOzScd+arb7se8EKFGRLPuM+051w8vhFK6AZHhrGbVTkrKEXZgV/5hbGcTP6
bKMVjrYCIsvgAu6Qn5bhlBQr+C8ynf08ZrehiUsyZVbQLs9LwE2oqznBV2EF
fTHT+rj33r91jLHGCjpoX5ri7j+utDbw2go+JNLZ4SZ+uBJ6/b0V7G/s8MWt
RuENmfxrBdo/iWm4eV9M2n1YtIJEdqFM3PPxtapNK1ZQu3XgEe4iA9d/d+lJ
2P6Syse9v7kw2JCTBJQo1hrcu6p1g/IOkeD5cbkvuH/d5bNJUcLyVjzfcHcE
TylfUSWBdcrsKO4o5aRFGy0SzJdF/sK98nLwwjYLEjANcq3iHs07H+DhR4KD
fPt5AjCTBNcGcwJIcMA5kx/365tRuuPBJBgc3y6E+7H/HR7PCBJMydWK4XY6
Vl7hlUwCNaU0BdyDb1fWzpSR4A5R2QC3CeGqe0EFCXKDV41wV5ftoE7XkGA3
5ZUp7oy7ex76tpBgMovdCretK2j5fSDBkSxrB9zvFyOizy+TIOiekR9ughfL
79I1EoSXxfrjLhlIJs/TWcMP07oA3IkNTyQvMFtDzxa+i7jN4lvaAwWsQdI3
LAJ3hxAzW8gxa2iyZU/C/YxeYGhFxxokeMtScMeNSxeHmloD80eUjlvvpYll
mKM1GNszPMTdpJOYeuWKNdRfID/HzRj9ne5cnDU0sKwWbORbjpx2TrSGvsW4
4o35dD9rEB5Zw4tk7/9w9+iJTjA0WMNr9+t1ARv3e4DVfJs18DuXNGz0v621
dvStNRA4u5pwf9I/ndwyZA1sqR9bcQ8blKnH0pLhphiRitut3ZbdcxcZtGSr
e3D/NFwfNdiLme1vL+4ZI70EFg0y/Bhu7scd0DnpMmVGhttRQV9wLxvfOtrl
SIbEO6zDuGlNPw3fDCdDCO3oKG7hna3fhRPI4GHKP44bOktHi+6TgV9ccQJ3
uOGtnz01ZOg5xzWNu67N+9fcABluVcfN4KbR05vhXiUD9VnB3EZ9s8j8UQEb
WKZLXtyoJ6wv2anaAFuj0r+N+oZPq6G2NrBrMn11o16jjPZBkA2shlav434U
0JwsXW0D8D1nywV8P+T3ipfT2ILrwggj7tGh0Qptgi14MgVtwx3DvWDcHW0L
b+8nMONeUT7INMJgB77rgTtx+9o6NyxE2EFgvR8bbolfhkl3WY5DTsvnXbiH
Lh92QbePw26WFnbcwdvd77vw20No7wkO3JxJaZ9iH9pDBV/jhgfeDuXm7DkB
15ZpOHE/ZZMKarl7AhS8pDdcUi/qcEHEAbqe2Gy43k9IW/yZAxTdi9zw+uQd
hzFOR/CaerrhTOEHAuqWjpDJXbfhFyadN8wTHaE9rmPD1SHLNB5UR3h5t23D
09/C115znIQXPSUb3mu4dUXE+iRsic3ZsOf11Ma12yfBjjZ783soktc+vjsJ
JszPNixsyDm4wuMEQ2JFG45vXpMTtneC7Qc2x2MT/Gtcl+EEuq0FG046N+7p
2O8E32wfbTimaYt6PZ8zOJmkbjhk9x7WfTbOQPMpccOJ9295t2c4g/fVhA3n
SjK88f/qDKyHN/3hRsSfdCEX0JHaNONfWt76Ey5waOzGhkmJH9tls1xAhvba
hrPlii5l/nAB7proDXu0PR/tlHKF9t6rG5Z0yjNZPe0K3BOb/aXrLQrPzXeF
5ueb/qxfXmw14QpCbZvunef1NZB1g9+0m/XdWcEH0Tk3mGHa9MiB0ZLCYjdo
v7uZX3xJVNs34wb/2iI213tkONBSzh2ij256/ZVfadQZd9AavrLhJ/7HQ2mL
3YG/dNOGcjraIXPuoPds09taVPrOHfYA05ebbrGXPeV1zgO4ajatstWssLTc
A5qrNv2i0Hdhfd0DVO9u+n/RLdHy
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.6, 0.4}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwt1nk8VF8bAPAZoZIWKlGRUCGFSil0H4x1LGNmMNbsW0L2tRRlTUgSUopE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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"\[CurlyPhi](t)\"", TraditionalForm]},
      PlotRange->{{0, 200}, {0, 2.1767131597652924`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{649., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.436708302846703*^9, 3.43670858615705*^9, {3.436708667728776*^9, 
   3.436708705948949*^9}, 3.436708888391455*^9, {3.436708943588758*^9, 
   3.436708963712274*^9}, 3.436709074763028*^9, {3.436709108210713*^9, 
   3.436709117869966*^9}, 3.436709423961821*^9, 3.436712214615634*^9, 
   3.468938282364809*^9, 3.468938477461527*^9, 3.468939609452206*^9, 
   3.468939910038463*^9, 3.469126439881639*^9, 3.469126887630897*^9, 
   3.489242102818687*^9, 3.500038607931285*^9, {3.5327052167844563`*^9, 
   3.532705241165474*^9}, 3.532705660097748*^9, 3.5327061625793743`*^9, 
   3.5327064159962606`*^9, 3.564681532467819*^9, 3.5646892064001303`*^9, 
   3.564689569498045*^9, 3.564690632713604*^9, 3.56469302402781*^9, 
   3.564693211889472*^9, 3.564695070633029*^9}]
}, Open  ]],

Cell["Numerical Intergations of the AME", "Text",
 CellChangeTimes->{{3.436707444111488*^9, 3.436707461772749*^9}, {
   3.436709334864331*^9, 3.436709336846146*^9}, 3.436712025213399*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solramep", "[", "1", "]"}], "=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Mu]", "=", "0.05"}], ",", 
      RowBox[{"\[Nu]", "=", "0.05"}]}], "}"}], ",", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"amep", "[", "1", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"amep", "[", "2", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"amep", "[", "3", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"amep", "[", "4", "]"}], "/.", "vals"}], ")"}], "==", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"a1", "[", "0", "]"}], "==", "0.1"}], ",", 
        RowBox[{
         RowBox[{"a2", "[", "0", "]"}], "==", "0.1"}], ",", 
        RowBox[{
         RowBox[{"\[CurlyTheta]1", "[", "0", "]"}], "==", "0.1"}], ",", 
        RowBox[{
         RowBox[{"\[CurlyTheta]2", "[", "0", "]"}], "==", "0.1"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a1", "[", "t", "]"}], ",", 
        RowBox[{"a2", "[", "t", "]"}], ",", 
        RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], ",", 
        RowBox[{"\[CurlyTheta]2", "[", "t", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "ti"}], "}"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.436707561368821*^9, 3.436707607657047*^9}, {
  3.436707641996551*^9, 3.436707699807487*^9}, {3.436707965718594*^9, 
  3.436707969218277*^9}, {3.436708279093091*^9, 3.436708279669862*^9}, {
  3.436708627544259*^9, 3.436708640158691*^9}, {3.436709502651014*^9, 
  3.43670956694684*^9}, {3.532705662678557*^9, 3.5327056926709538`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"a1", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"a2", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"\[CurlyTheta]2", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.436709568050694*^9, 3.436712214767787*^9, 
  3.468938323105826*^9, 3.468938477622719*^9, 3.468939609533846*^9, 
  3.468939913784586*^9, 3.469126440029466*^9, 3.469126887756891*^9, 
  3.489242108826615*^9, 3.500038610421792*^9, 3.532705248960359*^9, 
  3.532705693180365*^9, 3.532706162617591*^9, 3.532706416056299*^9, 
  3.564681532504862*^9, 3.56468922005652*^9, 3.5646895696510677`*^9, 
  3.564690632767243*^9, 3.564693024189343*^9, 3.564693211928837*^9, 
  3.564695070739406*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a1", "[", "t", "]"}], "/.", 
         RowBox[{"solramep", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t\>\"", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(1\)]\)(t)\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a2", "[", "t", "]"}], "/.", 
         RowBox[{"solramep", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.6"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t\>\"", ",", "\"\<\!\(\*SubscriptBox[\(a\), \(2\)]\)(t)\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[CurlyTheta]1", "[", "t", "]"}], "/.", 
         RowBox[{"solramep", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"AxesOrigin", "->", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(\[CurlyTheta]\), \(1\)]\)(t)\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[CurlyTheta]2", "[", "t", "]"}], "/.", 
         RowBox[{"solramep", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"AxesOrigin", "->", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(\[CurlyTheta]\), \(2\)]\)(t)\>\""}], 
         "}"}]}]}], "]"}]}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.43670797401342*^9, 3.436707974839756*^9}, {
  3.436708018211059*^9, 3.436708163439754*^9}, {3.436708284280279*^9, 
  3.43670829162185*^9}, {3.436708649998939*^9, 3.436708704732867*^9}, {
  3.436708933513278*^9, 3.436708942188644*^9}, {3.436709068857664*^9, 
  3.436709074238786*^9}, {3.436709107254534*^9, 3.436709117207737*^9}, {
  3.436709571862621*^9, 3.436709595058657*^9}, {3.532705254201531*^9, 
  3.532705260765308*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwt1Xc8ld8fAHA7SsNIRBIqezRkn4/Nta/r3huJ7FVUvpJRRGRUZklSpEIq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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(a\\), \\(1\\)]\\)(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.8, 0.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {194.4, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006`, 222.49223594996212`}], 
    InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwt1Xc8ld8fAHCUUbQooygVhWRr4nzk2vNe13UR2WRlZYtCUqKQKNEOEQrf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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(a\\), \\(2\\)]\\)(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.6, 0.4}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {583.2, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006`, 222.49223594996212`}], 
    InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVkmk41Isbhn/KUuFEi+04hdRBxeioNIfe11grS6aypJGI+dlKWYuKKGQL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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[CurlyTheta]\\), \\(1\\)]\\)(t)\"", 
         TraditionalForm]},
      PlotRange->{{0, 200}, {0., 2.078237455745382}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {972., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVVXk41Ov7llOIpBxEC21fS5ttsswY70OSbIXsSyJ8yi5LfbVQsiXJXiFK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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[CurlyTheta]\\), \\(2\\)]\\)(t)\"", 
         TraditionalForm]},
      PlotRange->{{0, 200}, {-0.12584418814719456`, 1.9797617527536437`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {1360.8000000000002`, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212`}]}, {}},
  
  ContentSelectable->True,
  ImageSize->{729., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.436709596758204*^9, 3.436712215188245*^9, 
  3.468938331404401*^9, 3.46893847787707*^9, 3.468939609874825*^9, 
  3.468939914991108*^9, 3.469126440268987*^9, 3.469126888269549*^9, 
  3.489242112508263*^9, 3.500038612117106*^9, 3.532705261353615*^9, 
  3.532705695929182*^9, 3.532706162736027*^9, 3.532706416158152*^9, 
  3.564681532585494*^9, 3.5646892255173407`*^9, 3.564689570303873*^9, 
  3.564690632853837*^9, 3.564693024577333*^9, 3.56469321209837*^9, 
  3.5646950708489323`*^9}]
}, Open  ]],

Cell["Graphics of the reconstituted solution", "Text",
 CellChangeTimes->{{3.436707444111488*^9, 3.436707461772749*^9}, {
   3.436709334864331*^9, 3.436709336846146*^9}, 3.436712025213399*^9, {
   3.436712060493901*^9, 3.436712069974138*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Mu]", "=", "0.05"}], ",", 
     RowBox[{"\[Nu]", "=", "0.05"}]}], "}"}], ",", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["ur", "1"], "[", "t", "]"}], "/.", 
           RowBox[{"solramep", "[", "1", "]"}]}], "/.", "vals"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
         RowBox[{"PlotRange", "->", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "->", 
          RowBox[{"{", 
           RowBox[{"\"\<t\>\"", ",", "\"\<u1(t)\>\""}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["ur", "3"], "[", "t", "]"}], "/.", 
           RowBox[{"solramep", "[", "1", "]"}]}], "/.", "vals"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
         RowBox[{"PlotRange", "->", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.6"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "->", 
          RowBox[{"{", 
           RowBox[{"\"\<t\>\"", ",", "\"\<u3(t)\>\""}], "}"}]}]}], "]"}]}], 
      "}"}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.436709613704089*^9, 3.436709718095512*^9}, {
  3.436709821940011*^9, 3.436709821996701*^9}, {3.436711219766186*^9, 
  3.436711266007394*^9}, {3.436711301142306*^9, 3.436711318385585*^9}, {
  3.436711564280316*^9, 3.436711566360418*^9}, {3.436712040135463*^9, 
  3.436712047594182*^9}, {3.532705270530055*^9, 3.5327052758785*^9}, {
  3.5327057091099777`*^9, 3.5327057208592367`*^9}, {3.5327060516202717`*^9, 
  3.532706076484746*^9}, {3.5646892488924427`*^9, 3.564689250269388*^9}, {
  3.564689363625331*^9, 3.564689368238064*^9}, {3.564695041887064*^9, 
  3.5646950469792633`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwUV3c41t8blkpWpcyQ7JW993nszft6tcSXZJaERIoiikoqqVQyohApezv2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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"u1(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.8, 0.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwUV3c41u8XlqwiyUpW9s4m+zn25iUtqSghX2Uko6ykCNlZ2dkre7zG89p7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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"u3(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.6, 0.4}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{527., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.436709662936314*^9, 3.43670972600211*^9, 3.436709824091894*^9, {
   3.43671123153436*^9, 3.436711258004141*^9}, {3.43671130533208*^9, 
   3.436711329910733*^9}, {3.436711544301918*^9, 3.436711568569765*^9}, 
   3.436712073583397*^9, 3.436712217670115*^9, 3.46893834045142*^9, 
   3.468938479501378*^9, 3.468939611421128*^9, 3.468939943900679*^9, 
   3.469126441627959*^9, 3.469126889939222*^9, 3.489242120307827*^9, 
   3.50003862093267*^9, 3.5327052768541594`*^9, {3.532705699094438*^9, 
   3.532705721939686*^9}, {3.532706057569429*^9, 3.532706077844574*^9}, 
   3.532706163573104*^9, 3.5327064169895144`*^9, 3.5646815327223377`*^9, 
   3.564689253918909*^9, 3.564689370249239*^9, 3.5646895714109907`*^9, 
   3.564690633709372*^9, 3.56469302496517*^9, 3.564693212940958*^9, 
   3.564695071881235*^9}]
}, Open  ]],

Cell["Numerical Intergations of the starting equations", "Text",
 CellChangeTimes->{{3.436707444111488*^9, 3.436707461772749*^9}, {
  3.436709334864331*^9, 3.436709347169195*^9}, {3.532705293404608*^9, 
  3.53270529495054*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solorig", "[", "1", "]"}], "=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Mu]", "=", "0.05"}], ",", 
      RowBox[{"\[Nu]", "=", "0.05"}]}], "}"}], ",", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"EOM", "/.", "detuning"}], "/.", "vals"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            SubscriptBox["u", "1"], "[", "0", "]"}], "==", "0.1"}], ",", 
          RowBox[{
           RowBox[{
            SubscriptBox["u", "2"], "[", "0", "]"}], "==", "0.1"}], ",", 
          RowBox[{
           RowBox[{
            SubscriptBox["u", "3"], "[", "0", "]"}], "==", "0.1"}], ",", 
          RowBox[{
           RowBox[{
            SubscriptBox["u", "4"], "[", "0", "]"}], "==", "0.1"}]}], "}"}]}],
        "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["u", "1"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["u", "2"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["u", "3"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["u", "4"], "[", "t", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
      RowBox[{"MaxSteps", "->", "1000000"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.436707561368821*^9, 3.436707607657047*^9}, {
   3.436707641996551*^9, 3.436707699807487*^9}, {3.436707965718594*^9, 
   3.436707969218277*^9}, {3.436708204419933*^9, 3.436708253154541*^9}, {
   3.43670837373002*^9, 3.436708396702103*^9}, {3.436708658513215*^9, 
   3.436708658576716*^9}, {3.436708714720637*^9, 3.436708728018784*^9}, {
   3.5327057254448442`*^9, 3.532705743307701*^9}, {3.564689289632896*^9, 
   3.564689343819642*^9}, 3.564692972054401*^9, {3.564695052563395*^9, 
   3.56469509159367*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["u", "1"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "2"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "3"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "4"], "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "200.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.436708381406758*^9, 3.436708398138699*^9}, 
   3.436708473068119*^9, 3.436708596869458*^9, {3.436708711454561*^9, 
   3.43670873139477*^9}, 3.436708897916433*^9, 3.436708976468212*^9, 
   3.436709424179976*^9, 3.436709757662745*^9, 3.43671155133194*^9, 
   3.436712077997157*^9, 3.436712218227032*^9, 3.46893834580292*^9, 
   3.468938479801133*^9, 3.468939611752985*^9, 3.468939950403642*^9, 
   3.469126441782497*^9, 3.469126890407371*^9, 3.489242143083263*^9, 
   3.500038624361801*^9, 3.532705280581847*^9, 3.532705743889324*^9, 
   3.532706163690403*^9, 3.5327064170170517`*^9, 3.5646815328105516`*^9, {
   3.564689346275823*^9, 3.564689373007464*^9}, 3.564689571722019*^9, 
   3.564690633869954*^9, 3.564693025022896*^9, 3.564693213007557*^9, {
   3.5646950724943*^9, 3.5646950921612988`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["u", "1"], "[", "t", "]"}], "/.", 
         RowBox[{"solorig", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{"\"\<t\>\"", ",", "\"\<u1(t)\>\""}], "}"}]}]}], "]"}], ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["u", "3"], "[", "t", "]"}], "/.", 
         RowBox[{"solorig", "[", "1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "ti"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.6"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{"\"\<t\>\"", ",", "\"\<u3(t)\>\""}], "}"}]}]}], "]"}]}], 
    "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.436708489059174*^9, 3.436708530594842*^9}, {
  3.436708660505579*^9, 3.436708662960626*^9}, {3.436708740912556*^9, 
  3.436708779419127*^9}, {3.436708846380706*^9, 3.436708866307115*^9}, {
  3.436708898376822*^9, 3.436708927075409*^9}, {3.436709125445795*^9, 
  3.43670912850145*^9}, {3.436709752128588*^9, 3.436709755092988*^9}, {
  3.532705283811137*^9, 3.532705290179524*^9}, {3.532706080881328*^9, 
  3.532706084978578*^9}, {3.5646893498839083`*^9, 3.5646893605593023`*^9}, {
  3.564695065132278*^9, 3.564695066567583*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwUV3dcz98XTksLaUlLaQ/tpXVPe9engUQaSmkoSYMiCUnfliRJ0l7ae932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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"u1(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.8, 0.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwUV3c8198XloTMsjIiskf2Ht1jbz4yQopKCCGZRSIiCiGrbNl7jw/XXkmy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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Frame->True,
      FrameLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"u3(t)\"", TraditionalForm]},
      PlotRange->{{0., 199.99999591836735`}, {-0.6, 0.4}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{540., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.436708533060222*^9, 3.436708598283035*^9, 3.436708733071404*^9, 
   3.436708781619493*^9, 3.436708978553758*^9, 3.436709129677587*^9, 
   3.436709424735833*^9, 3.436709758938252*^9, 3.436711552664252*^9, 
   3.436712079455104*^9, 3.436712218830009*^9, 3.468938348867474*^9, 
   3.468938480392467*^9, 3.468939612397022*^9, 3.468939961303028*^9, 
   3.469126442229281*^9, 3.469126890959557*^9, 3.489242147918114*^9, 
   3.500038626207718*^9, 3.5327052908925047`*^9, 3.5327057460192213`*^9, 
   3.532706085319536*^9, 3.532706163866652*^9, 3.532706417189333*^9, 
   3.5646815329577303`*^9, 3.5646893757594757`*^9, 3.564689571975045*^9, 
   3.5646906340625763`*^9, 3.5646930252327213`*^9, 3.564693213210693*^9, {
   3.564695072683897*^9, 3.564695093725327*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1239, 679},
WindowMargins->{{Automatic, 54}, {0, Automatic}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 497, 8, 50, "Subtitle"],
Cell[1079, 32, 138, 3, 29, "Subsubtitle"],
Cell[1220, 37, 419, 7, 28, "Text"],
Cell[1642, 46, 136, 4, 30, "Input"],
Cell[1781, 52, 144, 5, 28, "Text"],
Cell[CellGroupData[{
Cell[1950, 61, 3109, 89, 74, "Input"],
Cell[5062, 152, 3726, 108, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8825, 265, 141, 3, 71, "Section"],
Cell[8969, 270, 767, 26, 31, "Text"],
Cell[9739, 298, 53, 1, 30, "Input"],
Cell[9795, 301, 466, 18, 30, "Input"],
Cell[10264, 321, 255, 9, 30, "Input"],
Cell[10522, 332, 140, 4, 28, "Text"],
Cell[10665, 338, 1084, 35, 55, "Input"],
Cell[11752, 375, 174, 5, 28, "Text"],
Cell[11929, 382, 475, 16, 33, "Input"],
Cell[12407, 400, 235, 7, 30, "Input"],
Cell[12645, 409, 265, 7, 28, "Text"],
Cell[12913, 418, 1724, 52, 60, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[14674, 475, 152, 3, 41, "Section"],
Cell[14829, 480, 204, 3, 28, "Text"],
Cell[15036, 485, 622, 15, 33, "Input"],
Cell[15661, 502, 235, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[15921, 509, 2212, 67, 50, "Input"],
Cell[18136, 578, 2380, 71, 70, "Output"]
}, Open  ]],
Cell[20531, 652, 456, 14, 33, "Input"],
Cell[20990, 668, 358, 10, 30, "Text"],
Cell[21351, 680, 751, 24, 34, "Input"],
Cell[22105, 706, 515, 19, 31, "Text"],
Cell[22623, 727, 966, 31, 34, "Input"],
Cell[23592, 760, 658, 23, 30, "Text"],
Cell[24253, 785, 788, 22, 30, "Input"],
Cell[25044, 809, 196, 5, 29, "Text"],
Cell[25243, 816, 561, 17, 30, "Input"],
Cell[25807, 835, 239, 6, 28, "Text"],
Cell[26049, 843, 1354, 44, 34, "Input"],
Cell[27406, 889, 463, 18, 30, "Text"],
Cell[CellGroupData[{
Cell[27894, 911, 471, 15, 69, "Input"],
Cell[28368, 928, 2992, 87, 70, "Output"],
Cell[31363, 1017, 5411, 161, 70, "Output"],
Cell[36777, 1180, 8215, 243, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[45041, 1429, 85, 2, 41, "Section"],
Cell[CellGroupData[{
Cell[45151, 1435, 198, 5, 30, "Input"],
Cell[45352, 1442, 2711, 81, 95, "Output"]
}, Open  ]],
Cell[48078, 1526, 585, 21, 31, "Text"],
Cell[48666, 1549, 1216, 37, 30, "Input"],
Cell[49885, 1588, 369, 12, 30, "Text"],
Cell[CellGroupData[{
Cell[50279, 1604, 721, 20, 30, "Input"],
Cell[51003, 1626, 1223, 28, 33, "Output"]
}, Open  ]],
Cell[52241, 1657, 283, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[52549, 1670, 111, 3, 30, "Input"],
Cell[52663, 1675, 1780, 48, 50, "Output"]
}, Open  ]],
Cell[54458, 1726, 525, 19, 31, "Text"],
Cell[CellGroupData[{
Cell[55008, 1749, 250, 8, 30, "Input"],
Cell[55261, 1759, 987, 25, 50, "Output"]
}, Open  ]],
Cell[56263, 1787, 527, 19, 31, "Text"],
Cell[CellGroupData[{
Cell[56815, 1810, 287, 9, 30, "Input"],
Cell[57105, 1821, 992, 24, 30, "Output"]
}, Open  ]],
Cell[58112, 1848, 87, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[58224, 1854, 144, 4, 30, "Input"],
Cell[58371, 1860, 941, 22, 30, "Output"]
}, Open  ]],
Cell[59327, 1885, 282, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[59634, 1898, 475, 15, 30, "Input"],
Cell[60112, 1915, 2633, 69, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62782, 1989, 789, 26, 33, "Input"],
Cell[63574, 2017, 3648, 107, 58, "Output"]
}, Open  ]],
Cell[67237, 2127, 655, 18, 30, "Input"],
Cell[67895, 2147, 245, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[68165, 2159, 665, 21, 30, "Input"],
Cell[68833, 2182, 5160, 148, 104, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[74042, 2336, 86, 2, 41, "Section"],
Cell[74131, 2340, 502, 15, 30, "Text"],
Cell[74636, 2357, 328, 10, 30, "Input"],
Cell[CellGroupData[{
Cell[74989, 2371, 280, 9, 30, "Input"],
Cell[75272, 2382, 478, 9, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75787, 2396, 438, 14, 30, "Input"],
Cell[76228, 2412, 854, 21, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77119, 2438, 525, 15, 30, "Input"],
Cell[77647, 2455, 977, 27, 45, "Output"]
}, Open  ]],
Cell[78639, 2485, 181, 5, 28, "Text"],
Cell[78823, 2492, 496, 16, 30, "Input"],
Cell[79322, 2510, 565, 17, 30, "Input"],
Cell[79890, 2529, 533, 17, 30, "Input"],
Cell[80426, 2548, 464, 15, 30, "Input"],
Cell[80893, 2565, 149, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[81067, 2572, 94, 2, 30, "Input"],
Cell[81164, 2576, 4280, 138, 55, "Output"]
}, Open  ]],
Cell[85459, 2717, 312, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[85796, 2731, 276, 9, 50, "Input"],
Cell[86075, 2742, 14842, 422, 148, "Output"]
}, Open  ]],
Cell[100932, 3167, 494, 14, 30, "Text"],
Cell[CellGroupData[{
Cell[101451, 3185, 577, 18, 50, "Input"],
Cell[102031, 3205, 1712, 48, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103780, 3258, 577, 18, 50, "Input"],
Cell[104360, 3278, 1508, 42, 33, "Output"]
}, Open  ]],
Cell[105883, 3323, 600, 18, 47, "Text"],
Cell[CellGroupData[{
Cell[106508, 3345, 474, 16, 50, "Input"],
Cell[106985, 3363, 1765, 49, 33, "Output"]
}, Open  ]],
Cell[108765, 3415, 63, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[108853, 3421, 1146, 36, 55, "Input"],
Cell[110002, 3459, 2119, 59, 75, "Output"]
}, Open  ]],
Cell[112136, 3521, 87, 2, 28, "Text"],
Cell[112226, 3525, 171, 5, 30, "Input"],
Cell[112400, 3532, 366, 13, 30, "Text"],
Cell[CellGroupData[{
Cell[112791, 3549, 916, 24, 50, "Input"],
Cell[113710, 3575, 11136, 309, 179, "Output"]
}, Open  ]],
Cell[124861, 3887, 176, 5, 28, "Text"],
Cell[CellGroupData[{
Cell[125062, 3896, 636, 14, 30, "Input"],
Cell[125701, 3912, 662, 14, 33, "Output"]
}, Open  ]],
Cell[126378, 3929, 176, 5, 28, "Text"],
Cell[126557, 3936, 504, 14, 30, "Input"],
Cell[127064, 3952, 419, 13, 30, "Text"],
Cell[CellGroupData[{
Cell[127508, 3969, 1585, 46, 54, "Input"],
Cell[129096, 4017, 576, 11, 30, "Output"]
}, Open  ]],
Cell[129687, 4031, 156, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[129868, 4038, 325, 10, 34, "Input"],
Cell[130196, 4050, 768, 19, 30, "Output"]
}, Open  ]],
Cell[130979, 4072, 291, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[131295, 4085, 1139, 33, 50, "Input"],
Cell[132437, 4120, 15399, 406, 307, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[147885, 4532, 85, 2, 41, "Section"],
Cell[147973, 4536, 346, 10, 30, "Text"],
Cell[148322, 4548, 388, 13, 30, "Input"],
Cell[148713, 4563, 709, 22, 49, "Text"],
Cell[CellGroupData[{
Cell[149447, 4589, 435, 13, 50, "Input"],
Cell[149885, 4604, 7467, 228, 111, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157389, 4837, 435, 13, 50, "Input"],
Cell[157827, 4852, 5712, 168, 119, "Output"]
}, Open  ]],
Cell[163554, 5023, 412, 16, 30, "Text"],
Cell[CellGroupData[{
Cell[163991, 5043, 562, 19, 50, "Input"],
Cell[164556, 5064, 4753, 129, 83, "Output"]
}, Open  ]],
Cell[169324, 5196, 63, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[169412, 5202, 1086, 33, 55, "Input"],
Cell[170501, 5237, 4733, 130, 94, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[175283, 5373, 78, 2, 41, "Section"],
Cell[175364, 5377, 320, 13, 30, "Text"],
Cell[175687, 5392, 238, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[175950, 5402, 1097, 36, 33, "Input"],
Cell[177050, 5440, 1559, 43, 52, "Output"]
}, Open  ]],
Cell[178624, 5486, 287, 7, 41, "Text"],
Cell[CellGroupData[{
Cell[178936, 5497, 1143, 37, 33, "Input"],
Cell[180082, 5536, 1662, 45, 52, "Output"]
}, Open  ]],
Cell[181759, 5584, 151, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[181935, 5590, 1759, 57, 33, "Input"],
Cell[183697, 5649, 1880, 46, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185614, 5700, 2523, 81, 55, "Input"],
Cell[188140, 5783, 2050, 51, 52, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[190239, 5840, 202, 3, 41, "Section"],
Cell[190444, 5845, 198, 5, 28, "Text"],
Cell[CellGroupData[{
Cell[190667, 5854, 1452, 45, 33, "Input"],
Cell[192122, 5901, 2106, 54, 33, "Output"]
}, Open  ]],
Cell[194243, 5958, 102, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[194370, 5963, 576, 14, 30, "Input"],
Cell[194949, 5979, 2681, 70, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197667, 6054, 576, 14, 30, "Input"],
Cell[198246, 6070, 2578, 71, 52, "Output"]
}, Open  ]],
Cell[200839, 6144, 167, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[201031, 6150, 1760, 49, 47, "Input"],
Cell[202794, 6201, 2477, 61, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205308, 6267, 294, 7, 30, "Input"],
Cell[205605, 6276, 7605, 178, 119, "Output"]
}, Open  ]],
Cell[213225, 6457, 189, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[213439, 6463, 281, 6, 30, "Input"],
Cell[213723, 6471, 5469, 113, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219229, 6589, 307, 7, 30, "Input"],
Cell[219539, 6598, 5650, 117, 96, "Output"]
}, Open  ]],
Cell[225204, 6718, 207, 4, 28, "Text"],
Cell[CellGroupData[{
Cell[225436, 6726, 360, 9, 35, "Input"],
Cell[225799, 6737, 2318, 66, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[228154, 6808, 768, 17, 35, "Input"],
Cell[228925, 6827, 2773, 73, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231735, 6905, 429, 12, 35, "Input"],
Cell[232167, 6919, 2967, 79, 94, "Output"]
}, Open  ]],
Cell[235149, 7001, 201, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[235375, 7009, 396, 10, 30, "Input"],
Cell[235774, 7021, 862, 16, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[236673, 7042, 512, 14, 30, "Input"],
Cell[237188, 7058, 1047, 22, 30, "Output"]
}, Open  ]],
Cell[238250, 7083, 118, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[238393, 7088, 991, 22, 30, "Input"],
Cell[239387, 7112, 2857, 54, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[242281, 7171, 1070, 23, 30, "Input"],
Cell[243354, 7196, 1449, 35, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[244840, 7236, 1094, 24, 30, "Input"],
Cell[245937, 7262, 2087, 55, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248061, 7322, 1072, 23, 30, "Input"],
Cell[249136, 7347, 1961, 52, 52, "Output"]
}, Open  ]],
Cell[251112, 7402, 120, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[251257, 7407, 1017, 22, 30, "Input"],
Cell[252277, 7431, 2736, 51, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255050, 7487, 1018, 22, 30, "Input"],
Cell[256071, 7511, 1344, 32, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257452, 7548, 1768, 50, 55, "Input"],
Cell[259223, 7600, 2485, 67, 91, "Output"]
}, Open  ]],
Cell[261723, 7670, 251, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[261999, 7677, 426, 12, 30, "Input"],
Cell[262428, 7691, 843, 17, 30, "Output"]
}, Open  ]],
Cell[263286, 7711, 251, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[263562, 7718, 1847, 48, 74, "Input"],
Cell[265412, 7768, 2468, 43, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[267917, 7816, 1918, 50, 74, "Input"],
Cell[269838, 7868, 2497, 45, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[272372, 7918, 2208, 58, 74, "Input"],
Cell[274583, 7978, 3287, 70, 52, "Output"]
}, Open  ]],
Cell[277885, 8051, 232, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[278142, 8058, 1958, 50, 35, "Input"],
Cell[280103, 8110, 2254, 66, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282394, 8181, 2308, 56, 55, "Input"],
Cell[284705, 8239, 509, 15, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[285251, 8259, 1903, 49, 35, "Input"],
Cell[287157, 8310, 2067, 60, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289261, 8375, 2308, 56, 55, "Input"],
Cell[291572, 8433, 511, 15, 30, "Output"]
}, Open  ]],
Cell[292098, 8451, 591, 13, 30, "Text"],
Cell[CellGroupData[{
Cell[292714, 8468, 612, 16, 30, "Input"],
Cell[293329, 8486, 1325, 34, 56, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[294703, 8526, 107, 1, 41, "Section"],
Cell[294813, 8529, 170, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[295008, 8535, 834, 21, 47, "Input"],
Cell[295845, 8558, 1081, 24, 47, "Output"]
}, Open  ]],
Cell[296941, 8585, 239, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[297205, 8592, 55, 1, 30, "Input"],
Cell[297263, 8595, 896, 28, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298196, 8628, 486, 14, 30, "Input"],
Cell[298685, 8644, 5932, 107, 240, "Output"]
}, Open  ]],
Cell[304632, 8754, 101, 1, 28, "Text"],
Cell[304736, 8757, 208, 4, 30, "Input"],
Cell[304947, 8763, 165, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[305137, 8769, 1635, 47, 88, "Input"],
Cell[306775, 8818, 1901, 51, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308713, 8874, 2698, 69, 107, "Input"],
Cell[311414, 8945, 28399, 484, 155, "Output"]
}, Open  ]],
Cell[339828, 9432, 187, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[340040, 9438, 1991, 55, 88, "Input"],
Cell[342034, 9495, 2029, 59, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344100, 9559, 3513, 91, 126, "Input"],
Cell[347616, 9652, 28178, 491, 132, "Output"]
}, Open  ]],
Cell[375809, 10146, 242, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[376076, 10153, 2489, 60, 107, "Input"],
Cell[378568, 10215, 113955, 1880, 188, "Output"]
}, Open  ]],
Cell[492538, 12098, 227, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[492790, 12105, 1939, 50, 50, "Input"],
Cell[494732, 12157, 2422, 67, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[497191, 12229, 2164, 53, 88, "Input"],
Cell[499358, 12284, 113576, 1874, 192, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
